"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createContentType = void 0;
var lib_1 = require("../../lib");
/**
 * Creates a content type in a web or specified list.
 * @param ctInfo - The content type information.
 * @param parentInfo - The parent content type id and url containing it.
 * @param webUrl - The relative url to create the content type in.
 * @param listName - The list name to add the content type to. If blank, it will add it to the web content types.
 */
var createContentType = function (props) {
    // Return a promise
    return new Promise(function (resolve, reject) {
        // See if we are targeting a list
        if (props.listName) {
            // Process the request
            lib_1.Web.processQuery(ListTemplate(props.listName, props.ctInfo, props.parentContentTypeId), props.webUrl).then(function () {
                // Get the content type and resolve the request
                (0, lib_1.Web)(props.webUrl).Lists(props.listName).ContentTypes().query({
                    Filter: "Name eq '" + props.ctInfo.Name + "'"
                }).execute(function (cts) {
                    // Resolve the request
                    resolve(cts.results[0]);
                }, reject);
            }, reject);
        }
        else {
            // Process the request
            lib_1.Web.processQuery(WebTemplate(props.ctInfo, props.parentContentTypeId), props.webUrl).then(function () {
                // Get the content type and resolve the request
                (0, lib_1.Web)(props.webUrl).ContentTypes().query({
                    Filter: "Name eq '" + props.ctInfo.Name + "'"
                }).execute(function (cts) {
                    // Resolve the request
                    resolve(cts.results[0]);
                }, reject);
            }, reject);
        }
    });
};
exports.createContentType = createContentType;
// List Template
var ListTemplate = function (listName, ctInfo, parentId) {
    if (parentId === void 0) { parentId = "0x01"; }
    return "<Request xmlns=\"http://schemas.microsoft.com/sharepoint/clientquery/2009\" SchemaVersion=\"15.0.0.0\" LibraryVersion=\"16.0.0.0\" ApplicationName=\"Javascript Library\">\n        <Actions>\n            <ObjectPath Id=\"1\" ObjectPathId=\"0\" />\n            <ObjectPath Id=\"3\" ObjectPathId=\"2\" />\n            <ObjectPath Id=\"5\" ObjectPathId=\"4\" />\n            <ObjectPath Id=\"7\" ObjectPathId=\"6\" />\n            <ObjectPath Id=\"9\" ObjectPathId=\"8\" />\n            <ObjectPath Id=\"11\" ObjectPathId=\"10\" />\n            <ObjectIdentityQuery Id=\"12\" ObjectPathId=\"10\" />\n            <ObjectPath Id=\"14\" ObjectPathId=\"13\" />\n            <ObjectPath Id=\"16\" ObjectPathId=\"15\" />\n            <ObjectIdentityQuery Id=\"17\" ObjectPathId=\"15\" />\n            <Query Id=\"18\" ObjectPathId=\"13\">\n                <Query SelectAllProperties=\"true\">\n                    <Properties />\n                </Query>\n                <ChildItemQuery SelectAllProperties=\"true\">\n                    <Properties />\n                </ChildItemQuery>\n            </Query>\n        </Actions>\n        <ObjectPaths>\n            <StaticProperty Id=\"0\" TypeId=\"{3747adcd-a3c3-41b9-bfab-4a64dd2f1e0a}\" Name=\"Current\" />\n            <Property Id=\"2\" ParentId=\"0\" Name=\"Web\" />\n            <Property Id=\"4\" ParentId=\"2\" Name=\"ContentTypes\" />\n                <Method Id=\"6\" ParentId=\"4\" Name=\"GetById\">\n                    <Parameters>\n                        <Parameter Type=\"String\">".concat(parentId, "</Parameter>\n                    </Parameters>\n                </Method>\n            <Property Id=\"8\" ParentId=\"2\" Name=\"Lists\" />\n            <Method Id=\"10\" ParentId=\"8\" Name=\"GetByTitle\">\n                <Parameters>\n                    <Parameter Type=\"String\">").concat(listName, "</Parameter>\n                </Parameters>\n            </Method>\n            <Property Id=\"13\" ParentId=\"10\" Name=\"ContentTypes\" />\n            <Method Id=\"15\" ParentId=\"13\" Name=\"Add\">\n                <Parameters>\n                    <Parameter TypeId=\"{168f3091-4554-4f14-8866-b20d48e45b54}\">\n                        <Property Name=\"Description\" Type=\"").concat(ctInfo.Description ? "String" : "Null", "\">").concat(ctInfo.Description || "", "</Property>\n                        <Property Name=\"Group\" Type=\"").concat(ctInfo.Group ? "String" : "Null", "\">").concat(ctInfo.Group || "", "</Property>\n                        <Property Name=\"Id\" Type=\"Null\" />\n                        <Property Name=\"Name\" Type=\"String\">").concat(ctInfo.Name || "", "</Property>\n                        <Property Name=\"ParentContentType\" ObjectPathId=\"6\" />\n                    </Parameter>\n                </Parameters>\n            </Method>\n        </ObjectPaths>\n    </Request>");
};
// Web Template
var WebTemplate = function (ctInfo, parentId) {
    if (parentId === void 0) { parentId = "0x01"; }
    return "<Request xmlns=\"http://schemas.microsoft.com/sharepoint/clientquery/2009\" SchemaVersion=\"15.0.0.0\" LibraryVersion=\"16.0.0.0\" ApplicationName=\"Javascript Library\">\n        <Actions>\n            <ObjectPath Id=\"26\" ObjectPathId=\"25\" />\n            <ObjectIdentityQuery Id=\"27\" ObjectPathId=\"25\" />\n            <Query Id=\"28\" ObjectPathId=\"4\">\n                <Query SelectAllProperties=\"true\">\n                    <Properties />\n                </Query>\n                <ChildItemQuery SelectAllProperties=\"true\">\n                    <Properties />\n                </ChildItemQuery>\n            </Query>\n        </Actions>\n        <ObjectPaths>\n            <Property Id=\"4\" ParentId=\"2\" Name=\"ContentTypes\" />\n            <Method Id=\"25\" ParentId=\"4\" Name=\"Add\">\n                <Parameters>\n                    <Parameter TypeId=\"{168f3091-4554-4f14-8866-b20d48e45b54}\">\n                        <Property Name=\"Description\" Type=\"".concat(ctInfo.Description ? "String" : "Null", "\">").concat(ctInfo.Description || "", "</Property>\n                        <Property Name=\"Group\" Type=\"").concat(ctInfo.Group ? "String" : "Null", "\">").concat(ctInfo.Group || "", "</Property>\n                        <Property Name=\"Id\" Type=\"Null\" />\n                        <Property Name=\"Name\" Type=\"String\">").concat(ctInfo.Name || "", "</Property>\n                        <Property Name=\"ParentContentType\" ObjectPathId=\"6\" />\n                    </Parameter>\n                </Parameters>\n            </Method>\n            <Property Id=\"2\" ParentId=\"0\" Name=\"Web\" />\n            <Method Id=\"6\" ParentId=\"4\" Name=\"GetById\">\n                <Parameters>\n                    <Parameter Type=\"String\">").concat(parentId, "</Parameter>\n                </Parameters>\n            </Method>\n            <StaticProperty Id=\"0\" TypeId=\"{3747adcd-a3c3-41b9-bfab-4a64dd2f1e0a}\" Name=\"Current\" />\n        </ObjectPaths>\n    </Request>");
};
