"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Web = void 0;
var contextInfo_1 = require("./contextInfo");
var utils_1 = require("../utils");
exports.Web = (function (url, targetInfo) {
    var web = new utils_1.Base(targetInfo);
    // Default the properties
    web.targetInfo.defaultToWebFl = true;
    web.targetInfo.endpoint = "web";
    // See if the web url exists
    if (url) {
        // Set the settings
        web.targetInfo.url = url;
    }
    // Add the methods
    utils_1.Request.addMethods(web, { __metadata: { type: "SP.Web" } });
    // Return the web
    return web;
});
// Static method to get a remote web
exports.Web.getRemoteWeb = (function (requestUrl) {
    // Return the remote web information
    return new utils_1.Base({
        data: { requestUrl: requestUrl },
        defaultToWebFl: true,
        endpoint: "SP.RemoteWeb?$expand=Web",
        method: "POST"
    });
});
// Static method to get the sharing settings
exports.Web.getSharingSettings = (function (data, query) {
    // See if we are querying the information
    if (query) {
        var oData = new utils_1.OData(query);
        // Update the url
        data.objectUrl += "?" + oData.QueryString;
    }
    // Return the sharing settings
    return new utils_1.Base({
        data: data,
        defaultToWebFl: true,
        endpoint: "SP.Web.GetObjectSharingSettings",
        method: "POST"
    });
});
// Static method to get the url of a web from a page url
exports.Web.getWebUrlFromPageUrl = (function (pageUrl) {
    // Return the remote web information
    return new utils_1.Base({
        endpoint: "SP.Web.GetWebUrlFromPageUrl(@v)?@v='" + pageUrl + "'",
        method: "POST"
    });
});
// Static method to execute a process query request
exports.Web.processQuery = function (query, webUrl) {
    // Minify the xml query
    var data = query.replace(/\r?\n/g, '').replace(/  /g, '');
    // Return a promise
    return new Promise(function (resolve, reject) {
        var processResponse = function (resp) {
            // See if there was an error
            if (resp[0] && resp[0].ErrorInfo) {
                // Reject the request
                console.error("[Error] " + resp[0].ErrorInfo.ErrorMessage, resp[0].ErrorInfo);
                reject(resp[0].ErrorInfo);
            }
            else {
                // Resolve the request
                resolve(resp);
            }
        };
        // See if the web url exist
        if (webUrl) {
            // Get the context information for the web
            contextInfo_1.ContextInfo.getWeb(webUrl).execute(
            // Success
            function (ctx) {
                // Execute the request
                (new utils_1.Base({
                    data: data,
                    endpoint: "_vti_bin/client.svc/ProcessQuery",
                    method: "POST",
                    requestDigest: ctx.GetContextWebInformation.FormDigestValue,
                    requestType: utils_1.RequestType.Post,
                    url: webUrl
                })).execute(processResponse, reject);
            }, 
            // Error
            function () {
                // Reject the request
                reject("Error getting the context information for the web.");
            });
        }
        else {
            // Execute the request
            (new utils_1.Base({
                data: data,
                endpoint: "_vti_bin/client.svc/ProcessQuery",
                method: "POST",
                requestDigest: contextInfo_1.ContextInfo.formDigestValue,
                requestType: utils_1.RequestType.Post,
            })).execute(processResponse, reject);
        }
    });
};
