"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.sites = void 0;
var contextInfo_1 = require("../lib/contextInfo");
var site_1 = require("../lib/site");
var web_1 = require("../lib/web");
var utils_1 = require("../utils");
/**
 * Sites
 * The sites graph endpoint.
 */
exports.sites = (function (props) {
    var _a;
    if (props === void 0) { props = {}; }
    var sites = new utils_1.Base(props.targetInfo);
    // Default the properties
    sites.targetInfo.defaultToWebFl = true;
    sites.targetInfo.endpoint = "_api/v2.0/sites";
    sites.targetInfo.requestType = utils_1.RequestType.GraphGet;
    // Default the url
    sites.targetInfo.url = ((_a = props === null || props === void 0 ? void 0 : props.targetInfo) === null || _a === void 0 ? void 0 : _a.url) || contextInfo_1.ContextInfo.webServerRelativeUrl;
    // See if the site id was provided
    if (props.siteId) {
        // Append the site id
        sites.targetInfo.endpoint += "/" + props.siteId.replace(/^\{|\}$/g, '');
        // See if the web id is provided
        if (props.webId) {
            // Append the web id
            sites.targetInfo.endpoint += "," + props.webId.replace(/^\{|\}$/g, '');
        }
    }
    // Add the methods
    if (props.siteId || props.webId) {
        utils_1.Request.addMethods(sites, { __metadata: { type: "@odata.context/_api/v2.0/$metadata#site" } });
    }
    else {
        utils_1.Request.addMethods(sites, { __metadata: { type: "@odata.context/_api/v2.0/$metadata#sites" } });
    }
    // Return the sites
    return sites;
});
/** Returns the current site. */
exports.sites.getCurrent = function () {
    return (0, exports.sites)({
        siteId: contextInfo_1.ContextInfo.siteId,
        webId: contextInfo_1.ContextInfo.webId
    });
};
/** Returns a drive */
exports.sites.getDrive = function (props) {
    // Return a promise
    return new Promise(function (resolve, reject) {
        // Method to get the drive id
        var getDriveId = function (siteId, webId, libName) {
            // Return a promise
            return new Promise(function (resolve, reject) {
                // Get the drives
                (0, exports.sites)({ siteId: siteId, webId: webId }).drives().query({ Select: ["id", "name"] }).execute(function (drives) {
                    // Parse the drives
                    for (var i = 0; i < drives.results.length; i++) {
                        var drive = drives.results[i];
                        // See if this is the target library
                        if (drive["name"].toLowerCase() == libName.toLowerCase()) {
                            // Resolve the request
                            resolve(drive.id);
                            return;
                        }
                    }
                    // Not found
                    reject();
                }, reject);
            });
        };
        // See if the site id exists
        if (props.siteId) {
            // Get the drive id
            getDriveId(props.siteId, props.webId, props.listName).then(function (driveId) {
                // Resolve the request
                resolve((0, exports.sites)({ siteId: props.siteId }).drives(driveId));
            }, reject);
        }
        else {
            // Get the site/web ids
            exports.sites.getIdByUrl(props.siteUrl).then(function (info) {
                // Get the drive id
                getDriveId(info.siteId, info.webId, props.listName).then(function (driveId) {
                    // Resolve the request
                    resolve((0, exports.sites)({ siteId: info.siteId, webId: info.webId }).drives(driveId));
                }, reject);
            }, reject);
        }
    });
};
/** Returns a file */
exports.sites.getFile = function (props) {
    // Return a promise
    return new Promise(function (resolve, reject) {
        // Get the site/web info
        exports.sites.getIdByUrl(props.fileUrl).then(function (info) {
            // Get the file
            (0, web_1.Web)(info.webUrl, { requestDigest: info.digestValue }).getFileByUrl(props.fileUrl).execute(function (file) {
                // See if the library was provided
                if (props.listName) {
                    // Get the drive
                    exports.sites.getDrive({
                        listName: props.listName,
                        siteId: info.siteId,
                        siteUrl: info.siteUrl,
                        webId: info.webId
                    }).then(function (drive) {
                        // Resolve the request
                        resolve(drive.items(file.UniqueId));
                    }, reject);
                }
                else {
                    // Get the list information
                    file.ListItemAllFields().query({ Expand: ["ParentList"], Select: ["ParentList/Title"] }).execute(function (item) {
                        // Get the drive
                        exports.sites.getDrive({
                            listName: item.ParentList.Title,
                            siteId: info.siteId,
                            siteUrl: info.siteUrl,
                            webId: info.webId
                        }).then(function (drive) {
                            // Resolve the request
                            resolve(drive.items(file.UniqueId));
                        }, reject);
                    }, reject);
                }
            }, reject);
        }, reject);
    });
};
/** Returns a list */
exports.sites.getList = function (props) {
    // Finds the list
    var findList = function (siteId, webId, listName) {
        // Return a promise
        return new Promise(function (resolve, reject) {
            (0, exports.sites)({ siteId: siteId, webId: webId }).lists().query({
                Filter: "displayName eq '" + listName + "'",
                Select: ["id"]
            }).execute(function (sites) {
                // See if the list id exists
                var list = sites.results[0];
                if (list === null || list === void 0 ? void 0 : list.id) {
                    // Resolve the request
                    resolve(list === null || list === void 0 ? void 0 : list.id);
                }
                else {
                    // Reject the request
                    reject("List was not found.");
                }
            }, reject);
        });
    };
    // Return a promise
    return new Promise(function (resolve, reject) {
        // See if the site id exists
        if (props.siteId) {
            // See if the id was given
            if (props.listId) {
                // Resolve the request
                resolve((0, exports.sites)({ siteId: props.siteId, webId: props.webId }).lists(props.listId));
            }
            else {
                // Find the list
                findList(props.siteId, props.webId, props.listName).then(function (listId) {
                    // Resolve the request
                    resolve((0, exports.sites)({ siteId: props.siteId, webId: props.webId }).lists(listId));
                }, reject);
            }
        }
        else {
            // Get the ids
            exports.sites.getIdByUrl(props.siteUrl).then(function (info) {
                // See if the id was given
                if (props.listId) {
                    // Resolve the request
                    resolve((0, exports.sites)({ siteId: info.siteId, webId: info.webId }).lists(props.listId));
                }
                else {
                    // Find the list
                    findList(info.siteId, info.webId, props.listName).then(function (listId) {
                        // Resolve the request
                        resolve((0, exports.sites)({ siteId: info.siteId, webId: info.webId }).lists(listId));
                    }, reject);
                }
            }, reject);
        }
    });
};
/** Gets the site and web id from a url */
exports.sites.getIdByUrl = function (url) {
    // Return a promise
    return new Promise(function (resolve, reject) {
        // Get the context information
        contextInfo_1.ContextInfo.getWeb(url).execute(function (context) {
            // Get the site id
            (0, site_1.Site)(context.GetContextWebInformation.SiteFullUrl).query({ Select: ["Id"] }).execute(function (site) {
                // Get the web id
                (0, web_1.Web)(context.GetContextWebInformation.WebFullUrl).query({ Select: ["Id"] }).execute(function (web) {
                    // Resolve the request
                    resolve({
                        digestValue: context.GetContextWebInformation.FormDigestValue,
                        siteId: site.Id,
                        siteUrl: context.GetContextWebInformation.SiteFullUrl,
                        webId: web.Id,
                        webUrl: context.GetContextWebInformation.WebFullUrl
                    });
                });
            }, reject);
        }, reject);
    });
};
/** Returns the root site of the current site. */
exports.sites.getRoot = function () {
    return (0, exports.sites)({
        siteId: contextInfo_1.ContextInfo.siteId
    });
};
/** Returns a site by url */
exports.sites.getSite = function (url) {
    // Return a promise
    return new Promise(function (resolve, reject) {
        // Get the site info
        exports.sites.getIdByUrl(url).then(function (info) {
            // Resolve the request
            resolve((0, exports.sites)({
                siteId: info.siteId,
                webId: info.webId
            }));
        }, reject);
    });
};
