"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MapperV2 = void 0;
var utils_1 = require("../utils");
/**
 * Mapper for the v2 api.
 */
exports.MapperV2 = {
    _case: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    aadUserConversationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        user: {
            returnType: "user"
        },
    },
    accessPackage: {
        properties: [
            "accessPackagesIncompatibleWith|accessPackages|/[Name]|accessPackage", "assignmentPolicies|accessPackageAssignmentPolicys|/[Name]|accessPackageAssignmentPolicy", "incompatibleAccessPackages|accessPackages|/[Name]|accessPackage", "incompatibleGroups|groups|/[Name]|group", "resourceRoleScopes|accessPackageResourceRoleScopes|/[Name]|accessPackageResourceRoleScope"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accessPackagesIncompatibleWith: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackages"
        },
        assignmentPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageAssignmentPolicys"
        },
        catalog: {
            returnType: "accessPackageCatalog"
        },
        incompatibleAccessPackages: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackages"
        },
        incompatibleGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "groups"
        },
        resourceRoleScopes: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceRoleScopes"
        },
        getApplicablePolicyRequirements: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.accessPackageAssignmentRequestRequirements[]"
        },
    },
    accessPackages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accessPackage: {
            returnType: "accessPackage"
        },
        assignmentPolicy: {
            returnType: "accessPackageAssignmentPolicy"
        },
        target: {
            returnType: "accessPackageSubject"
        },
        reprocess: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    accessPackageAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageAssignmentPolicy: {
        properties: [
            "customExtensionStageSettings|customExtensionStageSettings|/[Name]|customExtensionStageSetting", "questions|accessPackageQuestions|/[Name]|accessPackageQuestion"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accessPackage: {
            returnType: "accessPackage"
        },
        catalog: {
            returnType: "accessPackageCatalog"
        },
        customExtensionStageSettings: {
            requestType: utils_1.RequestType.Get,
            returnType: "customExtensionStageSettings"
        },
        questions: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageQuestions"
        },
    },
    accessPackageAssignmentPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageAssignmentRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accessPackage: {
            returnType: "accessPackage"
        },
        assignment: {
            returnType: "accessPackageAssignment"
        },
        requestor: {
            returnType: "accessPackageSubject"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        reprocess: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        resume: {
            argNames: ["source", "type", "data"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    accessPackageAssignmentRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageAssignmentRequestWorkflowExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageAssignmentWorkflowExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageCatalog: {
        properties: [
            "accessPackages|accessPackages|/[Name]|accessPackage", "customWorkflowExtensions|customCalloutExtensions|/[Name]|customCalloutExtension", "resourceRoles|accessPackageResourceRoles|/[Name]|accessPackageResourceRole", "resources|accessPackageResources|/[Name]|accessPackageResource", "resourceScopes|accessPackageResourceScopes|/[Name]|accessPackageResourceScope"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accessPackages: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackages"
        },
        customWorkflowExtensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "customCalloutExtensions"
        },
        resourceRoles: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceRoles"
        },
        resources: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResources"
        },
        resourceScopes: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceScopes"
        },
    },
    accessPackageCatalogs: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageMultipleChoiceQuestion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageQuestion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageQuestions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageResource: {
        properties: [
            "roles|accessPackageResourceRoles|/[Name]|accessPackageResourceRole", "scopes|accessPackageResourceScopes|/[Name]|accessPackageResourceScope"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        environment: {
            returnType: "accessPackageResourceEnvironment"
        },
        roles: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceRoles"
        },
        scopes: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceScopes"
        },
    },
    accessPackageResources: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageResourceEnvironment: {
        properties: [
            "resources|accessPackageResources|/[Name]|accessPackageResource"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resources: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResources"
        },
    },
    accessPackageResourceEnvironments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageResourceRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        catalog: {
            returnType: "accessPackageCatalog"
        },
        resource: {
            returnType: "accessPackageResource"
        },
    },
    accessPackageResourceRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageResourceRole: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resource: {
            returnType: "accessPackageResource"
        },
    },
    accessPackageResourceRoles: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageResourceRoleScope: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        role: {
            returnType: "accessPackageResourceRole"
        },
        scope: {
            returnType: "accessPackageResourceScope"
        },
    },
    accessPackageResourceRoleScopes: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageResourceScope: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resource: {
            returnType: "accessPackageResource"
        },
    },
    accessPackageResourceScopes: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessPackageSubject: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        connectedOrganization: {
            returnType: "connectedOrganization"
        },
    },
    accessPackageTextInputQuestion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewHistoryDefinition: {
        properties: [
            "instances|accessReviewHistoryInstances|/[Name]|accessReviewHistoryInstance"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        instances: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewHistoryInstances"
        },
    },
    accessReviewHistoryDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewHistoryInstance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        generateDownloadUri: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.accessReviewHistoryInstance"
        },
    },
    accessReviewHistoryInstances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewInstance: {
        properties: [
            "contactedReviewers|accessReviewReviewers|/[Name]|accessReviewReviewer", "decisions|accessReviewInstanceDecisionItems|/[Name]|accessReviewInstanceDecisionItem", "stages|accessReviewStages|/[Name]|accessReviewStage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        contactedReviewers: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewReviewers"
        },
        decisions: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewInstanceDecisionItems"
        },
        stages: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewStages"
        },
        acceptRecommendations: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        applyDecisions: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        batchRecordDecisions: {
            argNames: ["decision", "justification", "principalId", "resourceId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        resetDecisions: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        sendReminder: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        stop: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    accessReviewInstances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewInstanceDecisionItem: {
        properties: [
            "insights|governanceInsights|/[Name]|governanceInsight"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        insights: {
            requestType: utils_1.RequestType.Get,
            returnType: "governanceInsights"
        },
    },
    accessReviewInstanceDecisionItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewReviewer: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewReviewers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewScheduleDefinition: {
        properties: [
            "instances|accessReviewInstances|/[Name]|accessReviewInstance"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        instances: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewInstances"
        },
        stop: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    accessReviewScheduleDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    accessReviewSet: {
        properties: [
            "definitions|accessReviewScheduleDefinitions|/[Name]|accessReviewScheduleDefinition", "historyDefinitions|accessReviewHistoryDefinitions|/[Name]|accessReviewHistoryDefinition"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        definitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewScheduleDefinitions"
        },
        historyDefinitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewHistoryDefinitions"
        },
    },
    accessReviewStage: {
        properties: [
            "decisions|accessReviewInstanceDecisionItems|/[Name]|accessReviewInstanceDecisionItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        decisions: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessReviewInstanceDecisionItems"
        },
        stop: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    accessReviewStages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    acronym: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    activityBasedTimeoutPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    activityBasedTimeoutPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    activityHistoryItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activity: {
            returnType: "userActivity"
        },
    },
    activityHistoryItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    addLargeGalleryViewOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    admin: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        edge: {
            returnType: "edge"
        },
        sharepoint: {
            returnType: "sharepoint"
        },
        microsoft365Apps: {
            returnType: "adminMicrosoft365Apps"
        },
        serviceAnnouncement: {
            returnType: "serviceAnnouncement"
        },
        reportSettings: {
            returnType: "adminReportSettings"
        },
        people: {
            returnType: "peopleAdminSettings"
        },
    },
    adminConsentRequestPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    adminMicrosoft365Apps: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        installationOptions: {
            returnType: "m365AppsInstallationOptions"
        },
    },
    adminReportSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    administrativeUnit: {
        properties: [
            "members|directoryObjects|/[Name]|directoryObject", "scopedRoleMembers|scopedRoleMemberships|/[Name]|scopedRoleMembership", "extensions|extensions|/[Name]|extension"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        scopedRoleMembers: {
            requestType: utils_1.RequestType.Get,
            returnType: "scopedRoleMemberships"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
    },
    administrativeUnits: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    agreement: {
        properties: [
            "acceptances|agreementAcceptances|/[Name]|agreementAcceptance", "files|agreementFileLocalizations|/[Name]|agreementFileLocalization"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        acceptances: {
            requestType: utils_1.RequestType.Get,
            returnType: "agreementAcceptances"
        },
        file: {
            returnType: "agreementFile"
        },
        files: {
            requestType: utils_1.RequestType.Get,
            returnType: "agreementFileLocalizations"
        },
    },
    agreements: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    agreementAcceptance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    agreementAcceptances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    agreementFile: {
        properties: [
            "localizations|agreementFileLocalizations|/[Name]|agreementFileLocalization"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        localizations: {
            requestType: utils_1.RequestType.Get,
            returnType: "agreementFileLocalizations"
        },
    },
    agreementFileLocalization: {
        properties: [
            "versions|agreementFileVersions|/[Name]|agreementFileVersion"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        versions: {
            requestType: utils_1.RequestType.Get,
            returnType: "agreementFileVersions"
        },
    },
    agreementFileLocalizations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    agreementFileProperties: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    agreementFileVersion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    agreementFileVersions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    alert: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    alerts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    allowedValue: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    allowedValues: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidCompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidCustomConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidGeneralDeviceConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidLobApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidManagedAppProtection: {
        properties: [
            "apps|managedMobileApps|/[Name]|managedMobileApp"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        apps: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedMobileApps"
        },
        deploymentSummary: {
            returnType: "managedAppPolicyDeploymentSummary"
        },
    },
    androidManagedAppProtections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidManagedAppRegistration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidStoreApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidWorkProfileCompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidWorkProfileCustomConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    androidWorkProfileGeneralDeviceConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    anonymousGuestConversationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appCatalogs: {
        properties: [
            "teamsApps|teamsApps|/[Name]|teamsApp"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        teamsApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamsApps"
        },
    },
    appConsentApprovalRoute: {
        properties: [
            "appConsentRequests|appConsentRequests|/[Name]|appConsentRequest"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appConsentRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "appConsentRequests"
        },
    },
    appConsentRequest: {
        properties: [
            "userConsentRequests|userConsentRequests|/[Name]|userConsentRequest"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        userConsentRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "userConsentRequests"
        },
    },
    appConsentRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appLogCollectionRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        createDownloadUrl: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.appLogCollectionDownloadDetails"
        },
    },
    appLogCollectionRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appManagementPolicy: {
        properties: [
            "appliesTo|directoryObjects|/[Name]|directoryObject"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appliesTo: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
    },
    appManagementPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appRoleAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appRoleAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appScope: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appleDeviceFeaturesConfigurationBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    appleManagedIdentityProvider: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    applePushNotificationCertificate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        downloadApplePushNotificationCertificateSigningRequest: {
            requestType: utils_1.RequestType.Get,
            returnType: "string"
        },
    },
    application: {
        properties: [
            "appManagementPolicies|appManagementPolicys|/[Name]|appManagementPolicy", "extensionProperties|extensionPropertys|/[Name]|extensionProperty", "federatedIdentityCredentials|federatedIdentityCredentials|/[Name]|federatedIdentityCredential", "homeRealmDiscoveryPolicies|homeRealmDiscoveryPolicys|/[Name]|homeRealmDiscoveryPolicy", "owners|directoryObjects|/[Name]|directoryObject", "tokenIssuancePolicies|tokenIssuancePolicys|/[Name]|tokenIssuancePolicy", "tokenLifetimePolicies|tokenLifetimePolicys|/[Name]|tokenLifetimePolicy"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appManagementPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "appManagementPolicys"
        },
        createdOnBehalfOf: {
            returnType: "directoryObject"
        },
        extensionProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensionPropertys"
        },
        federatedIdentityCredentials: {
            requestType: utils_1.RequestType.Get,
            returnType: "federatedIdentityCredentials"
        },
        homeRealmDiscoveryPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "homeRealmDiscoveryPolicys"
        },
        owners: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        tokenIssuancePolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "tokenIssuancePolicys"
        },
        tokenLifetimePolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "tokenLifetimePolicys"
        },
        synchronization: {
            returnType: "synchronization"
        },
        setVerifiedPublisher: {
            argNames: ["verifiedPublisherId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unsetVerifiedPublisher: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        addKey: {
            argNames: ["keyCredential", "passwordCredential", "proof"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.keyCredential"
        },
        addPassword: {
            argNames: ["passwordCredential"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.passwordCredential"
        },
        removeKey: {
            argNames: ["keyId", "proof"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        removePassword: {
            argNames: ["keyId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    applicationTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        instantiate: {
            argNames: ["displayName", "serviceManagementReference"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.applicationServicePrincipal"
        },
    },
    approval: {
        properties: [
            "stages|approvalStages|/[Name]|approvalStage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        stages: {
            requestType: utils_1.RequestType.Get,
            returnType: "approvalStages"
        },
    },
    approvals: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    approvalStage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    approvalStages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    article: {
        properties: [
            "indicators|articleIndicators|/[Name]|articleIndicator"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        indicators: {
            requestType: utils_1.RequestType.Get,
            returnType: "articleIndicators"
        },
    },
    articleIndicator: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    artifact: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    associatedTeamInfo: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    associatedTeamInfos: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attachment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attachments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attachmentBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attachmentBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attachmentSession: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attachmentSessions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attackSimulationOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attackSimulationOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attackSimulationRoot: {
        properties: [
            "endUserNotifications|endUserNotifications|/[Name]|endUserNotification", "landingPages|landingPages|/[Name]|landingPage", "loginPages|loginPages|/[Name]|loginPage", "operations|attackSimulationOperations|/[Name]|attackSimulationOperation", "payloads|payloads|/[Name]|payload", "simulationAutomations|simulationAutomations|/[Name]|simulationAutomation", "simulations|simulations|/[Name]|simulation", "trainings|trainings|/[Name]|training"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        endUserNotifications: {
            requestType: utils_1.RequestType.Get,
            returnType: "endUserNotifications"
        },
        landingPages: {
            requestType: utils_1.RequestType.Get,
            returnType: "landingPages"
        },
        loginPages: {
            requestType: utils_1.RequestType.Get,
            returnType: "loginPages"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "attackSimulationOperations"
        },
        payloads: {
            requestType: utils_1.RequestType.Get,
            returnType: "payloads"
        },
        simulationAutomations: {
            requestType: utils_1.RequestType.Get,
            returnType: "simulationAutomations"
        },
        simulations: {
            requestType: utils_1.RequestType.Get,
            returnType: "simulations"
        },
        trainings: {
            requestType: utils_1.RequestType.Get,
            returnType: "trainings"
        },
    },
    attendanceRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attendanceRecords: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attributeMappingFunctionSchema: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attributeSet: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    attributeSets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    audioRoutingGroup: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    audioRoutingGroups: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    auditEvent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    auditEvents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    auditLogRoot: {
        properties: [
            "directoryAudits|directoryAudits|/[Name]|directoryAudit", "provisioning|provisioningObjectSummarys|/[Name]|provisioningObjectSummary", "signIns|signIns|/[Name]|signIn"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        directoryAudits: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryAudits"
        },
        provisioning: {
            requestType: utils_1.RequestType.Get,
            returnType: "provisioningObjectSummarys"
        },
        signIns: {
            requestType: utils_1.RequestType.Get,
            returnType: "signIns"
        },
    },
    authentication: {
        properties: [
            "emailMethods|emailAuthenticationMethods|/[Name]|emailAuthenticationMethod", "fido2Methods|fido2AuthenticationMethods|/[Name]|fido2AuthenticationMethod", "methods|authenticationMethods|/[Name]|authenticationMethod", "microsoftAuthenticatorMethods|microsoftAuthenticatorAuthenticationMethods|/[Name]|microsoftAuthenticatorAuthenticationMethod", "operations|longRunningOperations|/[Name]|longRunningOperation", "passwordMethods|passwordAuthenticationMethods|/[Name]|passwordAuthenticationMethod", "phoneMethods|phoneAuthenticationMethods|/[Name]|phoneAuthenticationMethod", "softwareOathMethods|softwareOathAuthenticationMethods|/[Name]|softwareOathAuthenticationMethod", "temporaryAccessPassMethods|temporaryAccessPassAuthenticationMethods|/[Name]|temporaryAccessPassAuthenticationMethod", "windowsHelloForBusinessMethods|windowsHelloForBusinessAuthenticationMethods|/[Name]|windowsHelloForBusinessAuthenticationMethod"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        emailMethods: {
            requestType: utils_1.RequestType.Get,
            returnType: "emailAuthenticationMethods"
        },
        fido2Methods: {
            requestType: utils_1.RequestType.Get,
            returnType: "fido2AuthenticationMethods"
        },
        methods: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethods"
        },
        microsoftAuthenticatorMethods: {
            requestType: utils_1.RequestType.Get,
            returnType: "microsoftAuthenticatorAuthenticationMethods"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "longRunningOperations"
        },
        passwordMethods: {
            requestType: utils_1.RequestType.Get,
            returnType: "passwordAuthenticationMethods"
        },
        phoneMethods: {
            requestType: utils_1.RequestType.Get,
            returnType: "phoneAuthenticationMethods"
        },
        softwareOathMethods: {
            requestType: utils_1.RequestType.Get,
            returnType: "softwareOathAuthenticationMethods"
        },
        temporaryAccessPassMethods: {
            requestType: utils_1.RequestType.Get,
            returnType: "temporaryAccessPassAuthenticationMethods"
        },
        windowsHelloForBusinessMethods: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsHelloForBusinessAuthenticationMethods"
        },
    },
    authenticationCombinationConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationCombinationConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationConditionApplication: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationContextClassReference: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationContextClassReferences: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationEventListener: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationEventListeners: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationEventsFlow: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationEventsFlows: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationFlowsPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resetPassword: {
            argNames: ["newPassword"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.passwordResetResponse"
        },
    },
    authenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethodConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethodConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethodModeDetail: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethodModeDetails: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethodTarget: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethodTargets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationMethodsPolicy: {
        properties: [
            "authenticationMethodConfigurations|authenticationMethodConfigurations|/[Name]|authenticationMethodConfiguration"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        authenticationMethodConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodConfigurations"
        },
    },
    authenticationMethodsRoot: {
        properties: [
            "userRegistrationDetails|userRegistrationDetailss|/[Name]|userRegistrationDetails"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        userRegistrationDetails: {
            requestType: utils_1.RequestType.Get,
            returnType: "userRegistrationDetailss"
        },
        usersRegisteredByFeature: {
            argNames: ["includedUserTypes", "includedUserRoles"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.userRegistrationFeatureSummary"
        },
        usersRegisteredByMethod: {
            argNames: ["includedUserTypes", "includedUserRoles"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.userRegistrationMethodSummary"
        },
    },
    authenticationStrengthPolicy: {
        properties: [
            "combinationConfigurations|authenticationCombinationConfigurations|/[Name]|authenticationCombinationConfiguration"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        combinationConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationCombinationConfigurations"
        },
        updateAllowedCombinations: {
            argNames: ["allowedCombinations"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.updateAllowedCombinationsResult"
        },
        usage: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.authenticationStrengthUsage"
        },
    },
    authenticationStrengthPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authenticationStrengthRoot: {
        properties: [
            "authenticationMethodModes|authenticationMethodModeDetails|/[Name]|authenticationMethodModeDetail", "policies|authenticationStrengthPolicys|/[Name]|authenticationStrengthPolicy"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        authenticationMethodModes: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodModeDetails"
        },
        policies: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationStrengthPolicys"
        },
    },
    authoredNote: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authoredNotes: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authorityTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    authorizationPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    azureCommunicationServicesUserConversationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    azureUsage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        billed: {
            returnType: "billedUsage"
        },
        unbilled: {
            returnType: "unbilledUsage"
        },
    },
    b2xIdentityUserFlow: {
        properties: [
            "identityProviders|identityProviders|/[Name]|identityProvider", "languages|userFlowLanguageConfigurations|/[Name]|userFlowLanguageConfiguration", "userAttributeAssignments|identityUserFlowAttributeAssignments|/[Name]|identityUserFlowAttributeAssignment", "userFlowIdentityProviders|identityProviderBases|/[Name]|identityProviderBase"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        identityProviders: {
            requestType: utils_1.RequestType.Get,
            returnType: "identityProviders"
        },
        languages: {
            requestType: utils_1.RequestType.Get,
            returnType: "userFlowLanguageConfigurations"
        },
        userAttributeAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "identityUserFlowAttributeAssignments"
        },
        userFlowIdentityProviders: {
            requestType: utils_1.RequestType.Get,
            returnType: "identityProviderBases"
        },
    },
    b2xIdentityUserFlows: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    backupRestoreRoot: {
        properties: [
            "driveInclusionRules|driveProtectionRules|/[Name]|driveProtectionRule", "driveProtectionUnits|driveProtectionUnits|/[Name]|driveProtectionUnit", "exchangeProtectionPolicies|exchangeProtectionPolicys|/[Name]|exchangeProtectionPolicy", "exchangeRestoreSessions|exchangeRestoreSessions|/[Name]|exchangeRestoreSession", "mailboxInclusionRules|mailboxProtectionRules|/[Name]|mailboxProtectionRule", "mailboxProtectionUnits|mailboxProtectionUnits|/[Name]|mailboxProtectionUnit", "oneDriveForBusinessProtectionPolicies|oneDriveForBusinessProtectionPolicys|/[Name]|oneDriveForBusinessProtectionPolicy", "oneDriveForBusinessRestoreSessions|oneDriveForBusinessRestoreSessions|/[Name]|oneDriveForBusinessRestoreSession", "protectionPolicies|protectionPolicyBases|/[Name]|protectionPolicyBase", "protectionUnits|protectionUnitBases|/[Name]|protectionUnitBase", "restorePoints|restorePoints|/[Name]|restorePoint", "restoreSessions|restoreSessionBases|/[Name]|restoreSessionBase", "serviceApps|serviceApps|/[Name]|serviceApp", "sharePointProtectionPolicies|sharePointProtectionPolicys|/[Name]|sharePointProtectionPolicy", "sharePointRestoreSessions|sharePointRestoreSessions|/[Name]|sharePointRestoreSession", "siteInclusionRules|siteProtectionRules|/[Name]|siteProtectionRule", "siteProtectionUnits|siteProtectionUnits|/[Name]|siteProtectionUnit"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        driveInclusionRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveProtectionRules"
        },
        driveProtectionUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveProtectionUnits"
        },
        exchangeProtectionPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "exchangeProtectionPolicys"
        },
        exchangeRestoreSessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "exchangeRestoreSessions"
        },
        mailboxInclusionRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "mailboxProtectionRules"
        },
        mailboxProtectionUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "mailboxProtectionUnits"
        },
        oneDriveForBusinessProtectionPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "oneDriveForBusinessProtectionPolicys"
        },
        oneDriveForBusinessRestoreSessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "oneDriveForBusinessRestoreSessions"
        },
        protectionPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "protectionPolicyBases"
        },
        protectionUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "protectionUnitBases"
        },
        restorePoints: {
            requestType: utils_1.RequestType.Get,
            returnType: "restorePoints"
        },
        restoreSessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "restoreSessionBases"
        },
        serviceApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "serviceApps"
        },
        sharePointProtectionPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "sharePointProtectionPolicys"
        },
        sharePointRestoreSessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "sharePointRestoreSessions"
        },
        siteInclusionRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "siteProtectionRules"
        },
        siteProtectionUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "siteProtectionUnits"
        },
        enable: {
            argNames: ["appOwnerTenantId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.serviceStatus"
        },
    },
    baseItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        createdByUser: {
            returnType: "user"
        },
        lastModifiedByUser: {
            returnType: "user"
        },
    },
    baseItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    baseItemVersion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    baseSitePage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    baseSitePages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    billedReconciliation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    billedUsage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    billing: {
        properties: [
            "manifests|manifests|/[Name]|manifest", "operations|operations|/[Name]|operation"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        manifests: {
            requestType: utils_1.RequestType.Get,
            returnType: "manifests"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "operations"
        },
        reconciliation: {
            returnType: "billingReconciliation"
        },
        usage: {
            returnType: "azureUsage"
        },
    },
    billingReconciliation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        billed: {
            returnType: "billedReconciliation"
        },
    },
    bitlocker: {
        properties: [
            "recoveryKeys|bitlockerRecoveryKeys|/[Name]|bitlockerRecoveryKey"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        recoveryKeys: {
            requestType: utils_1.RequestType.Get,
            returnType: "bitlockerRecoveryKeys"
        },
    },
    bitlockerRecoveryKey: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bitlockerRecoveryKeys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingAppointment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingAppointments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingBusiness: {
        properties: [
            "appointments|bookingAppointments|/[Name]|bookingAppointment", "calendarView|bookingAppointments|/[Name]|bookingAppointment", "customers|bookingCustomerBases|/[Name]|bookingCustomerBase", "customQuestions|bookingCustomQuestions|/[Name]|bookingCustomQuestion", "services|bookingServices|/[Name]|bookingService", "staffMembers|bookingStaffMemberBases|/[Name]|bookingStaffMemberBase"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appointments: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingAppointments"
        },
        calendarView: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingAppointments"
        },
        customers: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingCustomerBases"
        },
        customQuestions: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingCustomQuestions"
        },
        services: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingServices"
        },
        staffMembers: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingStaffMemberBases"
        },
    },
    bookingBusinesss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingCurrency: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingCurrencys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingCustomQuestion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingCustomQuestions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingCustomer: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingCustomerBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingCustomerBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingService: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingServices: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingStaffMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingStaffMemberBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookingStaffMemberBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bookmark: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    browserSharedCookie: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    browserSharedCookies: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    browserSite: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    browserSites: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    browserSiteList: {
        properties: [
            "sharedCookies|browserSharedCookies|/[Name]|browserSharedCookie", "sites|browserSites|/[Name]|browserSite"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        sharedCookies: {
            requestType: utils_1.RequestType.Get,
            returnType: "browserSharedCookies"
        },
        sites: {
            requestType: utils_1.RequestType.Get,
            returnType: "browserSites"
        },
        publish: {
            argNames: ["revision", "sites", "sharedCookies"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.browserSiteList"
        },
    },
    browserSiteLists: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    builtInIdentityProvider: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    bulkUpload: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    calendar: {
        properties: [
            "calendarPermissions|calendarPermissions|/[Name]|calendarPermission", "calendarView|events|/[Name]|event", "events|events|/[Name]|event", "multiValueExtendedProperties|multiValueLegacyExtendedPropertys|/[Name]|multiValueLegacyExtendedProperty", "singleValueExtendedProperties|singleValueLegacyExtendedPropertys|/[Name]|singleValueLegacyExtendedProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        calendarPermissions: {
            requestType: utils_1.RequestType.Get,
            returnType: "calendarPermissions"
        },
        calendarView: {
            requestType: utils_1.RequestType.Get,
            returnType: "events"
        },
        events: {
            requestType: utils_1.RequestType.Get,
            returnType: "events"
        },
        multiValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiValueLegacyExtendedPropertys"
        },
        singleValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "singleValueLegacyExtendedPropertys"
        },
        getSchedule: {
            argNames: ["Schedules", "EndTime", "StartTime", "AvailabilityViewInterval"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.scheduleInformation[]"
        },
    },
    calendars: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    calendarGroup: {
        properties: [
            "calendars|calendars|/[Name]|calendar"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        calendars: {
            requestType: utils_1.RequestType.Get,
            returnType: "calendars"
        },
    },
    calendarGroups: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    calendarPermission: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    calendarPermissions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    calendarSharingMessage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accept: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.calendar"
        },
    },
    call: {
        properties: [
            "audioRoutingGroups|audioRoutingGroups|/[Name]|audioRoutingGroup", "contentSharingSessions|contentSharingSessions|/[Name]|contentSharingSession", "operations|commsOperations|/[Name]|commsOperation", "participants|participants|/[Name]|participant"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        audioRoutingGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "audioRoutingGroups"
        },
        contentSharingSessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "contentSharingSessions"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "commsOperations"
        },
        participants: {
            requestType: utils_1.RequestType.Get,
            returnType: "participants"
        },
        redirect: {
            argNames: ["targets", "timeout", "callbackUri"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        addLargeGalleryView: {
            argNames: ["clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.addLargeGalleryViewOperation"
        },
        answer: {
            argNames: ["callbackUri", "mediaConfig", "acceptedModalities", "participantCapacity", "callOptions"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        cancelMediaProcessing: {
            argNames: ["clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.cancelMediaProcessingOperation"
        },
        changeScreenSharingRole: {
            argNames: ["role"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        keepAlive: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        mute: {
            argNames: ["clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.muteParticipantOperation"
        },
        playPrompt: {
            argNames: ["prompts", "clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.playPromptOperation"
        },
        recordResponse: {
            argNames: ["prompts", "bargeInAllowed", "initialSilenceTimeoutInSeconds", "maxSilenceTimeoutInSeconds", "maxRecordDurationInSeconds", "playBeep", "stopTones", "clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.recordOperation"
        },
        reject: {
            argNames: ["reason", "callbackUri"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        sendDtmfTones: {
            argNames: ["tones", "delayBetweenTonesMs", "clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.sendDtmfTonesOperation"
        },
        subscribeToTone: {
            argNames: ["clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.subscribeToToneOperation"
        },
        transfer: {
            argNames: ["transferTarget", "transferee"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unmute: {
            argNames: ["clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.unmuteParticipantOperation"
        },
        updateRecordingStatus: {
            argNames: ["status", "clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.updateRecordingStatusOperation"
        },
    },
    calls: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    callRecord: {
        properties: [
            "participants_v2|participants|/[Name]|participant", "sessions|sessions|/[Name]|session"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        organizer_v2: {
            returnType: "organizer"
        },
        participants_v2: {
            requestType: utils_1.RequestType.Get,
            returnType: "participants"
        },
        sessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "sessions"
        },
    },
    callRecording: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    callRecordings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    callTranscript: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    callTranscripts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cancelMediaProcessingOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    canvasLayout: {
        properties: [
            "horizontalSections|horizontalSections|/[Name]|horizontalSection"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        horizontalSections: {
            requestType: utils_1.RequestType.Get,
            returnType: "horizontalSections"
        },
        verticalSection: {
            returnType: "verticalSection"
        },
    },
    caseOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    casesRoot: {
        properties: [
            "ediscoveryCases|ediscoveryCases|/[Name]|ediscoveryCase"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        ediscoveryCases: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryCases"
        },
    },
    categoryTemplate: {
        properties: [
            "subcategories|subcategoryTemplates|/[Name]|subcategoryTemplate"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        subcategories: {
            requestType: utils_1.RequestType.Get,
            returnType: "subcategoryTemplates"
        },
    },
    certificateBasedAuthConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    certificateBasedAuthConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    changeTrackedEntity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        stageForDeletion: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    channel: {
        properties: [
            "members|conversationMembers|/[Name]|conversationMember", "messages|chatMessages|/[Name]|chatMessage", "sharedWithTeams|sharedWithChannelTeamInfos|/[Name]|sharedWithChannelTeamInfo", "tabs|teamsTabs|/[Name]|teamsTab"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        allMembers: {
            requestType: utils_1.RequestType.Get,
            returnType: "conversationMembers"
        },
        filesFolder: {
            returnType: "driveItem"
        },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "conversationMembers"
        },
        messages: {
            requestType: utils_1.RequestType.Get,
            returnType: "chatMessages"
        },
        sharedWithTeams: {
            requestType: utils_1.RequestType.Get,
            returnType: "sharedWithChannelTeamInfos"
        },
        tabs: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamsTabs"
        },
        archive: {
            argNames: ["shouldSetSpoSiteReadOnlyForMembers"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unarchive: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        completeMigration: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        provisionEmail: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.provisionChannelEmailResult"
        },
        removeEmail: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        doesUserHaveAccess: {
            argNames: ["userId", "tenantId", "userPrincipalName"],
            requestType: utils_1.RequestType.Get,
            returnType: "boolean"
        },
    },
    channels: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    chat: {
        properties: [
            "installedApps|teamsAppInstallations|/[Name]|teamsAppInstallation", "members|conversationMembers|/[Name]|conversationMember", "messages|chatMessages|/[Name]|chatMessage", "permissionGrants|resourceSpecificPermissionGrants|/[Name]|resourceSpecificPermissionGrant", "pinnedMessages|pinnedChatMessageInfos|/[Name]|pinnedChatMessageInfo", "tabs|teamsTabs|/[Name]|teamsTab"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        installedApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamsAppInstallations"
        },
        lastMessagePreview: {
            returnType: "chatMessageInfo"
        },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "conversationMembers"
        },
        messages: {
            requestType: utils_1.RequestType.Get,
            returnType: "chatMessages"
        },
        permissionGrants: {
            requestType: utils_1.RequestType.Get,
            returnType: "resourceSpecificPermissionGrants"
        },
        pinnedMessages: {
            requestType: utils_1.RequestType.Get,
            returnType: "pinnedChatMessageInfos"
        },
        tabs: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamsTabs"
        },
        sendActivityNotification: {
            argNames: ["topic", "activityType", "chainId", "previewText", "teamsAppId", "templateParameters", "recipient"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        hideForUser: {
            argNames: ["user"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        markChatReadForUser: {
            argNames: ["user"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        markChatUnreadForUser: {
            argNames: ["user", "lastMessageReadDateTime"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unhideForUser: {
            argNames: ["user"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    chats: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    chatMessage: {
        properties: [
            "hostedContents|chatMessageHostedContents|/[Name]|chatMessageHostedContent", "replies|chatMessages|/[Name]|chatMessage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        hostedContents: {
            requestType: utils_1.RequestType.Get,
            returnType: "chatMessageHostedContents"
        },
        replies: {
            requestType: utils_1.RequestType.Get,
            returnType: "chatMessages"
        },
        setReaction: {
            argNames: ["reactionType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        softDelete: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        undoSoftDelete: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unsetReaction: {
            argNames: ["reactionType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    chatMessages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    chatMessageHostedContent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    chatMessageHostedContents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    chatMessageInfo: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    checklistItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    checklistItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    citationTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    claimsMappingPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    claimsMappingPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudClipboardItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudClipboardItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudClipboardRoot: {
        properties: [
            "items|cloudClipboardItems|/[Name]|cloudClipboardItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        items: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudClipboardItems"
        },
    },
    cloudCommunications: {
        properties: [
            "callRecords|callRecords|/[Name]|callRecord", "calls|calls|/[Name]|call", "onlineMeetings|onlineMeetings|/[Name]|onlineMeeting", "presences|presences|/[Name]|presence"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        callRecords: {
            requestType: utils_1.RequestType.Get,
            returnType: "callRecords"
        },
        calls: {
            requestType: utils_1.RequestType.Get,
            returnType: "calls"
        },
        onlineMeetings: {
            requestType: utils_1.RequestType.Get,
            returnType: "onlineMeetings"
        },
        presences: {
            requestType: utils_1.RequestType.Get,
            returnType: "presences"
        },
        getPresencesByUserId: {
            argNames: ["ids"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.presence[]"
        },
    },
    cloudPC: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        endGracePeriod: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        reboot: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        rename: {
            argNames: ["displayName"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        restore: {
            argNames: ["cloudPcSnapshotId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        troubleshoot: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    cloudPCs: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcAuditEvent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcAuditEvents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcDeviceImage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcDeviceImages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcGalleryImage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcGalleryImages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcOnPremisesConnection: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        runHealthChecks: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    cloudPcOnPremisesConnections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcProvisioningPolicy: {
        properties: [
            "assignments|cloudPcProvisioningPolicyAssignments|/[Name]|cloudPcProvisioningPolicyAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcProvisioningPolicyAssignments"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    cloudPcProvisioningPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcProvisioningPolicyAssignment: {
        properties: [
            "assignedUsers|users|/[Name]|user"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignedUsers: {
            requestType: utils_1.RequestType.Get,
            returnType: "users"
        },
    },
    cloudPcProvisioningPolicyAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcUserSetting: {
        properties: [
            "assignments|cloudPcUserSettingAssignments|/[Name]|cloudPcUserSettingAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcUserSettingAssignments"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    cloudPcUserSettings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcUserSettingAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    cloudPcUserSettingAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    columnDefinition: {
        properties: [],
        delete: {
            name: "",
            requestType: utils_1.RequestType.GraphDelete
        },
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        sourceColumn: {
            returnType: "columnDefinition"
        },
        update: {
            argNames: ["values"],
            name: "",
            requestMethod: "PATCH",
            requestType: utils_1.RequestType.PostBodyNoArgs
        },
    },
    columnDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    columnLink: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    columnLinks: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    commsOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    commsOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    community: {
        properties: [
            "owners|users|/[Name]|user"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        group: {
            returnType: "group"
        },
        owners: {
            requestType: utils_1.RequestType.Get,
            returnType: "users"
        },
    },
    communitys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    companySubscription: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    companySubscriptions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    compliance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    complianceManagementPartner: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    complianceManagementPartners: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conditionalAccessPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conditionalAccessPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conditionalAccessRoot: {
        properties: [
            "authenticationContextClassReferences|authenticationContextClassReferences|/[Name]|authenticationContextClassReference", "namedLocations|namedLocations|/[Name]|namedLocation", "policies|conditionalAccessPolicys|/[Name]|conditionalAccessPolicy", "templates|conditionalAccessTemplates|/[Name]|conditionalAccessTemplate"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        authenticationStrength: {
            returnType: "authenticationStrengthRoot"
        },
        authenticationContextClassReferences: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationContextClassReferences"
        },
        namedLocations: {
            requestType: utils_1.RequestType.Get,
            returnType: "namedLocations"
        },
        policies: {
            requestType: utils_1.RequestType.Get,
            returnType: "conditionalAccessPolicys"
        },
        templates: {
            requestType: utils_1.RequestType.Get,
            returnType: "conditionalAccessTemplates"
        },
    },
    conditionalAccessTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conditionalAccessTemplates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    connectedOrganization: {
        properties: [
            "externalSponsors|directoryObjects|/[Name]|directoryObject", "internalSponsors|directoryObjects|/[Name]|directoryObject"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        externalSponsors: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        internalSponsors: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
    },
    connectedOrganizations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    connectionOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    contact: {
        properties: [
            "extensions|extensions|/[Name]|extension", "multiValueExtendedProperties|multiValueLegacyExtendedPropertys|/[Name]|multiValueLegacyExtendedProperty", "singleValueExtendedProperties|singleValueLegacyExtendedPropertys|/[Name]|singleValueLegacyExtendedProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        multiValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiValueLegacyExtendedPropertys"
        },
        photo: {
            returnType: "profilePhoto"
        },
        singleValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "singleValueLegacyExtendedPropertys"
        },
    },
    contacts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    contactFolder: {
        properties: [
            "childFolders|contactFolders|/[Name]|contactFolder", "contacts|contacts|/[Name]|contact", "multiValueExtendedProperties|multiValueLegacyExtendedPropertys|/[Name]|multiValueLegacyExtendedProperty", "singleValueExtendedProperties|singleValueLegacyExtendedPropertys|/[Name]|singleValueLegacyExtendedProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        childFolders: {
            requestType: utils_1.RequestType.Get,
            returnType: "contactFolders"
        },
        contacts: {
            requestType: utils_1.RequestType.Get,
            returnType: "contacts"
        },
        multiValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiValueLegacyExtendedPropertys"
        },
        singleValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "singleValueLegacyExtendedPropertys"
        },
    },
    contactFolders: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    contentSharingSession: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    contentSharingSessions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    contentType: {
        properties: [
            "baseTypes|contentTypes|/[Name]|contentType", "columnLinks|columnLinks|/[Name]|columnLink", "columnPositions|columnDefinitions|/[Name]|columnDefinition", "columns|columnDefinitions|/[Name]|columnDefinition"
        ],
        delete: {
            name: "",
            requestType: utils_1.RequestType.GraphDelete
        },
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        base: {
            returnType: "contentType"
        },
        baseTypes: {
            requestType: utils_1.RequestType.Get,
            returnType: "contentTypes"
        },
        columnLinks: {
            requestType: utils_1.RequestType.Get,
            returnType: "columnLinks"
        },
        columnPositions: {
            requestType: utils_1.RequestType.Get,
            returnType: "columnDefinitions"
        },
        columns: {
            requestType: utils_1.RequestType.Get,
            returnType: "columnDefinitions"
        },
        update: {
            argNames: ["values"],
            name: "",
            requestMethod: "PATCH",
            requestType: utils_1.RequestType.PostBodyNoArgs
        },
        publish: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unpublish: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        associateWithHubSites: {
            argNames: ["hubSiteUrls", "propagateToExistingLists"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        copyToDefaultContentLocation: {
            argNames: ["sourceFile", "destinationFileName"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        isPublished: {
            requestType: utils_1.RequestType.Get,
            returnType: "boolean"
        },
    },
    contentTypes: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    contract: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conversation: {
        properties: [
            "threads|conversationThreads|/[Name]|conversationThread"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        threads: {
            requestType: utils_1.RequestType.Get,
            returnType: "conversationThreads"
        },
    },
    conversations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conversationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conversationMembers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    conversationThread: {
        properties: [
            "posts|posts|/[Name]|post"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        posts: {
            requestType: utils_1.RequestType.Get,
            returnType: "posts"
        },
        reply: {
            argNames: ["Post"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    conversationThreads: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    countryNamedLocation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    crossTenantAccessPolicy: {
        properties: [
            "partners|crossTenantAccessPolicyConfigurationPartners|/[Name]|crossTenantAccessPolicyConfigurationPartner"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        default: {
            returnType: "crossTenantAccessPolicyConfigurationDefault"
        },
        partners: {
            requestType: utils_1.RequestType.Get,
            returnType: "crossTenantAccessPolicyConfigurationPartners"
        },
        templates: {
            returnType: "policyTemplate"
        },
    },
    crossTenantAccessPolicyConfigurationDefault: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resetToSystemDefault: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    crossTenantAccessPolicyConfigurationPartner: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        identitySynchronization: {
            returnType: "crossTenantIdentitySyncPolicyPartner"
        },
    },
    crossTenantIdentitySyncPolicyPartner: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    customAuthenticationExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        validateAuthenticationConfiguration: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.authenticationConfigurationValidation"
        },
    },
    customAuthenticationExtensions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    customCalloutExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    customCalloutExtensions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    customExtensionStageSetting: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        customExtension: {
            returnType: "customCalloutExtension"
        },
    },
    customExtensionStageSettings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    customSecurityAttributeDefinition: {
        properties: [
            "allowedValues|allowedValues|/[Name]|allowedValue"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        allowedValues: {
            requestType: utils_1.RequestType.Get,
            returnType: "allowedValues"
        },
    },
    customSecurityAttributeDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    customTaskExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        createdBy: {
            returnType: "user"
        },
        lastModifiedBy: {
            returnType: "user"
        },
    },
    dataPolicyOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    dataSet: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    dataSource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    dataSourceContainer: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    dayNote: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    dayNotes: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    defaultManagedAppProtection: {
        properties: [
            "apps|managedMobileApps|/[Name]|managedMobileApp"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        apps: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedMobileApps"
        },
        deploymentSummary: {
            returnType: "managedAppPolicyDeploymentSummary"
        },
    },
    defaultManagedAppProtections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminAccessAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminAccessAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminCustomer: {
        properties: [
            "serviceManagementDetails|delegatedAdminServiceManagementDetails|/[Name]|delegatedAdminServiceManagementDetail"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        serviceManagementDetails: {
            requestType: utils_1.RequestType.Get,
            returnType: "delegatedAdminServiceManagementDetails"
        },
    },
    delegatedAdminCustomers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminRelationship: {
        properties: [
            "accessAssignments|delegatedAdminAccessAssignments|/[Name]|delegatedAdminAccessAssignment", "operations|delegatedAdminRelationshipOperations|/[Name]|delegatedAdminRelationshipOperation", "requests|delegatedAdminRelationshipRequests|/[Name]|delegatedAdminRelationshipRequest"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accessAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "delegatedAdminAccessAssignments"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "delegatedAdminRelationshipOperations"
        },
        requests: {
            requestType: utils_1.RequestType.Get,
            returnType: "delegatedAdminRelationshipRequests"
        },
    },
    delegatedAdminRelationships: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminRelationshipOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminRelationshipOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminRelationshipRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminRelationshipRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminServiceManagementDetail: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedAdminServiceManagementDetails: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedPermissionClassification: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    delegatedPermissionClassifications: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deletedChat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        undoDelete: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    deletedChats: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deletedItemContainer: {
        properties: [
            "workflows|workflows|/[Name]|workflow"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        workflows: {
            requestType: utils_1.RequestType.Get,
            returnType: "workflows"
        },
    },
    deletedTeam: {
        properties: [
            "channels|channels|/[Name]|channel"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        channels: {
            requestType: utils_1.RequestType.Get,
            returnType: "channels"
        },
    },
    deletedTeams: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deltaParticipants: {
        properties: [
            "participants|participants|/[Name]|participant"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        participants: {
            requestType: utils_1.RequestType.Get,
            returnType: "participants"
        },
    },
    departmentTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    detectedApp: {
        properties: [
            "managedDevices|managedDevices|/[Name]|managedDevice"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        managedDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedDevices"
        },
    },
    detectedApps: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    device: {
        properties: [
            "memberOf|directoryObjects|/[Name]|directoryObject", "registeredOwners|directoryObjects|/[Name]|directoryObject", "registeredUsers|directoryObjects|/[Name]|directoryObject", "transitiveMemberOf|directoryObjects|/[Name]|directoryObject", "extensions|extensions|/[Name]|extension"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        memberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        registeredOwners: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        registeredUsers: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        transitiveMemberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
    },
    deviceAndAppManagementRoleAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceAndAppManagementRoleAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceAndAppManagementRoleDefinition: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceAppManagement: {
        properties: [
            "managedEBooks|managedEBooks|/[Name]|managedEBook", "mobileAppCategories|mobileAppCategorys|/[Name]|mobileAppCategory", "mobileAppConfigurations|managedDeviceMobileAppConfigurations|/[Name]|managedDeviceMobileAppConfiguration", "mobileApps|mobileApps|/[Name]|mobileApp", "vppTokens|vppTokens|/[Name]|vppToken", "androidManagedAppProtections|androidManagedAppProtections|/[Name]|androidManagedAppProtection", "defaultManagedAppProtections|defaultManagedAppProtections|/[Name]|defaultManagedAppProtection", "iosManagedAppProtections|iosManagedAppProtections|/[Name]|iosManagedAppProtection", "managedAppPolicies|managedAppPolicys|/[Name]|managedAppPolicy", "managedAppRegistrations|managedAppRegistrations|/[Name]|managedAppRegistration", "managedAppStatuses|managedAppStatuss|/[Name]|managedAppStatus", "mdmWindowsInformationProtectionPolicies|mdmWindowsInformationProtectionPolicys|/[Name]|mdmWindowsInformationProtectionPolicy", "targetedManagedAppConfigurations|targetedManagedAppConfigurations|/[Name]|targetedManagedAppConfiguration", "windowsInformationProtectionPolicies|windowsInformationProtectionPolicys|/[Name]|windowsInformationProtectionPolicy"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        managedEBooks: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedEBooks"
        },
        mobileAppCategories: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileAppCategorys"
        },
        mobileAppConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedDeviceMobileAppConfigurations"
        },
        mobileApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileApps"
        },
        vppTokens: {
            requestType: utils_1.RequestType.Get,
            returnType: "vppTokens"
        },
        androidManagedAppProtections: {
            requestType: utils_1.RequestType.Get,
            returnType: "androidManagedAppProtections"
        },
        defaultManagedAppProtections: {
            requestType: utils_1.RequestType.Get,
            returnType: "defaultManagedAppProtections"
        },
        iosManagedAppProtections: {
            requestType: utils_1.RequestType.Get,
            returnType: "iosManagedAppProtections"
        },
        managedAppPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedAppPolicys"
        },
        managedAppRegistrations: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedAppRegistrations"
        },
        managedAppStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedAppStatuss"
        },
        mdmWindowsInformationProtectionPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "mdmWindowsInformationProtectionPolicys"
        },
        targetedManagedAppConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "targetedManagedAppConfigurations"
        },
        windowsInformationProtectionPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsInformationProtectionPolicys"
        },
        syncMicrosoftStoreForBusinessApps: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    deviceCategory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCategorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceActionItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceActionItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceDeviceOverview: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceDeviceStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceDeviceStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCompliancePolicy: {
        properties: [
            "assignments|deviceCompliancePolicyAssignments|/[Name]|deviceCompliancePolicyAssignment", "deviceSettingStateSummaries|settingStateDeviceSummarys|/[Name]|settingStateDeviceSummary", "deviceStatuses|deviceComplianceDeviceStatuss|/[Name]|deviceComplianceDeviceStatus", "scheduledActionsForRule|deviceComplianceScheduledActionForRules|/[Name]|deviceComplianceScheduledActionForRule", "userStatuses|deviceComplianceUserStatuss|/[Name]|deviceComplianceUserStatus"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceCompliancePolicyAssignments"
        },
        deviceSettingStateSummaries: {
            requestType: utils_1.RequestType.Get,
            returnType: "settingStateDeviceSummarys"
        },
        deviceStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceComplianceDeviceStatuss"
        },
        deviceStatusOverview: {
            returnType: "deviceComplianceDeviceOverview"
        },
        scheduledActionsForRule: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceComplianceScheduledActionForRules"
        },
        userStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceComplianceUserStatuss"
        },
        userStatusOverview: {
            returnType: "deviceComplianceUserOverview"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.deviceCompliancePolicyAssignment[]"
        },
        scheduleActionsForRules: {
            argNames: ["deviceComplianceScheduledActionForRules"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    deviceCompliancePolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCompliancePolicyAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCompliancePolicyAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCompliancePolicyDeviceStateSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCompliancePolicySettingStateSummary: {
        properties: [
            "deviceComplianceSettingStates|deviceComplianceSettingStates|/[Name]|deviceComplianceSettingState"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        deviceComplianceSettingStates: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceComplianceSettingStates"
        },
    },
    deviceCompliancePolicySettingStateSummarys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCompliancePolicyState: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceCompliancePolicyStates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceScheduledActionForRule: {
        properties: [
            "scheduledActionConfigurations|deviceComplianceActionItems|/[Name]|deviceComplianceActionItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        scheduledActionConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceComplianceActionItems"
        },
    },
    deviceComplianceScheduledActionForRules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceSettingState: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceSettingStates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceUserOverview: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceUserStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceComplianceUserStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfiguration: {
        properties: [
            "assignments|deviceConfigurationAssignments|/[Name]|deviceConfigurationAssignment", "deviceSettingStateSummaries|settingStateDeviceSummarys|/[Name]|settingStateDeviceSummary", "deviceStatuses|deviceConfigurationDeviceStatuss|/[Name]|deviceConfigurationDeviceStatus", "userStatuses|deviceConfigurationUserStatuss|/[Name]|deviceConfigurationUserStatus"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceConfigurationAssignments"
        },
        deviceSettingStateSummaries: {
            requestType: utils_1.RequestType.Get,
            returnType: "settingStateDeviceSummarys"
        },
        deviceStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceConfigurationDeviceStatuss"
        },
        deviceStatusOverview: {
            returnType: "deviceConfigurationDeviceOverview"
        },
        userStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceConfigurationUserStatuss"
        },
        userStatusOverview: {
            returnType: "deviceConfigurationUserOverview"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.deviceConfigurationAssignment[]"
        },
        getOmaSettingPlainTextValue: {
            argNames: ["secretReferenceValueId"],
            requestType: utils_1.RequestType.Get,
            returnType: "string"
        },
    },
    deviceConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationDeviceOverview: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationDeviceStateSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationDeviceStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationDeviceStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationState: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationStates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationUserOverview: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationUserStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceConfigurationUserStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceEnrollmentConfiguration: {
        properties: [
            "assignments|enrollmentConfigurationAssignments|/[Name]|enrollmentConfigurationAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "enrollmentConfigurationAssignments"
        },
        assign: {
            argNames: ["enrollmentConfigurationAssignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        setPriority: {
            argNames: ["priority"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    deviceEnrollmentConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceEnrollmentLimitConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceEnrollmentPlatformRestrictionsConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceEnrollmentWindowsHelloForBusinessConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceInstallState: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceInstallStates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceLocalCredentialInfo: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceLocalCredentialInfos: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceLogCollectionResponse: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        createDownloadUrl: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "string"
        },
    },
    deviceLogCollectionResponses: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceManagement: {
        properties: [
            "auditEvents|auditEvents|/[Name]|auditEvent", "termsAndConditions|termsAndConditionss|/[Name]|termsAndConditions", "deviceCompliancePolicies|deviceCompliancePolicys|/[Name]|deviceCompliancePolicy", "deviceCompliancePolicySettingStateSummaries|deviceCompliancePolicySettingStateSummarys|/[Name]|deviceCompliancePolicySettingStateSummary", "deviceConfigurations|deviceConfigurations|/[Name]|deviceConfiguration", "iosUpdateStatuses|iosUpdateDeviceStatuss|/[Name]|iosUpdateDeviceStatus", "complianceManagementPartners|complianceManagementPartners|/[Name]|complianceManagementPartner", "deviceCategories|deviceCategorys|/[Name]|deviceCategory", "deviceEnrollmentConfigurations|deviceEnrollmentConfigurations|/[Name]|deviceEnrollmentConfiguration", "deviceManagementPartners|deviceManagementPartners|/[Name]|deviceManagementPartner", "exchangeConnectors|deviceManagementExchangeConnectors|/[Name]|deviceManagementExchangeConnector", "mobileThreatDefenseConnectors|mobileThreatDefenseConnectors|/[Name]|mobileThreatDefenseConnector", "detectedApps|detectedApps|/[Name]|detectedApp", "managedDevices|managedDevices|/[Name]|managedDevice", "mobileAppTroubleshootingEvents|mobileAppTroubleshootingEvents|/[Name]|mobileAppTroubleshootingEvent", "userExperienceAnalyticsAppHealthApplicationPerformance|userExperienceAnalyticsAppHealthApplicationPerformances|/[Name]|userExperienceAnalyticsAppHealthApplicationPerformance", "userExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDetails|userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDetailss|/[Name]|userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDetails", "userExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDeviceId|userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDeviceIds|/[Name]|userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDeviceId", "userExperienceAnalyticsAppHealthApplicationPerformanceByOSVersion|userExperienceAnalyticsAppHealthAppPerformanceByOSVersions|/[Name]|userExperienceAnalyticsAppHealthAppPerformanceByOSVersion", "userExperienceAnalyticsAppHealthDeviceModelPerformance|userExperienceAnalyticsAppHealthDeviceModelPerformances|/[Name]|userExperienceAnalyticsAppHealthDeviceModelPerformance", "userExperienceAnalyticsAppHealthDevicePerformance|userExperienceAnalyticsAppHealthDevicePerformances|/[Name]|userExperienceAnalyticsAppHealthDevicePerformance", "userExperienceAnalyticsAppHealthDevicePerformanceDetails|userExperienceAnalyticsAppHealthDevicePerformanceDetailss|/[Name]|userExperienceAnalyticsAppHealthDevicePerformanceDetails", "userExperienceAnalyticsAppHealthOSVersionPerformance|userExperienceAnalyticsAppHealthOSVersionPerformances|/[Name]|userExperienceAnalyticsAppHealthOSVersionPerformance", "userExperienceAnalyticsBaselines|userExperienceAnalyticsBaselines|/[Name]|userExperienceAnalyticsBaseline", "userExperienceAnalyticsCategories|userExperienceAnalyticsCategorys|/[Name]|userExperienceAnalyticsCategory", "userExperienceAnalyticsDevicePerformance|userExperienceAnalyticsDevicePerformances|/[Name]|userExperienceAnalyticsDevicePerformance", "userExperienceAnalyticsDeviceScores|userExperienceAnalyticsDeviceScoress|/[Name]|userExperienceAnalyticsDeviceScores", "userExperienceAnalyticsDeviceStartupHistory|userExperienceAnalyticsDeviceStartupHistorys|/[Name]|userExperienceAnalyticsDeviceStartupHistory", "userExperienceAnalyticsDeviceStartupProcesses|userExperienceAnalyticsDeviceStartupProcesss|/[Name]|userExperienceAnalyticsDeviceStartupProcess", "userExperienceAnalyticsDeviceStartupProcessPerformance|userExperienceAnalyticsDeviceStartupProcessPerformances|/[Name]|userExperienceAnalyticsDeviceStartupProcessPerformance", "userExperienceAnalyticsMetricHistory|userExperienceAnalyticsMetricHistorys|/[Name]|userExperienceAnalyticsMetricHistory", "userExperienceAnalyticsModelScores|userExperienceAnalyticsModelScoress|/[Name]|userExperienceAnalyticsModelScores", "userExperienceAnalyticsScoreHistory|userExperienceAnalyticsScoreHistorys|/[Name]|userExperienceAnalyticsScoreHistory", "userExperienceAnalyticsWorkFromAnywhereMetrics|userExperienceAnalyticsWorkFromAnywhereMetrics|/[Name]|userExperienceAnalyticsWorkFromAnywhereMetric", "userExperienceAnalyticsWorkFromAnywhereModelPerformance|userExperienceAnalyticsWorkFromAnywhereModelPerformances|/[Name]|userExperienceAnalyticsWorkFromAnywhereModelPerformance", "windowsMalwareInformation|windowsMalwareInformations|/[Name]|windowsMalwareInformation", "importedWindowsAutopilotDeviceIdentities|importedWindowsAutopilotDeviceIdentitys|/[Name]|importedWindowsAutopilotDeviceIdentity", "windowsAutopilotDeviceIdentities|windowsAutopilotDeviceIdentitys|/[Name]|windowsAutopilotDeviceIdentity", "notificationMessageTemplates|notificationMessageTemplates|/[Name]|notificationMessageTemplate", "resourceOperations|resourceOperations|/[Name]|resourceOperation", "roleAssignments|deviceAndAppManagementRoleAssignments|/[Name]|deviceAndAppManagementRoleAssignment", "roleDefinitions|roleDefinitions|/[Name]|roleDefinition", "remoteAssistancePartners|remoteAssistancePartners|/[Name]|remoteAssistancePartner", "telecomExpenseManagementPartners|telecomExpenseManagementPartners|/[Name]|telecomExpenseManagementPartner", "troubleshootingEvents|deviceManagementTroubleshootingEvents|/[Name]|deviceManagementTroubleshootingEvent", "windowsInformationProtectionAppLearningSummaries|windowsInformationProtectionAppLearningSummarys|/[Name]|windowsInformationProtectionAppLearningSummary", "windowsInformationProtectionNetworkLearningSummaries|windowsInformationProtectionNetworkLearningSummarys|/[Name]|windowsInformationProtectionNetworkLearningSummary"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        auditEvents: {
            requestType: utils_1.RequestType.Get,
            returnType: "auditEvents"
        },
        virtualEndpoint: {
            returnType: "virtualEndpoint"
        },
        termsAndConditions: {
            requestType: utils_1.RequestType.Get,
            returnType: "termsAndConditionss"
        },
        deviceCompliancePolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceCompliancePolicys"
        },
        deviceCompliancePolicyDeviceStateSummary: {
            returnType: "deviceCompliancePolicyDeviceStateSummary"
        },
        deviceCompliancePolicySettingStateSummaries: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceCompliancePolicySettingStateSummarys"
        },
        deviceConfigurationDeviceStateSummaries: {
            returnType: "deviceConfigurationDeviceStateSummary"
        },
        deviceConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceConfigurations"
        },
        iosUpdateStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "iosUpdateDeviceStatuss"
        },
        softwareUpdateStatusSummary: {
            returnType: "softwareUpdateStatusSummary"
        },
        complianceManagementPartners: {
            requestType: utils_1.RequestType.Get,
            returnType: "complianceManagementPartners"
        },
        conditionalAccessSettings: {
            returnType: "onPremisesConditionalAccessSettings"
        },
        deviceCategories: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceCategorys"
        },
        deviceEnrollmentConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceEnrollmentConfigurations"
        },
        deviceManagementPartners: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceManagementPartners"
        },
        exchangeConnectors: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceManagementExchangeConnectors"
        },
        mobileThreatDefenseConnectors: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileThreatDefenseConnectors"
        },
        applePushNotificationCertificate: {
            returnType: "applePushNotificationCertificate"
        },
        detectedApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "detectedApps"
        },
        managedDeviceOverview: {
            returnType: "managedDeviceOverview"
        },
        managedDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedDevices"
        },
        mobileAppTroubleshootingEvents: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileAppTroubleshootingEvents"
        },
        userExperienceAnalyticsAppHealthApplicationPerformance: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthApplicationPerformances"
        },
        userExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDetails: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDetailss"
        },
        userExperienceAnalyticsAppHealthApplicationPerformanceByAppVersionDeviceId: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDeviceIds"
        },
        userExperienceAnalyticsAppHealthApplicationPerformanceByOSVersion: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthAppPerformanceByOSVersions"
        },
        userExperienceAnalyticsAppHealthDeviceModelPerformance: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthDeviceModelPerformances"
        },
        userExperienceAnalyticsAppHealthDevicePerformance: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthDevicePerformances"
        },
        userExperienceAnalyticsAppHealthDevicePerformanceDetails: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthDevicePerformanceDetailss"
        },
        userExperienceAnalyticsAppHealthOSVersionPerformance: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsAppHealthOSVersionPerformances"
        },
        userExperienceAnalyticsAppHealthOverview: {
            returnType: "userExperienceAnalyticsCategory"
        },
        userExperienceAnalyticsBaselines: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsBaselines"
        },
        userExperienceAnalyticsCategories: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsCategorys"
        },
        userExperienceAnalyticsDevicePerformance: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsDevicePerformances"
        },
        userExperienceAnalyticsDeviceScores: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsDeviceScoress"
        },
        userExperienceAnalyticsDeviceStartupHistory: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsDeviceStartupHistorys"
        },
        userExperienceAnalyticsDeviceStartupProcesses: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsDeviceStartupProcesss"
        },
        userExperienceAnalyticsDeviceStartupProcessPerformance: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsDeviceStartupProcessPerformances"
        },
        userExperienceAnalyticsMetricHistory: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsMetricHistorys"
        },
        userExperienceAnalyticsModelScores: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsModelScoress"
        },
        userExperienceAnalyticsOverview: {
            returnType: "userExperienceAnalyticsOverview"
        },
        userExperienceAnalyticsScoreHistory: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsScoreHistorys"
        },
        userExperienceAnalyticsWorkFromAnywhereHardwareReadinessMetric: {
            returnType: "userExperienceAnalyticsWorkFromAnywhereHardwareReadinessMetric"
        },
        userExperienceAnalyticsWorkFromAnywhereMetrics: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsWorkFromAnywhereMetrics"
        },
        userExperienceAnalyticsWorkFromAnywhereModelPerformance: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsWorkFromAnywhereModelPerformances"
        },
        windowsMalwareInformation: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsMalwareInformations"
        },
        importedWindowsAutopilotDeviceIdentities: {
            requestType: utils_1.RequestType.Get,
            returnType: "importedWindowsAutopilotDeviceIdentitys"
        },
        windowsAutopilotDeviceIdentities: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsAutopilotDeviceIdentitys"
        },
        notificationMessageTemplates: {
            requestType: utils_1.RequestType.Get,
            returnType: "notificationMessageTemplates"
        },
        resourceOperations: {
            requestType: utils_1.RequestType.Get,
            returnType: "resourceOperations"
        },
        roleAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceAndAppManagementRoleAssignments"
        },
        roleDefinitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "roleDefinitions"
        },
        remoteAssistancePartners: {
            requestType: utils_1.RequestType.Get,
            returnType: "remoteAssistancePartners"
        },
        reports: {
            returnType: "deviceManagementReports"
        },
        telecomExpenseManagementPartners: {
            requestType: utils_1.RequestType.Get,
            returnType: "telecomExpenseManagementPartners"
        },
        troubleshootingEvents: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceManagementTroubleshootingEvents"
        },
        windowsInformationProtectionAppLearningSummaries: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsInformationProtectionAppLearningSummarys"
        },
        windowsInformationProtectionNetworkLearningSummaries: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsInformationProtectionNetworkLearningSummarys"
        },
        verifyWindowsEnrollmentAutoDiscovery: {
            argNames: ["domainName"],
            requestType: utils_1.RequestType.Get,
            returnType: "boolean"
        },
        userExperienceAnalyticsSummarizeWorkFromAnywhereDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.userExperienceAnalyticsWorkFromAnywhereDevicesSummary"
        },
        getEffectivePermissions: {
            argNames: ["scope"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.rolePermission[]"
        },
    },
    deviceManagementCachedReportConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceManagementExchangeConnector: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        sync: {
            argNames: ["syncType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    deviceManagementExchangeConnectors: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceManagementExportJob: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceManagementExportJobs: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceManagementPartner: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        terminate: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    deviceManagementPartners: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceManagementReports: {
        properties: [
            "exportJobs|deviceManagementExportJobs|/[Name]|deviceManagementExportJob"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        exportJobs: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceManagementExportJobs"
        },
        retrieveDeviceAppInstallationStatusReport: {
            argNames: ["name", "select", "search", "groupBy", "orderBy", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getCachedReport: {
            argNames: ["id", "select", "groupBy", "orderBy", "search", "skip", "top"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getCompliancePolicyNonComplianceReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getCompliancePolicyNonComplianceSummaryReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getComplianceSettingNonComplianceReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getConfigurationPolicyNonComplianceReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getConfigurationPolicyNonComplianceSummaryReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getConfigurationSettingNonComplianceReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getDeviceManagementIntentPerSettingContributingProfiles: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getDeviceManagementIntentSettingsReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getDeviceNonComplianceReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getDevicesWithoutCompliancePolicyReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getHistoricalReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getNoncompliantDevicesAndSettingsReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getPolicyNonComplianceMetadata: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getPolicyNonComplianceReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getPolicyNonComplianceSummaryReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getReportFilters: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
        getSettingNonComplianceReport: {
            argNames: ["name", "select", "groupBy", "orderBy", "search", "skip", "top", "sessionId", "filter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "any"
        },
    },
    deviceManagementTroubleshootingEvent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceManagementTroubleshootingEvents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    deviceRegistrationPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    directory: {
        properties: [
            "deviceLocalCredentials|deviceLocalCredentialInfos|/[Name]|deviceLocalCredentialInfo", "administrativeUnits|administrativeUnits|/[Name]|administrativeUnit", "attributeSets|attributeSets|/[Name]|attributeSet", "customSecurityAttributeDefinitions|customSecurityAttributeDefinitions|/[Name]|customSecurityAttributeDefinition", "deletedItems|directoryObjects|/[Name]|directoryObject", "federationConfigurations|identityProviderBases|/[Name]|identityProviderBase", "onPremisesSynchronization|onPremisesDirectorySynchronizations|/[Name]|onPremisesDirectorySynchronization", "subscriptions|companySubscriptions|/[Name]|companySubscription"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        deviceLocalCredentials: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceLocalCredentialInfos"
        },
        administrativeUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "administrativeUnits"
        },
        attributeSets: {
            requestType: utils_1.RequestType.Get,
            returnType: "attributeSets"
        },
        customSecurityAttributeDefinitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "customSecurityAttributeDefinitions"
        },
        deletedItems: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        federationConfigurations: {
            requestType: utils_1.RequestType.Get,
            returnType: "identityProviderBases"
        },
        onPremisesSynchronization: {
            requestType: utils_1.RequestType.Get,
            returnType: "onPremisesDirectorySynchronizations"
        },
        subscriptions: {
            requestType: utils_1.RequestType.Get,
            returnType: "companySubscriptions"
        },
    },
    directoryAudit: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    directoryAudits: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    directoryDefinition: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        discover: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.directoryDefinition"
        },
    },
    directoryDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    directoryObject: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        restore: {
            argNames: ["autoReconcileProxyConflict"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.directoryObject"
        },
        checkMemberGroups: {
            argNames: ["groupIds"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "Array<string>[]"
        },
        checkMemberObjects: {
            argNames: ["ids"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "Array<string>[]"
        },
        getMemberGroups: {
            argNames: ["securityEnabledOnly"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "Array<string>[]"
        },
        getMemberObjects: {
            argNames: ["securityEnabledOnly"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "Array<string>[]"
        },
    },
    directoryObjects: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    directoryObjectPartnerReference: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    directoryRole: {
        properties: [
            "members|directoryObjects|/[Name]|directoryObject", "scopedMembers|scopedRoleMemberships|/[Name]|scopedRoleMembership"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        scopedMembers: {
            requestType: utils_1.RequestType.Get,
            returnType: "scopedRoleMemberships"
        },
    },
    directoryRoleTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    dispositionReviewStage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    documentSetVersion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        restore: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    documentSetVersions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    domain: {
        properties: [
            "domainNameReferences|directoryObjects|/[Name]|directoryObject", "federationConfiguration|internalDomainFederations|/[Name]|internalDomainFederation", "serviceConfigurationRecords|domainDnsRecords|/[Name]|domainDnsRecord", "verificationDnsRecords|domainDnsRecords|/[Name]|domainDnsRecord"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        domainNameReferences: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        federationConfiguration: {
            requestType: utils_1.RequestType.Get,
            returnType: "internalDomainFederations"
        },
        rootDomain: {
            returnType: "domain"
        },
        serviceConfigurationRecords: {
            requestType: utils_1.RequestType.Get,
            returnType: "domainDnsRecords"
        },
        verificationDnsRecords: {
            requestType: utils_1.RequestType.Get,
            returnType: "domainDnsRecords"
        },
        forceDelete: {
            argNames: ["disableUserAccounts"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        promote: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "boolean"
        },
        verify: {
            argNames: ["forceTakeover"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.domain"
        },
    },
    domainDnsCnameRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    domainDnsMxRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    domainDnsRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    domainDnsRecords: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    domainDnsSrvRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    domainDnsTxtRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    domainDnsUnavailableRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    drive: {
        properties: [
            "bundles|driveItems|/[Name]|driveItem", "following|driveItems|/[Name]|driveItem", "items|driveItems|/[Name]|driveItem", "special|driveItems|/[Name]|driveItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        bundles: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveItems"
        },
        following: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveItems"
        },
        getFolder: {
            argNames: ["folderUrl"],
            name: "root:/[[folderUrl]]:",
            requestType: utils_1.RequestType.GraphGetReplace,
            returnType: "driveItem"
        },
        items: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveItems"
        },
        list: {
            returnType: "list"
        },
        root: {
            returnType: "driveItem"
        },
        special: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveItems"
        },
        search: {
            argNames: ["q"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.driveItem[]"
        },
        recent: {
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.driveItem[]"
        },
        sharedWithMe: {
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.driveItem[]"
        },
    },
    drives: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveItem: {
        properties: [
            "children|driveItems|/[Name]|driveItem", "permissions|permissions|/[Name]|permission", "subscriptions|subscriptions|/[Name]|subscription", "thumbnails|thumbnailSets|/[Name]|thumbnailSet", "versions|driveItemVersions|/[Name]|driveItemVersion"
        ],
        delete: {
            name: "",
            requestType: utils_1.RequestType.GraphDelete
        },
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        workbook: {
            returnType: "workbook"
        },
        analytics: {
            returnType: "itemAnalytics"
        },
        children: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveItems"
        },
        listItem: {
            returnType: "listItem"
        },
        permissions: {
            requestType: utils_1.RequestType.Get,
            returnType: "permissions"
        },
        retentionLabel: {
            returnType: "itemRetentionLabel"
        },
        subscriptions: {
            requestType: utils_1.RequestType.Get,
            returnType: "subscriptions"
        },
        thumbnails: {
            requestType: utils_1.RequestType.Get,
            returnType: "thumbnailSets"
        },
        versions: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveItemVersions"
        },
        setSensitivityLabel: {
            argNames: ["actionSource", "assignmentMethod", "id", "justificationText"],
            requestType: utils_1.RequestType.PostWithArgsInBody
        },
        restore: {
            argNames: ["parentReference", "name"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.driveItem"
        },
        copy: {
            argNames: ["name", "parentReference"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.driveItem"
        },
        createUploadSession: {
            argNames: ["item", "deferCommit"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.uploadSession"
        },
        permanentDelete: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        assignSensitivityLabel: {
            argNames: ["sensitivityLabelId", "assignmentMethod", "justificationText"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        checkin: {
            argNames: ["checkInAs", "comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        checkout: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        createLink: {
            argNames: ["type", "scope", "expirationDateTime", "password", "message", "recipients", "retainInheritedPermissions", "sendNotification"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.permission"
        },
        discardCheckout: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        follow: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.driveItem"
        },
        invite: {
            argNames: ["requireSignIn", "roles", "sendInvitation", "message", "recipients", "retainInheritedPermissions", "expirationDateTime", "password"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.permission[]"
        },
        preview: {
            argNames: ["page", "zoom"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.itemPreviewInfo"
        },
        unfollow: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        validatePermission: {
            argNames: ["challengeToken", "password"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        delta: {
            argNames: ["token"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.driveItem[]"
        },
        search: {
            argNames: ["q"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.driveItem[]"
        },
        getActivitiesByInterval: {
            argNames: ["startDateTime", "endDateTime", "interval"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.itemActivityStat[]"
        },
    },
    driveItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveItemVersion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        restoreVersion: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    driveItemVersions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveProtectionRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveProtectionRules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveProtectionUnit: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveProtectionUnits: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveRestoreArtifact: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    driveRestoreArtifacts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    eBookInstallSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    edge: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        internetExplorerMode: {
            returnType: "internetExplorerMode"
        },
    },
    ediscoveryAddToReviewSetOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        reviewSet: {
            returnType: "ediscoveryReviewSet"
        },
        search: {
            returnType: "ediscoverySearch"
        },
    },
    ediscoveryCase: {
        properties: [
            "custodians|ediscoveryCustodians|/[Name]|ediscoveryCustodian", "noncustodialDataSources|ediscoveryNoncustodialDataSources|/[Name]|ediscoveryNoncustodialDataSource", "operations|caseOperations|/[Name]|caseOperation", "reviewSets|ediscoveryReviewSets|/[Name]|ediscoveryReviewSet", "searches|ediscoverySearchs|/[Name]|ediscoverySearch", "tags|ediscoveryReviewTags|/[Name]|ediscoveryReviewTag"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        custodians: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryCustodians"
        },
        noncustodialDataSources: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryNoncustodialDataSources"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "caseOperations"
        },
        reviewSets: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryReviewSets"
        },
        searches: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoverySearchs"
        },
        settings: {
            returnType: "ediscoveryCaseSettings"
        },
        tags: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryReviewTags"
        },
    },
    ediscoveryCaseSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    ediscoveryCustodian: {
        properties: [
            "siteSources|siteSources|/[Name]|siteSource", "unifiedGroupSources|unifiedGroupSources|/[Name]|unifiedGroupSource", "userSources|userSources|/[Name]|userSource"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        lastIndexOperation: {
            returnType: "ediscoveryIndexOperation"
        },
        siteSources: {
            requestType: utils_1.RequestType.Get,
            returnType: "siteSources"
        },
        unifiedGroupSources: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedGroupSources"
        },
        userSources: {
            requestType: utils_1.RequestType.Get,
            returnType: "userSources"
        },
    },
    ediscoveryEstimateOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        search: {
            returnType: "ediscoverySearch"
        },
    },
    ediscoveryExportOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        reviewSet: {
            returnType: "ediscoveryReviewSet"
        },
        reviewSetQuery: {
            returnType: "ediscoveryReviewSetQuery"
        },
    },
    ediscoveryHoldOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    ediscoveryIndexOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    ediscoveryNoncustodialDataSource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        dataSource: {
            returnType: "dataSource"
        },
        lastIndexOperation: {
            returnType: "ediscoveryIndexOperation"
        },
    },
    ediscoveryPurgeDataOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    ediscoveryReviewSet: {
        properties: [
            "queries|ediscoveryReviewSetQuerys|/[Name]|ediscoveryReviewSetQuery"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        queries: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryReviewSetQuerys"
        },
    },
    ediscoveryReviewSetQuery: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    ediscoveryReviewTag: {
        properties: [
            "childTags|ediscoveryReviewTags|/[Name]|ediscoveryReviewTag"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        childTags: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryReviewTags"
        },
        parent: {
            returnType: "ediscoveryReviewTag"
        },
    },
    ediscoverySearch: {
        properties: [
            "additionalSources|dataSources|/[Name]|dataSource", "custodianSources|dataSources|/[Name]|dataSource", "noncustodialSources|ediscoveryNoncustodialDataSources|/[Name]|ediscoveryNoncustodialDataSource"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        additionalSources: {
            requestType: utils_1.RequestType.Get,
            returnType: "dataSources"
        },
        addToReviewSetOperation: {
            returnType: "ediscoveryAddToReviewSetOperation"
        },
        custodianSources: {
            requestType: utils_1.RequestType.Get,
            returnType: "dataSources"
        },
        lastEstimateStatisticsOperation: {
            returnType: "ediscoveryEstimateOperation"
        },
        noncustodialSources: {
            requestType: utils_1.RequestType.Get,
            returnType: "ediscoveryNoncustodialDataSources"
        },
    },
    ediscoverySearchExportOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        search: {
            returnType: "ediscoverySearch"
        },
    },
    ediscoveryTagOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    editionUpgradeConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationAssignment: {
        properties: [
            "categories|educationCategorys|/[Name]|educationCategory", "resources|educationAssignmentResources|/[Name]|educationAssignmentResource", "submissions|educationSubmissions|/[Name]|educationSubmission"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        categories: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationCategorys"
        },
        gradingCategory: {
            returnType: "educationGradingCategory"
        },
        resources: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationAssignmentResources"
        },
        rubric: {
            returnType: "educationRubric"
        },
        submissions: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationSubmissions"
        },
        publish: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationAssignment"
        },
        activate: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationAssignment"
        },
        deactivate: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationAssignment"
        },
        setUpFeedbackResourcesFolder: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationAssignment"
        },
        setUpResourcesFolder: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationAssignment"
        },
    },
    educationAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationAssignmentDefaults: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationAssignmentResource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationAssignmentResources: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationAssignmentSettings: {
        properties: [
            "gradingCategories|educationGradingCategorys|/[Name]|educationGradingCategory"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        gradingCategories: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationGradingCategorys"
        },
    },
    educationCategory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationCategorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationClass: {
        properties: [
            "assignmentCategories|educationCategorys|/[Name]|educationCategory", "assignments|educationAssignments|/[Name]|educationAssignment", "modules|educationModules|/[Name]|educationModule", "members|educationUsers|/[Name]|educationUser", "schools|educationSchools|/[Name]|educationSchool", "teachers|educationUsers|/[Name]|educationUser"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignmentCategories: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationCategorys"
        },
        assignmentDefaults: {
            returnType: "educationAssignmentDefaults"
        },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationAssignments"
        },
        assignmentSettings: {
            returnType: "educationAssignmentSettings"
        },
        modules: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationModules"
        },
        group: {
            returnType: "group"
        },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationUsers"
        },
        schools: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationSchools"
        },
        teachers: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationUsers"
        },
    },
    educationClasss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationFeedbackOutcome: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationFeedbackResourceOutcome: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationGradingCategory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationGradingCategorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationModule: {
        properties: [
            "resources|educationModuleResources|/[Name]|educationModuleResource"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resources: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationModuleResources"
        },
        publish: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationModule"
        },
        setUpResourcesFolder: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationModule"
        },
        pin: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationModule"
        },
        unpin: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationModule"
        },
    },
    educationModules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationModuleResource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationModuleResources: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationOrganization: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationOutcome: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationOutcomes: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationPointsOutcome: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationRoot: {
        properties: [
            "classes|educationClasss|/[Name]|educationClass", "schools|educationSchools|/[Name]|educationSchool", "users|educationUsers|/[Name]|educationUser"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        classes: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationClasss"
        },
        me: {
            returnType: "educationUser"
        },
        schools: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationSchools"
        },
        users: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationUsers"
        },
    },
    educationRubric: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationRubrics: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationRubricOutcome: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationSchool: {
        properties: [
            "classes|educationClasss|/[Name]|educationClass", "users|educationUsers|/[Name]|educationUser"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        administrativeUnit: {
            returnType: "administrativeUnit"
        },
        classes: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationClasss"
        },
        users: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationUsers"
        },
    },
    educationSchools: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationSubmission: {
        properties: [
            "outcomes|educationOutcomes|/[Name]|educationOutcome", "resources|educationSubmissionResources|/[Name]|educationSubmissionResource", "submittedResources|educationSubmissionResources|/[Name]|educationSubmissionResource"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        outcomes: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationOutcomes"
        },
        resources: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationSubmissionResources"
        },
        submittedResources: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationSubmissionResources"
        },
        setUpResourcesFolder: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationSubmission"
        },
        excuse: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationSubmission"
        },
        reassign: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationSubmission"
        },
        _return: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationSubmission"
        },
        submit: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationSubmission"
        },
        unsubmit: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.educationSubmission"
        },
    },
    educationSubmissions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationSubmissionResource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationSubmissionResources: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    educationUser: {
        properties: [
            "assignments|educationAssignments|/[Name]|educationAssignment", "rubrics|educationRubrics|/[Name]|educationRubric", "classes|educationClasss|/[Name]|educationClass", "schools|educationSchools|/[Name]|educationSchool", "taughtClasses|educationClasss|/[Name]|educationClass"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationAssignments"
        },
        rubrics: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationRubrics"
        },
        classes: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationClasss"
        },
        schools: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationSchools"
        },
        taughtClasses: {
            requestType: utils_1.RequestType.Get,
            returnType: "educationClasss"
        },
        user: {
            returnType: "user"
        },
    },
    educationUsers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    emailAuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    emailAuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    emailAuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|authenticationMethodTargets|/[Name]|authenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodTargets"
        },
    },
    emailFileAssessmentRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    employeeExperience: {
        properties: [
            "communities|communitys|/[Name]|community", "engagementAsyncOperations|engagementAsyncOperations|/[Name]|engagementAsyncOperation", "learningCourseActivities|learningCourseActivitys|/[Name]|learningCourseActivity", "learningProviders|learningProviders|/[Name]|learningProvider"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        communities: {
            requestType: utils_1.RequestType.Get,
            returnType: "communitys"
        },
        engagementAsyncOperations: {
            requestType: utils_1.RequestType.Get,
            returnType: "engagementAsyncOperations"
        },
        learningCourseActivities: {
            requestType: utils_1.RequestType.Get,
            returnType: "learningCourseActivitys"
        },
        learningProviders: {
            requestType: utils_1.RequestType.Get,
            returnType: "learningProviders"
        },
    },
    employeeExperienceUser: {
        properties: [
            "learningCourseActivities|learningCourseActivitys|/[Name]|learningCourseActivity"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        learningCourseActivities: {
            requestType: utils_1.RequestType.Get,
            returnType: "learningCourseActivitys"
        },
    },
    endUserNotification: {
        properties: [
            "details|endUserNotificationDetails|/[Name]|endUserNotificationDetail"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        details: {
            requestType: utils_1.RequestType.Get,
            returnType: "endUserNotificationDetails"
        },
    },
    endUserNotifications: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    endUserNotificationDetail: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    endUserNotificationDetails: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    endpoint: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    endpoints: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    engagementAsyncOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    engagementAsyncOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    enrollmentConfigurationAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    enrollmentConfigurationAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    enrollmentTroubleshootingEvent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    enterpriseCodeSigningCertificate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    entitlementManagement: {
        properties: [
            "accessPackageAssignmentApprovals|approvals|/[Name]|approval", "accessPackages|accessPackages|/[Name]|accessPackage", "assignmentPolicies|accessPackageAssignmentPolicys|/[Name]|accessPackageAssignmentPolicy", "assignmentRequests|accessPackageAssignmentRequests|/[Name]|accessPackageAssignmentRequest", "assignments|accessPackageAssignments|/[Name]|accessPackageAssignment", "catalogs|accessPackageCatalogs|/[Name]|accessPackageCatalog", "connectedOrganizations|connectedOrganizations|/[Name]|connectedOrganization", "resourceEnvironments|accessPackageResourceEnvironments|/[Name]|accessPackageResourceEnvironment", "resourceRequests|accessPackageResourceRequests|/[Name]|accessPackageResourceRequest", "resourceRoleScopes|accessPackageResourceRoleScopes|/[Name]|accessPackageResourceRoleScope", "resources|accessPackageResources|/[Name]|accessPackageResource"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        accessPackageAssignmentApprovals: {
            requestType: utils_1.RequestType.Get,
            returnType: "approvals"
        },
        accessPackages: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackages"
        },
        assignmentPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageAssignmentPolicys"
        },
        assignmentRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageAssignmentRequests"
        },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageAssignments"
        },
        catalogs: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageCatalogs"
        },
        connectedOrganizations: {
            requestType: utils_1.RequestType.Get,
            returnType: "connectedOrganizations"
        },
        resourceEnvironments: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceEnvironments"
        },
        resourceRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceRequests"
        },
        resourceRoleScopes: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResourceRoleScopes"
        },
        resources: {
            requestType: utils_1.RequestType.Get,
            returnType: "accessPackageResources"
        },
        settings: {
            returnType: "entitlementManagementSettings"
        },
    },
    entitlementManagementSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    entity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    event: {
        properties: [
            "attachments|attachments|/[Name]|attachment", "extensions|extensions|/[Name]|extension", "instances|events|/[Name]|event", "multiValueExtendedProperties|multiValueLegacyExtendedPropertys|/[Name]|multiValueLegacyExtendedProperty", "singleValueExtendedProperties|singleValueLegacyExtendedPropertys|/[Name]|singleValueLegacyExtendedProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        attachments: {
            requestType: utils_1.RequestType.Get,
            returnType: "attachments"
        },
        calendar: {
            returnType: "calendar"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        instances: {
            requestType: utils_1.RequestType.Get,
            returnType: "events"
        },
        multiValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiValueLegacyExtendedPropertys"
        },
        singleValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "singleValueLegacyExtendedPropertys"
        },
        cancel: {
            argNames: ["Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        accept: {
            argNames: ["SendResponse", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        decline: {
            argNames: ["ProposedNewTime", "SendResponse", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        dismissReminder: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        forward: {
            argNames: ["ToRecipients", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        snoozeReminder: {
            argNames: ["NewReminderTime"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        tentativelyAccept: {
            argNames: ["ProposedNewTime", "SendResponse", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    events: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    eventMessage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        event: {
            returnType: "event"
        },
    },
    eventMessageRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    eventMessageResponse: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    exchangeProtectionPolicy: {
        properties: [
            "mailboxInclusionRules|mailboxProtectionRules|/[Name]|mailboxProtectionRule", "mailboxProtectionUnits|mailboxProtectionUnits|/[Name]|mailboxProtectionUnit"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        mailboxInclusionRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "mailboxProtectionRules"
        },
        mailboxProtectionUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "mailboxProtectionUnits"
        },
    },
    exchangeProtectionPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    exchangeRestoreSession: {
        properties: [
            "granularMailboxRestoreArtifacts|granularMailboxRestoreArtifacts|/[Name]|granularMailboxRestoreArtifact", "mailboxRestoreArtifacts|mailboxRestoreArtifacts|/[Name]|mailboxRestoreArtifact"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        granularMailboxRestoreArtifacts: {
            requestType: utils_1.RequestType.Get,
            returnType: "granularMailboxRestoreArtifacts"
        },
        mailboxRestoreArtifacts: {
            requestType: utils_1.RequestType.Get,
            returnType: "mailboxRestoreArtifacts"
        },
    },
    exchangeRestoreSessions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    exportSuccessOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resourceLocation: {
            returnType: "manifest"
        },
    },
    extension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    extensions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    extensionProperty: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    extensionPropertys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    external: {
        properties: [
            "connections|externalConnections|/[Name]|externalConnection"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        connections: {
            requestType: utils_1.RequestType.Get,
            returnType: "externalConnections"
        },
    },
    externalActivity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        performedBy: {
            returnType: "identity"
        },
    },
    externalActivityResult: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    externalConnection: {
        properties: [
            "groups|externalGroups|/[Name]|externalGroup", "items|externalItems|/[Name]|externalItem", "operations|connectionOperations|/[Name]|connectionOperation"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        groups: {
            requestType: utils_1.RequestType.Get,
            returnType: "externalGroups"
        },
        items: {
            requestType: utils_1.RequestType.Get,
            returnType: "externalItems"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "connectionOperations"
        },
        schema: {
            returnType: "schema"
        },
    },
    externalDomainName: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    externalDomainNames: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    externalGroup: {
        properties: [
            "members|identitys|/[Name]|identity"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "identitys"
        },
    },
    externalItem: {
        properties: [
            "activities|externalActivitys|/[Name]|externalActivity"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activities: {
            requestType: utils_1.RequestType.Get,
            returnType: "externalActivitys"
        },
    },
    externalUsersSelfServiceSignUpEventsFlow: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    failedOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    featureRolloutPolicy: {
        properties: [
            "appliesTo|directoryObjects|/[Name]|directoryObject"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appliesTo: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
    },
    featureRolloutPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    federatedIdentityCredential: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    federatedIdentityCredentials: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    fido2AuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    fido2AuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    fido2AuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|authenticationMethodTargets|/[Name]|authenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodTargets"
        },
    },
    fido2CombinationConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    fieldValueSet: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    fileAssessmentRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    fileAttachment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    filePlanDescriptor: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        authorityTemplate: {
            returnType: "authorityTemplate"
        },
        categoryTemplate: {
            returnType: "categoryTemplate"
        },
        citationTemplate: {
            returnType: "citationTemplate"
        },
        departmentTemplate: {
            returnType: "departmentTemplate"
        },
        filePlanReferenceTemplate: {
            returnType: "filePlanReferenceTemplate"
        },
    },
    filePlanDescriptorTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    filePlanReferenceTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    fileStorage: {
        properties: [
            "containers|fileStorageContainers|/[Name]|fileStorageContainer"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        containers: {
            requestType: utils_1.RequestType.Get,
            returnType: "fileStorageContainers"
        },
        deletedContainers: {
            requestType: utils_1.RequestType.Get,
            returnType: "fileStorageContainers"
        },
    },
    fileStorageContainer: {
        properties: [
            "permissions|permissions|/[Name]|permission"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        drive: {
            returnType: "drive"
        },
        permissions: {
            requestType: utils_1.RequestType.Get,
            returnType: "permissions"
        },
        recycleBin: {
            returnType: "recycleBin"
        },
        restore: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.fileStorageContainer"
        },
        lock: {
            argNames: ["lockState"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        permanentDelete: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unlock: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    fileStorageContainers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    filterOperatorSchema: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    governanceInsight: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    governanceInsights: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    granularMailboxRestoreArtifact: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    granularMailboxRestoreArtifacts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    group: {
        properties: [
            "sets|sets|/[Name]|set"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        sets: {
            requestType: utils_1.RequestType.Get,
            returnType: "sets"
        },
        assignLicense: {
            argNames: ["addLicenses", "removeLicenses"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.group"
        },
        retryServiceProvisioning: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        checkGrantedPermissionsForApp: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.resourceSpecificPermissionGrant[]"
        },
        validateProperties: {
            argNames: ["displayName", "mailNickname", "onBehalfOfUserId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        addFavorite: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        removeFavorite: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        resetUnseenCount: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        subscribeByMail: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unsubscribeByMail: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        renew: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    groups: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    groupLifecyclePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        addGroup: {
            argNames: ["groupId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "boolean"
        },
        removeGroup: {
            argNames: ["groupId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "boolean"
        },
    },
    groupLifecyclePolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    groupSetting: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    groupSettings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    groupSettingTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    healthIssue: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    homeRealmDiscoveryPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    homeRealmDiscoveryPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    horizontalSection: {
        properties: [
            "columns|horizontalSectionColumns|/[Name]|horizontalSectionColumn"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        columns: {
            requestType: utils_1.RequestType.Get,
            returnType: "horizontalSectionColumns"
        },
    },
    horizontalSections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    horizontalSectionColumn: {
        properties: [
            "webparts|webParts|/[Name]|webPart"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        webparts: {
            requestType: utils_1.RequestType.Get,
            returnType: "webParts"
        },
    },
    horizontalSectionColumns: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    host: {
        properties: [
            "childHostPairs|hostPairs|/[Name]|hostPair", "components|hostComponents|/[Name]|hostComponent", "cookies|hostCookies|/[Name]|hostCookie", "hostPairs|hostPairs|/[Name]|hostPair", "parentHostPairs|hostPairs|/[Name]|hostPair", "passiveDns|passiveDnsRecords|/[Name]|passiveDnsRecord", "passiveDnsReverse|passiveDnsRecords|/[Name]|passiveDnsRecord", "ports|hostPorts|/[Name]|hostPort", "sslCertificates|hostSslCertificates|/[Name]|hostSslCertificate", "subdomains|subdomains|/[Name]|subdomain", "trackers|hostTrackers|/[Name]|hostTracker"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        childHostPairs: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostPairs"
        },
        components: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostComponents"
        },
        cookies: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostCookies"
        },
        hostPairs: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostPairs"
        },
        parentHostPairs: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostPairs"
        },
        passiveDns: {
            requestType: utils_1.RequestType.Get,
            returnType: "passiveDnsRecords"
        },
        passiveDnsReverse: {
            requestType: utils_1.RequestType.Get,
            returnType: "passiveDnsRecords"
        },
        ports: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostPorts"
        },
        reputation: {
            returnType: "hostReputation"
        },
        sslCertificates: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostSslCertificates"
        },
        subdomains: {
            requestType: utils_1.RequestType.Get,
            returnType: "subdomains"
        },
        trackers: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostTrackers"
        },
        whois: {
            returnType: "whoisRecord"
        },
    },
    hostComponent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        host: {
            returnType: "host"
        },
    },
    hostCookie: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        host: {
            returnType: "host"
        },
    },
    hostPair: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        childHost: {
            returnType: "host"
        },
        parentHost: {
            returnType: "host"
        },
    },
    hostPort: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        host: {
            returnType: "host"
        },
        mostRecentSslCertificate: {
            returnType: "sslCertificate"
        },
    },
    hostReputation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    hostSslCertificate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        host: {
            returnType: "host"
        },
        sslCertificate: {
            returnType: "sslCertificate"
        },
    },
    hostTracker: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        host: {
            returnType: "host"
        },
    },
    hostname: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityApiConnector: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        uploadClientCertificate: {
            argNames: ["pkcs12Value", "password"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.identityApiConnector"
        },
    },
    identityApiConnectors: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityBuiltInUserFlowAttribute: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityContainer: {
        properties: [
            "healthIssues|healthIssues|/[Name]|healthIssue", "sensors|sensors|/[Name]|sensor"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        healthIssues: {
            requestType: utils_1.RequestType.Get,
            returnType: "healthIssues"
        },
        sensors: {
            requestType: utils_1.RequestType.Get,
            returnType: "sensors"
        },
    },
    identityCustomUserFlowAttribute: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityGovernance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        lifecycleWorkflows: {
            returnType: "lifecycleWorkflowsContainer"
        },
        accessReviews: {
            returnType: "accessReviewSet"
        },
        appConsent: {
            returnType: "appConsentApprovalRoute"
        },
        termsOfUse: {
            returnType: "termsOfUseContainer"
        },
        entitlementManagement: {
            returnType: "entitlementManagement"
        },
        privilegedAccess: {
            returnType: "privilegedAccessRoot"
        },
    },
    identityProtectionRoot: {
        properties: [
            "riskDetections|riskDetections|/[Name]|riskDetection", "riskyServicePrincipals|riskyServicePrincipals|/[Name]|riskyServicePrincipal", "riskyUsers|riskyUsers|/[Name]|riskyUser", "servicePrincipalRiskDetections|servicePrincipalRiskDetections|/[Name]|servicePrincipalRiskDetection"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        riskDetections: {
            requestType: utils_1.RequestType.Get,
            returnType: "riskDetections"
        },
        riskyServicePrincipals: {
            requestType: utils_1.RequestType.Get,
            returnType: "riskyServicePrincipals"
        },
        riskyUsers: {
            requestType: utils_1.RequestType.Get,
            returnType: "riskyUsers"
        },
        servicePrincipalRiskDetections: {
            requestType: utils_1.RequestType.Get,
            returnType: "servicePrincipalRiskDetections"
        },
    },
    identityProvider: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityProviders: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityProviderBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityProviderBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identitySecurityDefaultsEnforcementPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityUserFlow: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityUserFlowAttribute: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityUserFlowAttributes: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    identityUserFlowAttributeAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        userAttribute: {
            returnType: "identityUserFlowAttribute"
        },
    },
    identityUserFlowAttributeAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    importedWindowsAutopilotDeviceIdentity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    importedWindowsAutopilotDeviceIdentitys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    importedWindowsAutopilotDeviceIdentityUpload: {
        properties: [
            "deviceIdentities|importedWindowsAutopilotDeviceIdentitys|/[Name]|importedWindowsAutopilotDeviceIdentity"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        deviceIdentities: {
            requestType: utils_1.RequestType.Get,
            returnType: "importedWindowsAutopilotDeviceIdentitys"
        },
    },
    incident: {
        properties: [
            "alerts|alerts|/[Name]|alert"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        alerts: {
            requestType: utils_1.RequestType.Get,
            returnType: "alerts"
        },
    },
    indicator: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        artifact: {
            returnType: "artifact"
        },
    },
    inferenceClassification: {
        properties: [
            "overrides|inferenceClassificationOverrides|/[Name]|inferenceClassificationOverride"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        overrides: {
            requestType: utils_1.RequestType.Get,
            returnType: "inferenceClassificationOverrides"
        },
    },
    inferenceClassificationOverride: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    inferenceClassificationOverrides: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    informationProtection: {
        properties: [
            "threatAssessmentRequests|threatAssessmentRequests|/[Name]|threatAssessmentRequest"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        bitlocker: {
            returnType: "bitlocker"
        },
        threatAssessmentRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "threatAssessmentRequests"
        },
    },
    insights: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    insightsSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    intelligenceProfile: {
        properties: [
            "indicators|intelligenceProfileIndicators|/[Name]|intelligenceProfileIndicator"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        indicators: {
            requestType: utils_1.RequestType.Get,
            returnType: "intelligenceProfileIndicators"
        },
    },
    intelligenceProfileIndicator: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    internalDomainFederation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    internalDomainFederations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    internetExplorerMode: {
        properties: [
            "siteLists|browserSiteLists|/[Name]|browserSiteList"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        siteLists: {
            requestType: utils_1.RequestType.Get,
            returnType: "browserSiteLists"
        },
    },
    invitation: {
        properties: [
            "invitedUserSponsors|directoryObjects|/[Name]|directoryObject"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        invitedUser: {
            returnType: "user"
        },
        invitedUserSponsors: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
    },
    inviteParticipantsOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosCertificateProfile: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosCompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosCustomConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosDeviceFeaturesConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosGeneralDeviceConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosLobApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosLobAppProvisioningConfigurationAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosManagedAppProtection: {
        properties: [
            "apps|managedMobileApps|/[Name]|managedMobileApp"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        apps: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedMobileApps"
        },
        deploymentSummary: {
            returnType: "managedAppPolicyDeploymentSummary"
        },
    },
    iosManagedAppProtections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosManagedAppRegistration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosMobileAppConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosStoreApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosUpdateConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosUpdateDeviceStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosUpdateDeviceStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosVppApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosVppEBook: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosVppEBookAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    iosiPadOSWebClip: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    ipAddress: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    ipNamedLocation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    itemActivity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        driveItem: {
            returnType: "driveItem"
        },
    },
    itemActivitys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    itemActivityStat: {
        properties: [
            "activities|itemActivitys|/[Name]|itemActivity"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activities: {
            requestType: utils_1.RequestType.Get,
            returnType: "itemActivitys"
        },
    },
    itemActivityStats: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    itemAnalytics: {
        properties: [
            "itemActivityStats|itemActivityStats|/[Name]|itemActivityStat"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        allTime: {
            returnType: "itemActivityStat"
        },
        itemActivityStats: {
            requestType: utils_1.RequestType.Get,
            returnType: "itemActivityStats"
        },
        lastSevenDays: {
            returnType: "itemActivityStat"
        },
    },
    itemAttachment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        item: {
            returnType: "outlookItem"
        },
    },
    itemInsights: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    itemRetentionLabel: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    labelsRoot: {
        properties: [
            "authorities|authorityTemplates|/[Name]|authorityTemplate", "categories|categoryTemplates|/[Name]|categoryTemplate", "citations|citationTemplates|/[Name]|citationTemplate", "departments|departmentTemplates|/[Name]|departmentTemplate", "filePlanReferences|filePlanReferenceTemplates|/[Name]|filePlanReferenceTemplate", "retentionLabels|retentionLabels|/[Name]|retentionLabel"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        authorities: {
            requestType: utils_1.RequestType.Get,
            returnType: "authorityTemplates"
        },
        categories: {
            requestType: utils_1.RequestType.Get,
            returnType: "categoryTemplates"
        },
        citations: {
            requestType: utils_1.RequestType.Get,
            returnType: "citationTemplates"
        },
        departments: {
            requestType: utils_1.RequestType.Get,
            returnType: "departmentTemplates"
        },
        filePlanReferences: {
            requestType: utils_1.RequestType.Get,
            returnType: "filePlanReferenceTemplates"
        },
        retentionLabels: {
            requestType: utils_1.RequestType.Get,
            returnType: "retentionLabels"
        },
    },
    landingPage: {
        properties: [
            "details|landingPageDetails|/[Name]|landingPageDetail"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        details: {
            requestType: utils_1.RequestType.Get,
            returnType: "landingPageDetails"
        },
    },
    landingPages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    landingPageDetail: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    landingPageDetails: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    learningAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    learningContent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    learningContents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    learningCourseActivity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    learningCourseActivitys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    learningProvider: {
        properties: [
            "learningContents|learningContents|/[Name]|learningContent", "learningCourseActivities|learningCourseActivitys|/[Name]|learningCourseActivity"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        learningContents: {
            requestType: utils_1.RequestType.Get,
            returnType: "learningContents"
        },
        learningCourseActivities: {
            requestType: utils_1.RequestType.Get,
            returnType: "learningCourseActivitys"
        },
    },
    learningProviders: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    learningSelfInitiatedCourse: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    licenseDetails: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    licenseDetailss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    lifecycleManagementSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    lifecycleWorkflowsContainer: {
        properties: [
            "customTaskExtensions|customTaskExtensions|/[Name]|customTaskExtension", "taskDefinitions|taskDefinitions|/[Name]|taskDefinition", "workflows|workflows|/[Name]|workflow", "workflowTemplates|workflowTemplates|/[Name]|workflowTemplate"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        customTaskExtensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "customTaskExtensions"
        },
        deletedItems: {
            returnType: "deletedItemContainer"
        },
        insights: {
            returnType: "insights"
        },
        settings: {
            returnType: "lifecycleManagementSettings"
        },
        taskDefinitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "taskDefinitions"
        },
        workflows: {
            requestType: utils_1.RequestType.Get,
            returnType: "workflows"
        },
        workflowTemplates: {
            requestType: utils_1.RequestType.Get,
            returnType: "workflowTemplates"
        },
    },
    linkedResource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    linkedResources: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    list: {
        properties: [
            "columns|columnDefinitions|/[Name]|columnDefinition", "contentTypes|contentTypes|/[Name]|contentType", "items|listItems|/[Name]|listItem", "operations|richLongRunningOperations|/[Name]|richLongRunningOperation", "subscriptions|subscriptions|/[Name]|subscription"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        columns: {
            requestType: utils_1.RequestType.Get,
            returnType: "columnDefinitions"
        },
        contentTypes: {
            requestType: utils_1.RequestType.Get,
            returnType: "contentTypes"
        },
        delete: {
            name: "",
            requestType: utils_1.RequestType.GraphDelete
        },
        drive: {
            returnType: "drive"
        },
        items: {
            requestType: utils_1.RequestType.Get,
            returnType: "listItems"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "richLongRunningOperations"
        },
        subscriptions: {
            requestType: utils_1.RequestType.Get,
            returnType: "subscriptions"
        },
        update: {
            argNames: ["values"],
            name: "",
            requestMethod: "PATCH",
            requestType: utils_1.RequestType.PostBodyNoArgs
        },
    },
    lists: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    listItem: {
        properties: [
            "documentSetVersions|documentSetVersions|/[Name]|documentSetVersion", "versions|listItemVersions|/[Name]|listItemVersion"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        analytics: {
            returnType: "itemAnalytics"
        },
        delete: {
            name: "",
            requestType: utils_1.RequestType.GraphDelete
        },
        documentSetVersions: {
            requestType: utils_1.RequestType.Get,
            returnType: "documentSetVersions"
        },
        driveItem: {
            returnType: "driveItem"
        },
        fields: {
            returnType: "fieldValueSet"
        },
        versions: {
            requestType: utils_1.RequestType.Get,
            returnType: "listItemVersions"
        },
        update: {
            argNames: ["values"],
            name: "",
            requestMethod: "PATCH",
            requestType: utils_1.RequestType.PostBodyNoArgs
        },
        createLink: {
            argNames: ["type", "scope", "expirationDateTime", "password", "message", "recipients", "retainInheritedPermissions", "sendNotification"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.permission"
        },
        getActivitiesByInterval: {
            argNames: ["startDateTime", "endDateTime", "interval"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.itemActivityStat[]"
        },
    },
    listItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    listItemVersion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fields: {
            returnType: "fieldValueSet"
        },
        restoreVersion: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    listItemVersions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    localizedNotificationMessage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    localizedNotificationMessages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    loginPage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    loginPages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    longRunningOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    longRunningOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    m365AppsInstallationOptions: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSCompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSCustomConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSDeviceFeaturesConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSDmgApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSGeneralDeviceConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSLobApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSMicrosoftDefenderApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSMicrosoftEdgeApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    macOSOfficeSuiteApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailAssessmentRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailFolder: {
        properties: [
            "childFolders|mailFolders|/[Name]|mailFolder", "messageRules|messageRules|/[Name]|messageRule", "messages|messages|/[Name]|message", "multiValueExtendedProperties|multiValueLegacyExtendedPropertys|/[Name]|multiValueLegacyExtendedProperty", "singleValueExtendedProperties|singleValueLegacyExtendedPropertys|/[Name]|singleValueLegacyExtendedProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        childFolders: {
            requestType: utils_1.RequestType.Get,
            returnType: "mailFolders"
        },
        messageRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "messageRules"
        },
        messages: {
            requestType: utils_1.RequestType.Get,
            returnType: "messages"
        },
        multiValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiValueLegacyExtendedPropertys"
        },
        singleValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "singleValueLegacyExtendedPropertys"
        },
        copy: {
            argNames: ["DestinationId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.mailFolder"
        },
        move: {
            argNames: ["DestinationId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.mailFolder"
        },
    },
    mailFolders: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailSearchFolder: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailboxProtectionRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailboxProtectionRules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailboxProtectionUnit: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailboxProtectionUnits: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailboxRestoreArtifact: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mailboxRestoreArtifacts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    malwareStateForWindowsDevice: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    malwareStateForWindowsDevices: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAndroidLobApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAndroidStoreApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        targetApps: {
            argNames: ["apps", "appGroupType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    managedAppPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppPolicyDeploymentSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppProtection: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        targetApps: {
            argNames: ["apps", "appGroupType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    managedAppRegistration: {
        properties: [
            "appliedPolicies|managedAppPolicys|/[Name]|managedAppPolicy", "intendedPolicies|managedAppPolicys|/[Name]|managedAppPolicy", "operations|managedAppOperations|/[Name]|managedAppOperation"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appliedPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedAppPolicys"
        },
        intendedPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedAppPolicys"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedAppOperations"
        },
    },
    managedAppRegistrations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedAppStatusRaw: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDevice: {
        properties: [
            "deviceCompliancePolicyStates|deviceCompliancePolicyStates|/[Name]|deviceCompliancePolicyState", "deviceConfigurationStates|deviceConfigurationStates|/[Name]|deviceConfigurationState", "logCollectionRequests|deviceLogCollectionResponses|/[Name]|deviceLogCollectionResponse", "users|users|/[Name]|user"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        deviceCompliancePolicyStates: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceCompliancePolicyStates"
        },
        deviceConfigurationStates: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceConfigurationStates"
        },
        deviceCategory: {
            returnType: "deviceCategory"
        },
        logCollectionRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceLogCollectionResponses"
        },
        users: {
            requestType: utils_1.RequestType.Get,
            returnType: "users"
        },
        windowsProtectionState: {
            returnType: "windowsProtectionState"
        },
        bypassActivationLock: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        cleanWindowsDevice: {
            argNames: ["keepUserData"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        deleteUserFromSharedAppleDevice: {
            argNames: ["userPrincipalName"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        disableLostMode: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        locateDevice: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        logoutSharedAppleDeviceActiveUser: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        rebootNow: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        recoverPasscode: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        remoteLock: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        requestRemoteAssistance: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        resetPasscode: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        retire: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        shutDown: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        syncDevice: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        updateWindowsDeviceAccount: {
            argNames: ["updateWindowsDeviceAccountActionParameter"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        windowsDefenderScan: {
            argNames: ["quickScan"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        windowsDefenderUpdateSignatures: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        wipe: {
            argNames: ["keepEnrollmentData", "keepUserData", "macOsUnlockCode", "persistEsimDataPlan"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    managedDevices: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfiguration: {
        properties: [
            "assignments|managedDeviceMobileAppConfigurationAssignments|/[Name]|managedDeviceMobileAppConfigurationAssignment", "deviceStatuses|managedDeviceMobileAppConfigurationDeviceStatuss|/[Name]|managedDeviceMobileAppConfigurationDeviceStatus", "userStatuses|managedDeviceMobileAppConfigurationUserStatuss|/[Name]|managedDeviceMobileAppConfigurationUserStatus"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedDeviceMobileAppConfigurationAssignments"
        },
        deviceStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedDeviceMobileAppConfigurationDeviceStatuss"
        },
        deviceStatusSummary: {
            returnType: "managedDeviceMobileAppConfigurationDeviceSummary"
        },
        userStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedDeviceMobileAppConfigurationUserStatuss"
        },
        userStatusSummary: {
            returnType: "managedDeviceMobileAppConfigurationUserSummary"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    managedDeviceMobileAppConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationDeviceStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationDeviceStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationDeviceSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationUserStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationUserStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceMobileAppConfigurationUserSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedDeviceOverview: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedEBook: {
        properties: [
            "assignments|managedEBookAssignments|/[Name]|managedEBookAssignment", "deviceStates|deviceInstallStates|/[Name]|deviceInstallState", "userStateSummary|userInstallStateSummarys|/[Name]|userInstallStateSummary"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedEBookAssignments"
        },
        deviceStates: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceInstallStates"
        },
        installSummary: {
            returnType: "eBookInstallSummary"
        },
        userStateSummary: {
            requestType: utils_1.RequestType.Get,
            returnType: "userInstallStateSummarys"
        },
        assign: {
            argNames: ["managedEBookAssignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    managedEBooks: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedEBookAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedEBookAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedIOSLobApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedIOSStoreApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedMobileApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedMobileApps: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    managedMobileLobApp: {
        properties: [
            "contentVersions|mobileAppContents|/[Name]|mobileAppContent"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        contentVersions: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileAppContents"
        },
    },
    manifest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mdmWindowsInformationProtectionPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mdmWindowsInformationProtectionPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    meetingAttendanceReport: {
        properties: [
            "attendanceRecords|attendanceRecords|/[Name]|attendanceRecord"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        attendanceRecords: {
            requestType: utils_1.RequestType.Get,
            returnType: "attendanceRecords"
        },
    },
    meetingAttendanceReports: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    membershipOutlierInsight: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        container: {
            returnType: "directoryObject"
        },
        lastModifiedBy: {
            returnType: "user"
        },
        member: {
            returnType: "directoryObject"
        },
    },
    message: {
        properties: [
            "attachments|attachments|/[Name]|attachment", "extensions|extensions|/[Name]|extension", "multiValueExtendedProperties|multiValueLegacyExtendedPropertys|/[Name]|multiValueLegacyExtendedProperty", "singleValueExtendedProperties|singleValueLegacyExtendedPropertys|/[Name]|singleValueLegacyExtendedProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        attachments: {
            requestType: utils_1.RequestType.Get,
            returnType: "attachments"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        multiValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiValueLegacyExtendedPropertys"
        },
        singleValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "singleValueLegacyExtendedPropertys"
        },
        forward: {
            argNames: ["ToRecipients", "Message", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        copy: {
            argNames: ["DestinationId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.message"
        },
        move: {
            argNames: ["DestinationId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.message"
        },
        createForward: {
            argNames: ["ToRecipients", "Message", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.message"
        },
        createReply: {
            argNames: ["Message", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.message"
        },
        createReplyAll: {
            argNames: ["Message", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.message"
        },
        reply: {
            argNames: ["Message", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        replyAll: {
            argNames: ["Message", "Comment"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        send: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    messages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    messageRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    messageRules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    microsoftAccountUserConversationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    microsoftAuthenticatorAuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        device: {
            returnType: "device"
        },
    },
    microsoftAuthenticatorAuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    microsoftAuthenticatorAuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|microsoftAuthenticatorAuthenticationMethodTargets|/[Name]|microsoftAuthenticatorAuthenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "microsoftAuthenticatorAuthenticationMethodTargets"
        },
    },
    microsoftAuthenticatorAuthenticationMethodTarget: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    microsoftAuthenticatorAuthenticationMethodTargets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    microsoftStoreForBusinessApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileApp: {
        properties: [
            "assignments|mobileAppAssignments|/[Name]|mobileAppAssignment", "categories|mobileAppCategorys|/[Name]|mobileAppCategory"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileAppAssignments"
        },
        categories: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileAppCategorys"
        },
        assign: {
            argNames: ["mobileAppAssignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    mobileApps: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileAppAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileAppAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileAppCategory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileAppCategorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileAppContent: {
        properties: [
            "containedApps|mobileContainedApps|/[Name]|mobileContainedApp", "files|mobileAppContentFiles|/[Name]|mobileAppContentFile"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        containedApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileContainedApps"
        },
        files: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileAppContentFiles"
        },
    },
    mobileAppContents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileAppContentFile: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        commit: {
            argNames: ["fileEncryptionInfo"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        renewUpload: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    mobileAppContentFiles: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileAppTroubleshootingEvent: {
        properties: [
            "appLogCollectionRequests|appLogCollectionRequests|/[Name]|appLogCollectionRequest"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appLogCollectionRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "appLogCollectionRequests"
        },
    },
    mobileAppTroubleshootingEvents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileContainedApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileContainedApps: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileLobApp: {
        properties: [
            "contentVersions|mobileAppContents|/[Name]|mobileAppContent"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        contentVersions: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileAppContents"
        },
    },
    mobileThreatDefenseConnector: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    mobileThreatDefenseConnectors: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    multiTenantOrganization: {
        properties: [
            "tenants|multiTenantOrganizationMembers|/[Name]|multiTenantOrganizationMember"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        joinRequest: {
            returnType: "multiTenantOrganizationJoinRequestRecord"
        },
        tenants: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiTenantOrganizationMembers"
        },
    },
    multiTenantOrganizationIdentitySyncPolicyTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    multiTenantOrganizationJoinRequestRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    multiTenantOrganizationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    multiTenantOrganizationMembers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    multiTenantOrganizationPartnerConfigurationTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    multiValueLegacyExtendedProperty: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    multiValueLegacyExtendedPropertys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    muteParticipantOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    namedLocation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    namedLocations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    networkAdapter: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    notebook: {
        properties: [
            "sectionGroups|sectionGroups|/[Name]|sectionGroup", "sections|onenoteSections|/[Name]|onenoteSection"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        sectionGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "sectionGroups"
        },
        sections: {
            requestType: utils_1.RequestType.Get,
            returnType: "onenoteSections"
        },
        copyNotebook: {
            argNames: ["groupId", "renameAs", "notebookFolder", "siteCollectionId", "siteId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.onenoteOperation"
        },
    },
    notebooks: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    notificationMessageTemplate: {
        properties: [
            "localizedNotificationMessages|localizedNotificationMessages|/[Name]|localizedNotificationMessage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        localizedNotificationMessages: {
            requestType: utils_1.RequestType.Get,
            returnType: "localizedNotificationMessages"
        },
        sendTestMessage: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    notificationMessageTemplates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    oAuth2PermissionGrant: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    oAuth2PermissionGrants: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    offerShiftRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    offerShiftRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    officeGraphInsights: {
        properties: [
            "shared|sharedInsights|/[Name]|sharedInsight", "trending|trendings|/[Name]|trending", "used|usedInsights|/[Name]|usedInsight"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        shared: {
            requestType: utils_1.RequestType.Get,
            returnType: "sharedInsights"
        },
        trending: {
            requestType: utils_1.RequestType.Get,
            returnType: "trendings"
        },
        used: {
            requestType: utils_1.RequestType.Get,
            returnType: "usedInsights"
        },
    },
    onAttributeCollectionListener: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onAuthenticationMethodLoadStartListener: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onInteractiveAuthFlowStartListener: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onPremisesConditionalAccessSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onPremisesDirectorySynchronization: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onPremisesDirectorySynchronizations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onTokenIssuanceStartCustomExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onTokenIssuanceStartListener: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onUserCreateStartListener: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    oneDriveForBusinessProtectionPolicy: {
        properties: [
            "driveInclusionRules|driveProtectionRules|/[Name]|driveProtectionRule", "driveProtectionUnits|driveProtectionUnits|/[Name]|driveProtectionUnit"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        driveInclusionRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveProtectionRules"
        },
        driveProtectionUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveProtectionUnits"
        },
    },
    oneDriveForBusinessProtectionPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    oneDriveForBusinessRestoreSession: {
        properties: [
            "driveRestoreArtifacts|driveRestoreArtifacts|/[Name]|driveRestoreArtifact"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        driveRestoreArtifacts: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveRestoreArtifacts"
        },
    },
    oneDriveForBusinessRestoreSessions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenote: {
        properties: [
            "notebooks|notebooks|/[Name]|notebook", "operations|onenoteOperations|/[Name]|onenoteOperation", "pages|onenotePages|/[Name]|onenotePage", "resources|onenoteResources|/[Name]|onenoteResource", "sectionGroups|sectionGroups|/[Name]|sectionGroup", "sections|onenoteSections|/[Name]|onenoteSection"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        notebooks: {
            requestType: utils_1.RequestType.Get,
            returnType: "notebooks"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "onenoteOperations"
        },
        pages: {
            requestType: utils_1.RequestType.Get,
            returnType: "onenotePages"
        },
        resources: {
            requestType: utils_1.RequestType.Get,
            returnType: "onenoteResources"
        },
        sectionGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "sectionGroups"
        },
        sections: {
            requestType: utils_1.RequestType.Get,
            returnType: "onenoteSections"
        },
    },
    onenoteEntityBaseModel: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenoteEntityHierarchyModel: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenoteEntitySchemaObjectModel: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenoteOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenoteOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenotePage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        parentNotebook: {
            returnType: "notebook"
        },
        parentSection: {
            returnType: "onenoteSection"
        },
        copyToSection: {
            argNames: ["id", "groupId", "siteCollectionId", "siteId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.onenoteOperation"
        },
        onenotePatchContent: {
            argNames: ["commands"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        preview: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.onenotePagePreview"
        },
    },
    onenotePages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenoteResource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenoteResources: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onenoteSection: {
        properties: [
            "pages|onenotePages|/[Name]|onenotePage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        pages: {
            requestType: utils_1.RequestType.Get,
            returnType: "onenotePages"
        },
        parentNotebook: {
            returnType: "notebook"
        },
        parentSectionGroup: {
            returnType: "sectionGroup"
        },
        copyToNotebook: {
            argNames: ["id", "groupId", "renameAs", "siteCollectionId", "siteId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.onenoteOperation"
        },
        copyToSectionGroup: {
            argNames: ["id", "groupId", "renameAs", "siteCollectionId", "siteId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.onenoteOperation"
        },
    },
    onenoteSections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onlineMeeting: {
        properties: [
            "recordings|callRecordings|/[Name]|callRecording", "transcripts|callTranscripts|/[Name]|callTranscript"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        recordings: {
            requestType: utils_1.RequestType.Get,
            returnType: "callRecordings"
        },
        transcripts: {
            requestType: utils_1.RequestType.Get,
            returnType: "callTranscripts"
        },
        sendVirtualAppointmentReminderSms: {
            argNames: ["remindBeforeTimeInMinutesType", "attendees"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        sendVirtualAppointmentSms: {
            argNames: ["messageType", "attendees"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        getVirtualAppointmentJoinWebUrl: {
            requestType: utils_1.RequestType.Get,
            returnType: "string"
        },
    },
    onlineMeetings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    onlineMeetingBase: {
        properties: [
            "attendanceReports|meetingAttendanceReports|/[Name]|meetingAttendanceReport"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        attendanceReports: {
            requestType: utils_1.RequestType.Get,
            returnType: "meetingAttendanceReports"
        },
    },
    openShift: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    openShifts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    openShiftChangeRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    openShiftChangeRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    openTypeExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    operation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    orgContact: {
        properties: [
            "directReports|directoryObjects|/[Name]|directoryObject", "memberOf|directoryObjects|/[Name]|directoryObject", "transitiveMemberOf|directoryObjects|/[Name]|directoryObject"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        directReports: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        manager: {
            returnType: "directoryObject"
        },
        memberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        transitiveMemberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        retryServiceProvisioning: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    organization: {
        properties: [
            "certificateBasedAuthConfiguration|certificateBasedAuthConfigurations|/[Name]|certificateBasedAuthConfiguration", "extensions|extensions|/[Name]|extension"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        branding: {
            returnType: "organizationalBranding"
        },
        certificateBasedAuthConfiguration: {
            requestType: utils_1.RequestType.Get,
            returnType: "certificateBasedAuthConfigurations"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        setMobileDeviceManagementAuthority: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "number"
        },
    },
    organizationalBranding: {
        properties: [
            "localizations|organizationalBrandingLocalizations|/[Name]|organizationalBrandingLocalization"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        localizations: {
            requestType: utils_1.RequestType.Get,
            returnType: "organizationalBrandingLocalizations"
        },
    },
    organizationalBrandingLocalization: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    organizationalBrandingLocalizations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    organizationalBrandingProperties: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    organizer: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    outlookCategory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    outlookCategorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    outlookItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    outlookUser: {
        properties: [
            "masterCategories|outlookCategorys|/[Name]|outlookCategory"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        masterCategories: {
            requestType: utils_1.RequestType.Get,
            returnType: "outlookCategorys"
        },
    },
    participant: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        mute: {
            argNames: ["clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.muteParticipantOperation"
        },
        startHoldMusic: {
            argNames: ["customPrompt", "clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.startHoldMusicOperation"
        },
        stopHoldMusic: {
            argNames: ["clientContext"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.stopHoldMusicOperation"
        },
    },
    participants: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    participantBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    participantJoiningNotification: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        call: {
            returnType: "call"
        },
    },
    participantLeftNotification: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        call: {
            returnType: "call"
        },
    },
    partners: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        billing: {
            returnType: "billing"
        },
    },
    passiveDnsRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        artifact: {
            returnType: "artifact"
        },
        parentHost: {
            returnType: "host"
        },
    },
    passwordAuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    passwordAuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    payload: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    payloads: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    peopleAdminSettings: {
        properties: [
            "profileCardProperties|profileCardPropertys|/[Name]|profileCardProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        profileCardProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "profileCardPropertys"
        },
        pronouns: {
            returnType: "pronounsSettings"
        },
        itemInsights: {
            returnType: "insightsSettings"
        },
    },
    permission: {
        properties: [],
        delete: {
            name: "",
            requestType: utils_1.RequestType.GraphDelete
        },
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        update: {
            argNames: ["values"],
            name: "",
            requestMethod: "PATCH",
            requestType: utils_1.RequestType.PostBodyNoArgs
        },
        grant: {
            argNames: ["roles", "recipients"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.permission[]"
        },
    },
    permissions: {
        add: {
            argNames: ["values"],
            name: "",
            requestType: utils_1.RequestType.PostBodyNoArgs
        },
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    permissionGrantConditionSet: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    permissionGrantConditionSets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    permissionGrantPolicy: {
        properties: [
            "excludes|permissionGrantConditionSets|/[Name]|permissionGrantConditionSet", "includes|permissionGrantConditionSets|/[Name]|permissionGrantConditionSet"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        excludes: {
            requestType: utils_1.RequestType.Get,
            returnType: "permissionGrantConditionSets"
        },
        includes: {
            requestType: utils_1.RequestType.Get,
            returnType: "permissionGrantConditionSets"
        },
    },
    permissionGrantPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    person: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    persons: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    phoneAuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        disableSmsSignIn: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        enableSmsSignIn: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    phoneAuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    pinnedChatMessageInfo: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        message: {
            returnType: "chatMessage"
        },
    },
    pinnedChatMessageInfos: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    place: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    planner: {
        properties: [
            "buckets|plannerBuckets|/[Name]|plannerBucket", "plans|plannerPlans|/[Name]|plannerPlan", "tasks|plannerTasks|/[Name]|plannerTask"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        buckets: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerBuckets"
        },
        plans: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerPlans"
        },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerTasks"
        },
    },
    plannerAssignedToTaskBoardTaskFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerBucket: {
        properties: [
            "tasks|plannerTasks|/[Name]|plannerTask"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerTasks"
        },
    },
    plannerBuckets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerBucketTaskBoardTaskFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerGroup: {
        properties: [
            "plans|plannerPlans|/[Name]|plannerPlan"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        plans: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerPlans"
        },
    },
    plannerPlan: {
        properties: [
            "buckets|plannerBuckets|/[Name]|plannerBucket", "tasks|plannerTasks|/[Name]|plannerTask"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        buckets: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerBuckets"
        },
        details: {
            returnType: "plannerPlanDetails"
        },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerTasks"
        },
    },
    plannerPlans: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerPlanDetails: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerProgressTaskBoardTaskFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerTask: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignedToTaskBoardFormat: {
            returnType: "plannerAssignedToTaskBoardTaskFormat"
        },
        bucketTaskBoardFormat: {
            returnType: "plannerBucketTaskBoardTaskFormat"
        },
        details: {
            returnType: "plannerTaskDetails"
        },
        progressTaskBoardFormat: {
            returnType: "plannerProgressTaskBoardTaskFormat"
        },
    },
    plannerTasks: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerTaskDetails: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    plannerUser: {
        properties: [
            "plans|plannerPlans|/[Name]|plannerPlan", "tasks|plannerTasks|/[Name]|plannerTask"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        plans: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerPlans"
        },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "plannerTasks"
        },
    },
    playPromptOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    policyBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    policyRoot: {
        properties: [
            "authenticationStrengthPolicies|authenticationStrengthPolicys|/[Name]|authenticationStrengthPolicy", "activityBasedTimeoutPolicies|activityBasedTimeoutPolicys|/[Name]|activityBasedTimeoutPolicy", "appManagementPolicies|appManagementPolicys|/[Name]|appManagementPolicy", "claimsMappingPolicies|claimsMappingPolicys|/[Name]|claimsMappingPolicy", "homeRealmDiscoveryPolicies|homeRealmDiscoveryPolicys|/[Name]|homeRealmDiscoveryPolicy", "permissionGrantPolicies|permissionGrantPolicys|/[Name]|permissionGrantPolicy", "tokenIssuancePolicies|tokenIssuancePolicys|/[Name]|tokenIssuancePolicy", "tokenLifetimePolicies|tokenLifetimePolicys|/[Name]|tokenLifetimePolicy", "featureRolloutPolicies|featureRolloutPolicys|/[Name]|featureRolloutPolicy", "conditionalAccessPolicies|conditionalAccessPolicys|/[Name]|conditionalAccessPolicy", "roleManagementPolicies|unifiedRoleManagementPolicys|/[Name]|unifiedRoleManagementPolicy", "roleManagementPolicyAssignments|unifiedRoleManagementPolicyAssignments|/[Name]|unifiedRoleManagementPolicyAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        authenticationMethodsPolicy: {
            returnType: "authenticationMethodsPolicy"
        },
        authenticationStrengthPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationStrengthPolicys"
        },
        authenticationFlowsPolicy: {
            returnType: "authenticationFlowsPolicy"
        },
        deviceRegistrationPolicy: {
            returnType: "deviceRegistrationPolicy"
        },
        activityBasedTimeoutPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "activityBasedTimeoutPolicys"
        },
        appManagementPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "appManagementPolicys"
        },
        authorizationPolicy: {
            returnType: "authorizationPolicy"
        },
        claimsMappingPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "claimsMappingPolicys"
        },
        crossTenantAccessPolicy: {
            returnType: "crossTenantAccessPolicy"
        },
        defaultAppManagementPolicy: {
            returnType: "tenantAppManagementPolicy"
        },
        homeRealmDiscoveryPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "homeRealmDiscoveryPolicys"
        },
        permissionGrantPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "permissionGrantPolicys"
        },
        tokenIssuancePolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "tokenIssuancePolicys"
        },
        tokenLifetimePolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "tokenLifetimePolicys"
        },
        featureRolloutPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "featureRolloutPolicys"
        },
        adminConsentRequestPolicy: {
            returnType: "adminConsentRequestPolicy"
        },
        conditionalAccessPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "conditionalAccessPolicys"
        },
        identitySecurityDefaultsEnforcementPolicy: {
            returnType: "identitySecurityDefaultsEnforcementPolicy"
        },
        roleManagementPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleManagementPolicys"
        },
        roleManagementPolicyAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleManagementPolicyAssignments"
        },
    },
    policyTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        multiTenantOrganizationIdentitySynchronization: {
            returnType: "multiTenantOrganizationIdentitySyncPolicyTemplate"
        },
        multiTenantOrganizationPartnerConfiguration: {
            returnType: "multiTenantOrganizationPartnerConfigurationTemplate"
        },
    },
    post: {
        properties: [
            "attachments|attachments|/[Name]|attachment", "extensions|extensions|/[Name]|extension", "multiValueExtendedProperties|multiValueLegacyExtendedPropertys|/[Name]|multiValueLegacyExtendedProperty", "singleValueExtendedProperties|singleValueLegacyExtendedPropertys|/[Name]|singleValueLegacyExtendedProperty"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        attachments: {
            requestType: utils_1.RequestType.Get,
            returnType: "attachments"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        inReplyTo: {
            returnType: "post"
        },
        multiValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "multiValueLegacyExtendedPropertys"
        },
        singleValueExtendedProperties: {
            requestType: utils_1.RequestType.Get,
            returnType: "singleValueLegacyExtendedPropertys"
        },
        forward: {
            argNames: ["Comment", "ToRecipients"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        reply: {
            argNames: ["Post"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    posts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    presence: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        clearPresence: {
            argNames: ["sessionId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        clearUserPreferredPresence: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        setPresence: {
            argNames: ["sessionId", "availability", "activity", "expirationDuration"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        setStatusMessage: {
            argNames: ["statusMessage"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        setUserPreferredPresence: {
            argNames: ["availability", "activity", "expirationDuration"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    presences: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    print: {
        properties: [
            "connectors|printConnectors|/[Name]|printConnector", "operations|printOperations|/[Name]|printOperation", "printers|printers|/[Name]|printer", "services|printServices|/[Name]|printService", "shares|printerShares|/[Name]|printerShare", "taskDefinitions|printTaskDefinitions|/[Name]|printTaskDefinition"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        connectors: {
            requestType: utils_1.RequestType.Get,
            returnType: "printConnectors"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "printOperations"
        },
        printers: {
            requestType: utils_1.RequestType.Get,
            returnType: "printers"
        },
        services: {
            requestType: utils_1.RequestType.Get,
            returnType: "printServices"
        },
        shares: {
            requestType: utils_1.RequestType.Get,
            returnType: "printerShares"
        },
        taskDefinitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "printTaskDefinitions"
        },
    },
    printConnector: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printConnectors: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printDocument: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        createUploadSession: {
            argNames: ["properties"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.uploadSession"
        },
    },
    printDocuments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printJob: {
        properties: [
            "documents|printDocuments|/[Name]|printDocument", "tasks|printTasks|/[Name]|printTask"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        documents: {
            requestType: utils_1.RequestType.Get,
            returnType: "printDocuments"
        },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "printTasks"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        start: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.printJobStatus"
        },
        abort: {
            argNames: ["reason"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        redirect: {
            argNames: ["destinationPrinterId", "configuration"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.printJob"
        },
    },
    printJobs: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printService: {
        properties: [
            "endpoints|printServiceEndpoints|/[Name]|printServiceEndpoint"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        endpoints: {
            requestType: utils_1.RequestType.Get,
            returnType: "printServiceEndpoints"
        },
    },
    printServices: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printServiceEndpoint: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printServiceEndpoints: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printTask: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        definition: {
            returnType: "printTaskDefinition"
        },
        trigger: {
            returnType: "printTaskTrigger"
        },
    },
    printTasks: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printTaskDefinition: {
        properties: [
            "tasks|printTasks|/[Name]|printTask"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "printTasks"
        },
    },
    printTaskDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printTaskTrigger: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        definition: {
            returnType: "printTaskDefinition"
        },
    },
    printTaskTriggers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printUsage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printUsageByPrinter: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printUsageByPrinters: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printUsageByUser: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printUsageByUsers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printer: {
        properties: [
            "connectors|printConnectors|/[Name]|printConnector", "shares|printerShares|/[Name]|printerShare", "taskTriggers|printTaskTriggers|/[Name]|printTaskTrigger"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        connectors: {
            requestType: utils_1.RequestType.Get,
            returnType: "printConnectors"
        },
        shares: {
            requestType: utils_1.RequestType.Get,
            returnType: "printerShares"
        },
        taskTriggers: {
            requestType: utils_1.RequestType.Get,
            returnType: "printTaskTriggers"
        },
        restoreFactoryDefaults: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    printers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    printerBase: {
        properties: [
            "jobs|printJobs|/[Name]|printJob"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        jobs: {
            requestType: utils_1.RequestType.Get,
            returnType: "printJobs"
        },
    },
    printerCreateOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        printer: {
            returnType: "printer"
        },
    },
    printerShare: {
        properties: [
            "allowedGroups|groups|/[Name]|group", "allowedUsers|users|/[Name]|user"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        allowedGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "groups"
        },
        allowedUsers: {
            requestType: utils_1.RequestType.Get,
            returnType: "users"
        },
        printer: {
            returnType: "printer"
        },
    },
    printerShares: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privacy: {
        properties: [
            "subjectRightsRequests|subjectRightsRequests|/[Name]|subjectRightsRequest"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        subjectRightsRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "subjectRightsRequests"
        },
    },
    privilegedAccessGroup: {
        properties: [
            "assignmentApprovals|approvals|/[Name]|approval", "assignmentScheduleInstances|privilegedAccessGroupAssignmentScheduleInstances|/[Name]|privilegedAccessGroupAssignmentScheduleInstance", "assignmentScheduleRequests|privilegedAccessGroupAssignmentScheduleRequests|/[Name]|privilegedAccessGroupAssignmentScheduleRequest", "assignmentSchedules|privilegedAccessGroupAssignmentSchedules|/[Name]|privilegedAccessGroupAssignmentSchedule", "eligibilityScheduleInstances|privilegedAccessGroupEligibilityScheduleInstances|/[Name]|privilegedAccessGroupEligibilityScheduleInstance", "eligibilityScheduleRequests|privilegedAccessGroupEligibilityScheduleRequests|/[Name]|privilegedAccessGroupEligibilityScheduleRequest", "eligibilitySchedules|privilegedAccessGroupEligibilitySchedules|/[Name]|privilegedAccessGroupEligibilitySchedule"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignmentApprovals: {
            requestType: utils_1.RequestType.Get,
            returnType: "approvals"
        },
        assignmentScheduleInstances: {
            requestType: utils_1.RequestType.Get,
            returnType: "privilegedAccessGroupAssignmentScheduleInstances"
        },
        assignmentScheduleRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "privilegedAccessGroupAssignmentScheduleRequests"
        },
        assignmentSchedules: {
            requestType: utils_1.RequestType.Get,
            returnType: "privilegedAccessGroupAssignmentSchedules"
        },
        eligibilityScheduleInstances: {
            requestType: utils_1.RequestType.Get,
            returnType: "privilegedAccessGroupEligibilityScheduleInstances"
        },
        eligibilityScheduleRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "privilegedAccessGroupEligibilityScheduleRequests"
        },
        eligibilitySchedules: {
            requestType: utils_1.RequestType.Get,
            returnType: "privilegedAccessGroupEligibilitySchedules"
        },
    },
    privilegedAccessGroupAssignmentSchedule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activatedUsing: {
            returnType: "privilegedAccessGroupEligibilitySchedule"
        },
        group: {
            returnType: "group"
        },
        principal: {
            returnType: "directoryObject"
        },
    },
    privilegedAccessGroupAssignmentSchedules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessGroupAssignmentScheduleInstance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activatedUsing: {
            returnType: "privilegedAccessGroupEligibilityScheduleInstance"
        },
        group: {
            returnType: "group"
        },
        principal: {
            returnType: "directoryObject"
        },
    },
    privilegedAccessGroupAssignmentScheduleInstances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessGroupAssignmentScheduleRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activatedUsing: {
            returnType: "privilegedAccessGroupEligibilitySchedule"
        },
        group: {
            returnType: "group"
        },
        principal: {
            returnType: "directoryObject"
        },
        targetSchedule: {
            returnType: "privilegedAccessGroupEligibilitySchedule"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    privilegedAccessGroupAssignmentScheduleRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessGroupEligibilitySchedule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        group: {
            returnType: "group"
        },
        principal: {
            returnType: "directoryObject"
        },
    },
    privilegedAccessGroupEligibilitySchedules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessGroupEligibilityScheduleInstance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        group: {
            returnType: "group"
        },
        principal: {
            returnType: "directoryObject"
        },
    },
    privilegedAccessGroupEligibilityScheduleInstances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessGroupEligibilityScheduleRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        group: {
            returnType: "group"
        },
        principal: {
            returnType: "directoryObject"
        },
        targetSchedule: {
            returnType: "privilegedAccessGroupEligibilitySchedule"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    privilegedAccessGroupEligibilityScheduleRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessRoot: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        group: {
            returnType: "privilegedAccessGroup"
        },
    },
    privilegedAccessSchedule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessScheduleInstance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    privilegedAccessScheduleRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    profileCardProperty: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    profileCardPropertys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    profilePhoto: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    profilePhotos: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    pronounsSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    protectionPolicyBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activate: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.protectionPolicyBase"
        },
        deactivate: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.protectionPolicyBase"
        },
    },
    protectionPolicyBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    protectionRuleBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        run: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.protectionRuleBase"
        },
    },
    protectionUnitBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    protectionUnitBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    provisioningObjectSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    provisioningObjectSummarys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    qna: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    rbacApplication: {
        properties: [
            "resourceNamespaces|unifiedRbacResourceNamespaces|/[Name]|unifiedRbacResourceNamespace", "roleAssignments|unifiedRoleAssignments|/[Name]|unifiedRoleAssignment", "roleDefinitions|unifiedRoleDefinitions|/[Name]|unifiedRoleDefinition", "roleAssignmentScheduleInstances|unifiedRoleAssignmentScheduleInstances|/[Name]|unifiedRoleAssignmentScheduleInstance", "roleAssignmentScheduleRequests|unifiedRoleAssignmentScheduleRequests|/[Name]|unifiedRoleAssignmentScheduleRequest", "roleAssignmentSchedules|unifiedRoleAssignmentSchedules|/[Name]|unifiedRoleAssignmentSchedule", "roleEligibilityScheduleInstances|unifiedRoleEligibilityScheduleInstances|/[Name]|unifiedRoleEligibilityScheduleInstance", "roleEligibilityScheduleRequests|unifiedRoleEligibilityScheduleRequests|/[Name]|unifiedRoleEligibilityScheduleRequest", "roleEligibilitySchedules|unifiedRoleEligibilitySchedules|/[Name]|unifiedRoleEligibilitySchedule"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resourceNamespaces: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRbacResourceNamespaces"
        },
        roleAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleAssignments"
        },
        roleDefinitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleDefinitions"
        },
        roleAssignmentScheduleInstances: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleAssignmentScheduleInstances"
        },
        roleAssignmentScheduleRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleAssignmentScheduleRequests"
        },
        roleAssignmentSchedules: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleAssignmentSchedules"
        },
        roleEligibilityScheduleInstances: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleEligibilityScheduleInstances"
        },
        roleEligibilityScheduleRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleEligibilityScheduleRequests"
        },
        roleEligibilitySchedules: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleEligibilitySchedules"
        },
    },
    recordOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    recycleBin: {
        properties: [
            "items|recycleBinItems|/[Name]|recycleBinItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        items: {
            requestType: utils_1.RequestType.Get,
            returnType: "recycleBinItems"
        },
    },
    recycleBinItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    recycleBinItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    referenceAttachment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    relation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fromTerm: {
            returnType: "term"
        },
        set: {
            returnType: "set"
        },
        toTerm: {
            returnType: "term"
        },
    },
    relyingPartyDetailedSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    remoteAssistancePartner: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        beginOnboarding: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        disconnect: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    remoteAssistancePartners: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    remoteDesktopSecurityConfiguration: {
        properties: [
            "targetDeviceGroups|targetDeviceGroups|/[Name]|targetDeviceGroup"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        targetDeviceGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "targetDeviceGroups"
        },
    },
    reportRoot: {
        properties: [
            "dailyPrintUsageByPrinter|printUsageByPrinters|/[Name]|printUsageByPrinter", "dailyPrintUsageByUser|printUsageByUsers|/[Name]|printUsageByUser", "monthlyPrintUsageByPrinter|printUsageByPrinters|/[Name]|printUsageByPrinter", "monthlyPrintUsageByUser|printUsageByUsers|/[Name]|printUsageByUser"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        authenticationMethods: {
            returnType: "authenticationMethodsRoot"
        },
        partners: {
            returnType: "partners"
        },
        dailyPrintUsageByPrinter: {
            requestType: utils_1.RequestType.Get,
            returnType: "printUsageByPrinters"
        },
        dailyPrintUsageByUser: {
            requestType: utils_1.RequestType.Get,
            returnType: "printUsageByUsers"
        },
        monthlyPrintUsageByPrinter: {
            requestType: utils_1.RequestType.Get,
            returnType: "printUsageByPrinters"
        },
        monthlyPrintUsageByUser: {
            requestType: utils_1.RequestType.Get,
            returnType: "printUsageByUsers"
        },
        security: {
            returnType: "securityReportsRoot"
        },
        deviceConfigurationDeviceActivity: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        deviceConfigurationUserActivity: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        managedDeviceEnrollmentFailureDetails: {
            argNames: ["skip", "top", "filter", "skipToken"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        managedDeviceEnrollmentTopFailures: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365ActivationCounts: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365ActivationsUserCounts: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365ActivationsUserDetail: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365ActiveUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365ActiveUserDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365GroupsActivityCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365GroupsActivityDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365GroupsActivityFileCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365GroupsActivityGroupCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365GroupsActivityStorage: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOffice365ServicesUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOneDriveActivityFileCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOneDriveActivityUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOneDriveActivityUserDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOneDriveUsageAccountCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOneDriveUsageAccountDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOneDriveUsageFileCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getOneDriveUsageStorage: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointActivityFileCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointActivityPages: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointActivityUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointActivityUserDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointSiteUsageDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointSiteUsageFileCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointSiteUsagePages: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointSiteUsageSiteCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSharePointSiteUsageStorage: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessActivityCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessActivityUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessActivityUserDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessDeviceUsageDistributionUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessDeviceUsageUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessDeviceUsageUserDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessOrganizerActivityCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessOrganizerActivityMinuteCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessOrganizerActivityUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessParticipantActivityCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessParticipantActivityMinuteCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessParticipantActivityUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessPeerToPeerActivityCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessPeerToPeerActivityMinuteCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getSkypeForBusinessPeerToPeerActivityUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerActivityCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerActivityUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerActivityUserDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerDeviceUsageDistributionUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerDeviceUsageUserCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerDeviceUsageUserDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerGroupsActivityCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerGroupsActivityDetail: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getYammerGroupsActivityGroupCounts: {
            argNames: ["period"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.report"
        },
        getGroupArchivedPrintJobs: {
            argNames: ["groupId", "startDateTime", "endDateTime"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.archivedPrintJob[]"
        },
        getPrinterArchivedPrintJobs: {
            argNames: ["printerId", "startDateTime", "endDateTime"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.archivedPrintJob[]"
        },
        getUserArchivedPrintJobs: {
            argNames: ["userId", "startDateTime", "endDateTime"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.archivedPrintJob[]"
        },
    },
    request: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    resellerDelegatedAdminRelationship: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    resourceOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    resourceOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    resourceSpecificPermissionGrant: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    resourceSpecificPermissionGrants: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    restoreArtifactBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        restorePoint: {
            returnType: "restorePoint"
        },
    },
    restorePoint: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        protectionUnit: {
            returnType: "protectionUnitBase"
        },
    },
    restorePoints: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    restoreSessionBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activate: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.restoreSessionBase"
        },
    },
    restoreSessionBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    retentionEvent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        retentionEventType: {
            returnType: "retentionEventType"
        },
    },
    retentionEventType: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    retentionLabel: {
        properties: [
            "dispositionReviewStages|dispositionReviewStages|/[Name]|dispositionReviewStage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        descriptors: {
            returnType: "filePlanDescriptor"
        },
        dispositionReviewStages: {
            requestType: utils_1.RequestType.Get,
            returnType: "dispositionReviewStages"
        },
        retentionEventType: {
            returnType: "retentionEventType"
        },
    },
    richLongRunningOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    richLongRunningOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskDetection: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskDetections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskyServicePrincipal: {
        properties: [
            "history|riskyServicePrincipalHistoryItems|/[Name]|riskyServicePrincipalHistoryItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        history: {
            requestType: utils_1.RequestType.Get,
            returnType: "riskyServicePrincipalHistoryItems"
        },
    },
    riskyServicePrincipals: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskyServicePrincipalHistoryItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskyServicePrincipalHistoryItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskyUser: {
        properties: [
            "history|riskyUserHistoryItems|/[Name]|riskyUserHistoryItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        history: {
            requestType: utils_1.RequestType.Get,
            returnType: "riskyUserHistoryItems"
        },
    },
    riskyUsers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskyUserHistoryItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    riskyUserHistoryItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    roleAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        roleDefinition: {
            returnType: "roleDefinition"
        },
    },
    roleAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    roleDefinition: {
        properties: [
            "roleAssignments|roleAssignments|/[Name]|roleAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        roleAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "roleAssignments"
        },
    },
    roleDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    roleManagement: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        directory: {
            returnType: "rbacApplication"
        },
        entitlementManagement: {
            returnType: "rbacApplication"
        },
    },
    room: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    rooms: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    roomList: {
        properties: [
            "rooms|rooms|/[Name]|room"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        rooms: {
            requestType: utils_1.RequestType.Get,
            returnType: "rooms"
        },
    },
    run: {
        properties: [
            "taskProcessingResults|taskProcessingResults|/[Name]|taskProcessingResult", "userProcessingResults|userProcessingResults|/[Name]|userProcessingResult"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        taskProcessingResults: {
            requestType: utils_1.RequestType.Get,
            returnType: "taskProcessingResults"
        },
        userProcessingResults: {
            requestType: utils_1.RequestType.Get,
            returnType: "userProcessingResults"
        },
    },
    runningOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    samlOrWsFedExternalDomainFederation: {
        properties: [
            "domains|externalDomainNames|/[Name]|externalDomainName"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        domains: {
            requestType: utils_1.RequestType.Get,
            returnType: "externalDomainNames"
        },
    },
    samlOrWsFedProvider: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    schedule: {
        properties: [
            "offerShiftRequests|offerShiftRequests|/[Name]|offerShiftRequest", "openShiftChangeRequests|openShiftChangeRequests|/[Name]|openShiftChangeRequest", "openShifts|openShifts|/[Name]|openShift", "schedulingGroups|schedulingGroups|/[Name]|schedulingGroup", "shifts|shifts|/[Name]|shift", "swapShiftsChangeRequests|swapShiftsChangeRequests|/[Name]|swapShiftsChangeRequest", "timeOffReasons|timeOffReasons|/[Name]|timeOffReason", "timeOffRequests|timeOffRequests|/[Name]|timeOffRequest", "timesOff|timeOffs|/[Name]|timeOff"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        dayNotes: {
            requestType: utils_1.RequestType.Get,
            returnType: "dayNotes"
        },
        offerShiftRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "offerShiftRequests"
        },
        openShiftChangeRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "openShiftChangeRequests"
        },
        openShifts: {
            requestType: utils_1.RequestType.Get,
            returnType: "openShifts"
        },
        schedulingGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "schedulingGroups"
        },
        shifts: {
            requestType: utils_1.RequestType.Get,
            returnType: "shifts"
        },
        swapShiftsChangeRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "swapShiftsChangeRequests"
        },
        timeCards: {
            requestType: utils_1.RequestType.Get,
            returnType: "timeCards"
        },
        timeOffReasons: {
            requestType: utils_1.RequestType.Get,
            returnType: "timeOffReasons"
        },
        timeOffRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "timeOffRequests"
        },
        timesOff: {
            requestType: utils_1.RequestType.Get,
            returnType: "timeOffs"
        },
        share: {
            argNames: ["notifyTeam", "startDateTime", "endDateTime"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    scheduleChangeRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        decline: {
            argNames: ["message"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        approve: {
            argNames: ["message"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    schedulingGroup: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    schedulingGroups: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    schema: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    schemaExtension: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    scopedRoleMembership: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    scopedRoleMemberships: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    search: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    searchAnswer: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    searchEntity: {
        properties: [
            "acronyms|acronyms|/[Name]|acronym", "bookmarks|bookmarks|/[Name]|bookmark", "qnas|qnas|/[Name]|qna"
        ],
        acronyms: {
            requestType: utils_1.RequestType.Get,
            returnType: "acronyms"
        },
        bookmarks: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookmarks"
        },
        qnas: {
            requestType: utils_1.RequestType.Get,
            returnType: "qnas"
        },
        query: {
            argNames: ["requests"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.searchResponse[]"
        },
    },
    sectionGroup: {
        properties: [
            "sectionGroups|sectionGroups|/[Name]|sectionGroup", "sections|onenoteSections|/[Name]|onenoteSection"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        parentNotebook: {
            returnType: "notebook"
        },
        parentSectionGroup: {
            returnType: "sectionGroup"
        },
        sectionGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "sectionGroups"
        },
        sections: {
            requestType: utils_1.RequestType.Get,
            returnType: "onenoteSections"
        },
    },
    sectionGroups: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    secureScore: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    secureScores: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    secureScoreControlProfile: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    secureScoreControlProfiles: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    security: {
        properties: [
            "subjectRightsRequests|subjectRightsRequests|/[Name]|subjectRightsRequest", "alerts_v2|alerts|/[Name]|alert", "incidents|incidents|/[Name]|incident", "alerts|alerts|/[Name]|alert", "secureScoreControlProfiles|secureScoreControlProfiles|/[Name]|secureScoreControlProfile", "secureScores|secureScores|/[Name]|secureScore"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        subjectRightsRequests: {
            requestType: utils_1.RequestType.Get,
            returnType: "subjectRightsRequests"
        },
        cases: {
            returnType: "casesRoot"
        },
        identities: {
            returnType: "identityContainer"
        },
        alerts_v2: {
            requestType: utils_1.RequestType.Get,
            returnType: "alerts"
        },
        incidents: {
            requestType: utils_1.RequestType.Get,
            returnType: "incidents"
        },
        attackSimulation: {
            returnType: "attackSimulationRoot"
        },
        labels: {
            returnType: "labelsRoot"
        },
        triggers: {
            returnType: "triggersRoot"
        },
        triggerTypes: {
            returnType: "triggerTypesRoot"
        },
        alerts: {
            requestType: utils_1.RequestType.Get,
            returnType: "alerts"
        },
        secureScoreControlProfiles: {
            requestType: utils_1.RequestType.Get,
            returnType: "secureScoreControlProfiles"
        },
        secureScores: {
            requestType: utils_1.RequestType.Get,
            returnType: "secureScores"
        },
        threatIntelligence: {
            returnType: "threatIntelligence"
        },
        runHuntingQuery: {
            argNames: ["query", "timespan"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.huntingQueryResults"
        },
    },
    securityReportsRoot: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        getAttackSimulationRepeatOffenders: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.attackSimulationRepeatOffender[]"
        },
        getAttackSimulationSimulationUserCoverage: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.attackSimulationSimulationUserCoverage[]"
        },
        getAttackSimulationTrainingUserCoverage: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.attackSimulationTrainingUserCoverage[]"
        },
    },
    segment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sendDtmfTonesOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sensor: {
        properties: [
            "healthIssues|healthIssues|/[Name]|healthIssue"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        healthIssues: {
            requestType: utils_1.RequestType.Get,
            returnType: "healthIssues"
        },
    },
    serviceAnnouncement: {
        properties: [
            "healthOverviews|serviceHealths|/[Name]|serviceHealth", "issues|serviceHealthIssues|/[Name]|serviceHealthIssue", "messages|serviceUpdateMessages|/[Name]|serviceUpdateMessage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        healthOverviews: {
            requestType: utils_1.RequestType.Get,
            returnType: "serviceHealths"
        },
        issues: {
            requestType: utils_1.RequestType.Get,
            returnType: "serviceHealthIssues"
        },
        messages: {
            requestType: utils_1.RequestType.Get,
            returnType: "serviceUpdateMessages"
        },
    },
    serviceAnnouncementAttachment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceAnnouncementAttachments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceAnnouncementBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activate: {
            argNames: ["effectiveDateTime"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.serviceApp"
        },
        deactivate: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.serviceApp"
        },
    },
    serviceApps: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceHealth: {
        properties: [
            "issues|serviceHealthIssues|/[Name]|serviceHealthIssue"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        issues: {
            requestType: utils_1.RequestType.Get,
            returnType: "serviceHealthIssues"
        },
    },
    serviceHealths: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceHealthIssue: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        incidentReport: {
            requestType: utils_1.RequestType.Get,
            returnType: "any"
        },
    },
    serviceHealthIssues: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    servicePrincipal: {
        properties: [
            "appManagementPolicies|appManagementPolicys|/[Name]|appManagementPolicy", "appRoleAssignedTo|appRoleAssignments|/[Name]|appRoleAssignment", "appRoleAssignments|appRoleAssignments|/[Name]|appRoleAssignment", "claimsMappingPolicies|claimsMappingPolicys|/[Name]|claimsMappingPolicy", "createdObjects|directoryObjects|/[Name]|directoryObject", "delegatedPermissionClassifications|delegatedPermissionClassifications|/[Name]|delegatedPermissionClassification", "endpoints|endpoints|/[Name]|endpoint", "federatedIdentityCredentials|federatedIdentityCredentials|/[Name]|federatedIdentityCredential", "homeRealmDiscoveryPolicies|homeRealmDiscoveryPolicys|/[Name]|homeRealmDiscoveryPolicy", "memberOf|directoryObjects|/[Name]|directoryObject", "oauth2PermissionGrants|oAuth2PermissionGrants|/[Name]|oAuth2PermissionGrant", "ownedObjects|directoryObjects|/[Name]|directoryObject", "owners|directoryObjects|/[Name]|directoryObject", "tokenIssuancePolicies|tokenIssuancePolicys|/[Name]|tokenIssuancePolicy", "tokenLifetimePolicies|tokenLifetimePolicys|/[Name]|tokenLifetimePolicy", "transitiveMemberOf|directoryObjects|/[Name]|directoryObject"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appManagementPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "appManagementPolicys"
        },
        appRoleAssignedTo: {
            requestType: utils_1.RequestType.Get,
            returnType: "appRoleAssignments"
        },
        appRoleAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "appRoleAssignments"
        },
        claimsMappingPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "claimsMappingPolicys"
        },
        createdObjects: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        delegatedPermissionClassifications: {
            requestType: utils_1.RequestType.Get,
            returnType: "delegatedPermissionClassifications"
        },
        endpoints: {
            requestType: utils_1.RequestType.Get,
            returnType: "endpoints"
        },
        federatedIdentityCredentials: {
            requestType: utils_1.RequestType.Get,
            returnType: "federatedIdentityCredentials"
        },
        homeRealmDiscoveryPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "homeRealmDiscoveryPolicys"
        },
        memberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        oauth2PermissionGrants: {
            requestType: utils_1.RequestType.Get,
            returnType: "oAuth2PermissionGrants"
        },
        ownedObjects: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        owners: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        remoteDesktopSecurityConfiguration: {
            returnType: "remoteDesktopSecurityConfiguration"
        },
        tokenIssuancePolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "tokenIssuancePolicys"
        },
        tokenLifetimePolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "tokenLifetimePolicys"
        },
        transitiveMemberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        synchronization: {
            returnType: "synchronization"
        },
        addKey: {
            argNames: ["keyCredential", "passwordCredential", "proof"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.keyCredential"
        },
        addPassword: {
            argNames: ["passwordCredential"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.passwordCredential"
        },
        removeKey: {
            argNames: ["keyId", "proof"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        removePassword: {
            argNames: ["keyId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        addTokenSigningCertificate: {
            argNames: ["displayName", "endDateTime"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.selfSignedCertificate"
        },
    },
    servicePrincipalRiskDetection: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    servicePrincipalRiskDetections: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceStorageQuotaBreakdown: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceStorageQuotaBreakdowns: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    serviceUpdateMessage: {
        properties: [
            "attachments|serviceAnnouncementAttachments|/[Name]|serviceAnnouncementAttachment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        attachments: {
            requestType: utils_1.RequestType.Get,
            returnType: "serviceAnnouncementAttachments"
        },
    },
    serviceUpdateMessages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    session: {
        properties: [
            "segments|segments|/[Name]|segment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        segments: {
            requestType: utils_1.RequestType.Get,
            returnType: "segments"
        },
    },
    set: {
        properties: [
            "children|terms|/[Name]|term", "relations|relations|/[Name]|relation", "terms|terms|/[Name]|term"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        children: {
            requestType: utils_1.RequestType.Get,
            returnType: "terms"
        },
        parentGroup: {
            returnType: "group"
        },
        relations: {
            requestType: utils_1.RequestType.Get,
            returnType: "relations"
        },
        terms: {
            requestType: utils_1.RequestType.Get,
            returnType: "terms"
        },
    },
    settingStateDeviceSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    settingStateDeviceSummarys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sharePointProtectionPolicy: {
        properties: [
            "siteInclusionRules|siteProtectionRules|/[Name]|siteProtectionRule", "siteProtectionUnits|siteProtectionUnits|/[Name]|siteProtectionUnit"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        siteInclusionRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "siteProtectionRules"
        },
        siteProtectionUnits: {
            requestType: utils_1.RequestType.Get,
            returnType: "siteProtectionUnits"
        },
    },
    sharePointProtectionPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sharePointRestoreSession: {
        properties: [
            "siteRestoreArtifacts|siteRestoreArtifacts|/[Name]|siteRestoreArtifact"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        siteRestoreArtifacts: {
            requestType: utils_1.RequestType.Get,
            returnType: "siteRestoreArtifacts"
        },
    },
    sharePointRestoreSessions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sharedDriveItem: {
        properties: [
            "items|driveItems|/[Name]|driveItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        driveItem: {
            returnType: "driveItem"
        },
        items: {
            requestType: utils_1.RequestType.Get,
            returnType: "driveItems"
        },
        list: {
            returnType: "list"
        },
        listItem: {
            returnType: "listItem"
        },
        permission: {
            returnType: "permission"
        },
        root: {
            returnType: "driveItem"
        },
        site: {
            returnType: "site"
        },
    },
    sharedInsight: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        lastSharedMethod: {
            returnType: "entity"
        },
        resource: {
            returnType: "entity"
        },
    },
    sharedInsights: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sharedPCConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sharedWithChannelTeamInfo: {
        properties: [
            "allowedMembers|conversationMembers|/[Name]|conversationMember"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        allowedMembers: {
            requestType: utils_1.RequestType.Get,
            returnType: "conversationMembers"
        },
    },
    sharedWithChannelTeamInfos: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    sharepoint: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        settings: {
            returnType: "sharepointSettings"
        },
    },
    sharepointSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    shift: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    shifts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    shiftPreferences: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    signIn: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    signIns: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    simulation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        landingPage: {
            returnType: "landingPage"
        },
        loginPage: {
            returnType: "loginPage"
        },
        payload: {
            returnType: "payload"
        },
    },
    simulations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    simulationAutomation: {
        properties: [
            "runs|simulationAutomationRuns|/[Name]|simulationAutomationRun"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        runs: {
            requestType: utils_1.RequestType.Get,
            returnType: "simulationAutomationRuns"
        },
    },
    simulationAutomations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    simulationAutomationRun: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    simulationAutomationRuns: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    singleValueLegacyExtendedProperty: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    singleValueLegacyExtendedPropertys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    site: {
        properties: [
            "columns|columnDefinitions|/[Name]|columnDefinition", "contentTypes|contentTypes|/[Name]|contentType", "drives|drives|/[Name]|drive", "externalColumns|columnDefinitions|/[Name]|columnDefinition", "items|baseItems|/[Name]|baseItem", "lists|lists|/[Name]|list", "operations|richLongRunningOperations|/[Name]|richLongRunningOperation", "pages|baseSitePages|/[Name]|baseSitePage", "permissions|permissions|/[Name]|permission", "sites|sites|/[Name]|site", "termStores|stores|/[Name]|store"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        analytics: {
            returnType: "itemAnalytics"
        },
        columns: {
            requestType: utils_1.RequestType.Get,
            returnType: "columnDefinitions"
        },
        contentTypes: {
            requestType: utils_1.RequestType.Get,
            returnType: "contentTypes"
        },
        drive: {
            returnType: "drive"
        },
        drives: {
            requestType: utils_1.RequestType.Get,
            returnType: "drives"
        },
        externalColumns: {
            requestType: utils_1.RequestType.Get,
            returnType: "columnDefinitions"
        },
        items: {
            requestType: utils_1.RequestType.Get,
            returnType: "baseItems"
        },
        lists: {
            requestType: utils_1.RequestType.Get,
            returnType: "lists"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "richLongRunningOperations"
        },
        pages: {
            requestType: utils_1.RequestType.Get,
            returnType: "baseSitePages"
        },
        permissions: {
            requestType: utils_1.RequestType.Get,
            returnType: "permissions"
        },
        sites: {
            requestType: utils_1.RequestType.Get,
            returnType: "sites"
        },
        termStore: {
            returnType: "store"
        },
        termStores: {
            requestType: utils_1.RequestType.Get,
            returnType: "stores"
        },
        onenote: {
            returnType: "onenote"
        },
        getActivitiesByInterval: {
            argNames: ["startDateTime", "endDateTime", "interval"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.itemActivityStat[]"
        },
        getApplicableContentTypesForList: {
            argNames: ["listId"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.contentType[]"
        },
        getByPath: {
            argNames: ["path"],
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.site"
        },
    },
    sitePage: {
        properties: [
            "webParts|webParts|/[Name]|webPart"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        canvasLayout: {
            returnType: "canvasLayout"
        },
        webParts: {
            requestType: utils_1.RequestType.Get,
            returnType: "webParts"
        },
        publish: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        getWebPartsByPosition: {
            argNames: ["webPartIndex", "horizontalSectionId", "isInVerticalSection", "columnId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.webPart[]"
        },
    },
    siteProtectionRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    siteProtectionRules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    siteProtectionUnit: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    siteProtectionUnits: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    siteRestoreArtifact: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    siteRestoreArtifacts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    siteSource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        site: {
            returnType: "site"
        },
    },
    skypeForBusinessUserConversationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    skypeUserConversationMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    smsAuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|smsAuthenticationMethodTargets|/[Name]|smsAuthenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "smsAuthenticationMethodTargets"
        },
    },
    smsAuthenticationMethodTarget: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    smsAuthenticationMethodTargets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    socialIdentityProvider: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    softwareOathAuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    softwareOathAuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    softwareOathAuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|authenticationMethodTargets|/[Name]|authenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodTargets"
        },
    },
    softwareUpdateStatusSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    solutionsRoot: {
        properties: [
            "bookingBusinesses|bookingBusinesss|/[Name]|bookingBusiness", "bookingCurrencies|bookingCurrencys|/[Name]|bookingCurrency"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        bookingBusinesses: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingBusinesss"
        },
        bookingCurrencies: {
            requestType: utils_1.RequestType.Get,
            returnType: "bookingCurrencys"
        },
        backupRestore: {
            returnType: "backupRestoreRoot"
        },
        virtualEvents: {
            returnType: "virtualEventsRoot"
        },
    },
    sslCertificate: {
        properties: [
            "relatedHosts|hosts|/[Name]|host"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        relatedHosts: {
            requestType: utils_1.RequestType.Get,
            returnType: "hosts"
        },
    },
    standardWebPart: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    startHoldMusicOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    stopHoldMusicOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    storage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fileStorage: {
            returnType: "fileStorage"
        },
        settings: {
            returnType: "storageSettings"
        },
    },
    storageQuotaBreakdown: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    storageSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        quota: {
            returnType: "unifiedStorageQuota"
        },
    },
    store: {
        properties: [
            "groups|groups|/[Name]|group", "sets|sets|/[Name]|set"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        groups: {
            requestType: utils_1.RequestType.Get,
            returnType: "groups"
        },
        sets: {
            requestType: utils_1.RequestType.Get,
            returnType: "sets"
        },
    },
    stsPolicy: {
        properties: [
            "appliesTo|directoryObjects|/[Name]|directoryObject"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appliesTo: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
    },
    subcategoryTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    subdomain: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        host: {
            returnType: "host"
        },
    },
    subjectRightsRequest: {
        properties: [
            "approvers|users|/[Name]|user", "collaborators|users|/[Name]|user", "notes|authoredNotes|/[Name]|authoredNote"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        approvers: {
            requestType: utils_1.RequestType.Get,
            returnType: "users"
        },
        collaborators: {
            requestType: utils_1.RequestType.Get,
            returnType: "users"
        },
        notes: {
            requestType: utils_1.RequestType.Get,
            returnType: "authoredNotes"
        },
        team: {
            returnType: "team"
        },
        getFinalAttachment: {
            requestType: utils_1.RequestType.Get,
            returnType: "any"
        },
        getFinalReport: {
            requestType: utils_1.RequestType.Get,
            returnType: "any"
        },
    },
    subjectRightsRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    subscribeToToneOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    subscribedSku: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    subscription: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        reauthorize: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    subscriptions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    swapShiftsChangeRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    swapShiftsChangeRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    synchronization: {
        properties: [
            "jobs|synchronizationJobs|/[Name]|synchronizationJob", "templates|synchronizationTemplates|/[Name]|synchronizationTemplate"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        jobs: {
            requestType: utils_1.RequestType.Get,
            returnType: "synchronizationJobs"
        },
        templates: {
            requestType: utils_1.RequestType.Get,
            returnType: "synchronizationTemplates"
        },
        acquireAccessToken: {
            argNames: ["credentials"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    synchronizationJob: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        bulkUpload: {
            returnType: "bulkUpload"
        },
        schema: {
            returnType: "synchronizationSchema"
        },
        pause: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        provisionOnDemand: {
            argNames: ["parameters"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.stringKeyStringValuePair"
        },
        restart: {
            argNames: ["criteria"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        start: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        validateCredentials: {
            argNames: ["applicationIdentifier", "templateId", "useSavedCredentials", "credentials"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    synchronizationJobs: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    synchronizationSchema: {
        properties: [
            "directories|directoryDefinitions|/[Name]|directoryDefinition"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        directories: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryDefinitions"
        },
        parseExpression: {
            argNames: ["expression", "testInputObject", "targetAttributeDefinition"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.parseExpressionResponse"
        },
        filterOperators: {
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.filterOperatorSchema[]"
        },
        functions: {
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.attributeMappingFunctionSchema[]"
        },
    },
    synchronizationTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        schema: {
            returnType: "synchronizationSchema"
        },
    },
    synchronizationTemplates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    tag: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    targetDeviceGroup: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    targetDeviceGroups: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    targetedManagedAppConfiguration: {
        properties: [
            "apps|managedMobileApps|/[Name]|managedMobileApp", "assignments|targetedManagedAppPolicyAssignments|/[Name]|targetedManagedAppPolicyAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        apps: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedMobileApps"
        },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "targetedManagedAppPolicyAssignments"
        },
        deploymentSummary: {
            returnType: "managedAppPolicyDeploymentSummary"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        targetApps: {
            argNames: ["apps", "appGroupType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    targetedManagedAppConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    targetedManagedAppPolicyAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    targetedManagedAppPolicyAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    targetedManagedAppProtection: {
        properties: [
            "assignments|targetedManagedAppPolicyAssignments|/[Name]|targetedManagedAppPolicyAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "targetedManagedAppPolicyAssignments"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        targetApps: {
            argNames: ["apps", "appGroupType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    task: {
        properties: [
            "taskProcessingResults|taskProcessingResults|/[Name]|taskProcessingResult"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        taskProcessingResults: {
            requestType: utils_1.RequestType.Get,
            returnType: "taskProcessingResults"
        },
    },
    taskDefinition: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    taskFileAttachment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    taskProcessingResult: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        subject: {
            returnType: "user"
        },
        task: {
            returnType: "task"
        },
    },
    taskReport: {
        properties: [
            "taskProcessingResults|taskProcessingResults|/[Name]|taskProcessingResult"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        task: {
            returnType: "task"
        },
        taskDefinition: {
            returnType: "taskDefinition"
        },
        taskProcessingResults: {
            requestType: utils_1.RequestType.Get,
            returnType: "taskProcessingResults"
        },
    },
    team: {
        properties: [
            "allChannels|channels|/[Name]|channel", "channels|channels|/[Name]|channel", "incomingChannels|channels|/[Name]|channel", "installedApps|teamsAppInstallations|/[Name]|teamsAppInstallation", "members|conversationMembers|/[Name]|conversationMember", "operations|teamsAsyncOperations|/[Name]|teamsAsyncOperation", "permissionGrants|resourceSpecificPermissionGrants|/[Name]|resourceSpecificPermissionGrant", "tags|teamworkTags|/[Name]|teamworkTag"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        allChannels: {
            requestType: utils_1.RequestType.Get,
            returnType: "channels"
        },
        channels: {
            requestType: utils_1.RequestType.Get,
            returnType: "channels"
        },
        group: {
            returnType: "group"
        },
        incomingChannels: {
            requestType: utils_1.RequestType.Get,
            returnType: "channels"
        },
        installedApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamsAppInstallations"
        },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "conversationMembers"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamsAsyncOperations"
        },
        permissionGrants: {
            requestType: utils_1.RequestType.Get,
            returnType: "resourceSpecificPermissionGrants"
        },
        photo: {
            returnType: "profilePhoto"
        },
        primaryChannel: {
            returnType: "channel"
        },
        tags: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamworkTags"
        },
        template: {
            returnType: "teamsTemplate"
        },
        schedule: {
            returnType: "schedule"
        },
        archive: {
            argNames: ["shouldSetSpoSiteReadOnlyForMembers"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unarchive: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        completeMigration: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        clone: {
            argNames: ["displayName", "description", "mailNickname", "classification", "visibility", "partsToClone"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        sendActivityNotification: {
            argNames: ["topic", "activityType", "chainId", "previewText", "teamsAppId", "templateParameters", "recipient"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    teams: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamInfo: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        team: {
            returnType: "team"
        },
    },
    teamsApp: {
        properties: [
            "appDefinitions|teamsAppDefinitions|/[Name]|teamsAppDefinition"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appDefinitions: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamsAppDefinitions"
        },
    },
    teamsApps: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamsAppDefinition: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        bot: {
            returnType: "teamworkBot"
        },
    },
    teamsAppDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamsAppInstallation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        teamsApp: {
            returnType: "teamsApp"
        },
        teamsAppDefinition: {
            returnType: "teamsAppDefinition"
        },
        upgrade: {
            argNames: ["consentedPermissionSet"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    teamsAppInstallations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamsAppSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamsAsyncOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamsAsyncOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamsTab: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        teamsApp: {
            returnType: "teamsApp"
        },
    },
    teamsTabs: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamsTemplate: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamwork: {
        properties: [
            "workforceIntegrations|workforceIntegrations|/[Name]|workforceIntegration", "deletedChats|deletedChats|/[Name]|deletedChat", "deletedTeams|deletedTeams|/[Name]|deletedTeam"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        workforceIntegrations: {
            requestType: utils_1.RequestType.Get,
            returnType: "workforceIntegrations"
        },
        deletedChats: {
            requestType: utils_1.RequestType.Get,
            returnType: "deletedChats"
        },
        deletedTeams: {
            requestType: utils_1.RequestType.Get,
            returnType: "deletedTeams"
        },
        teamsAppSettings: {
            returnType: "teamsAppSettings"
        },
        sendActivityNotificationToRecipients: {
            argNames: ["topic", "activityType", "chainId", "previewText", "teamsAppId", "templateParameters", "recipients"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    teamworkBot: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamworkHostedContent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamworkTag: {
        properties: [
            "members|teamworkTagMembers|/[Name]|teamworkTagMember"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        members: {
            requestType: utils_1.RequestType.Get,
            returnType: "teamworkTagMembers"
        },
    },
    teamworkTags: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamworkTagMember: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    teamworkTagMembers: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    telecomExpenseManagementPartner: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    telecomExpenseManagementPartners: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    temporaryAccessPassAuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    temporaryAccessPassAuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    temporaryAccessPassAuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|authenticationMethodTargets|/[Name]|authenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodTargets"
        },
    },
    tenantAppManagementPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    tenantRelationship: {
        properties: [
            "delegatedAdminCustomers|delegatedAdminCustomers|/[Name]|delegatedAdminCustomer", "delegatedAdminRelationships|delegatedAdminRelationships|/[Name]|delegatedAdminRelationship"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        multiTenantOrganization: {
            returnType: "multiTenantOrganization"
        },
        delegatedAdminCustomers: {
            requestType: utils_1.RequestType.Get,
            returnType: "delegatedAdminCustomers"
        },
        delegatedAdminRelationships: {
            requestType: utils_1.RequestType.Get,
            returnType: "delegatedAdminRelationships"
        },
        findTenantInformationByDomainName: {
            argNames: ["domainName"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.tenantInformation"
        },
        findTenantInformationByTenantId: {
            argNames: ["tenantId"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.tenantInformation"
        },
    },
    term: {
        properties: [
            "children|terms|/[Name]|term", "relations|relations|/[Name]|relation"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        children: {
            requestType: utils_1.RequestType.Get,
            returnType: "terms"
        },
        relations: {
            requestType: utils_1.RequestType.Get,
            returnType: "relations"
        },
        set: {
            returnType: "set"
        },
    },
    termsAndConditions: {
        properties: [
            "acceptanceStatuses|termsAndConditionsAcceptanceStatuss|/[Name]|termsAndConditionsAcceptanceStatus", "assignments|termsAndConditionsAssignments|/[Name]|termsAndConditionsAssignment"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        acceptanceStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "termsAndConditionsAcceptanceStatuss"
        },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "termsAndConditionsAssignments"
        },
    },
    termsAndConditionss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    termsAndConditionsAcceptanceStatus: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        termsAndConditions: {
            returnType: "termsAndConditions"
        },
    },
    termsAndConditionsAcceptanceStatuss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    termsAndConditionsAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    termsAndConditionsAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    termsOfUseContainer: {
        properties: [
            "agreementAcceptances|agreementAcceptances|/[Name]|agreementAcceptance", "agreements|agreements|/[Name]|agreement"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        agreementAcceptances: {
            requestType: utils_1.RequestType.Get,
            returnType: "agreementAcceptances"
        },
        agreements: {
            requestType: utils_1.RequestType.Get,
            returnType: "agreements"
        },
    },
    textWebPart: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    threatAssessmentRequest: {
        properties: [
            "results|threatAssessmentResults|/[Name]|threatAssessmentResult"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        results: {
            requestType: utils_1.RequestType.Get,
            returnType: "threatAssessmentResults"
        },
    },
    threatAssessmentRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    threatAssessmentResult: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    threatAssessmentResults: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    threatIntelligence: {
        properties: [
            "articleIndicators|articleIndicators|/[Name]|articleIndicator", "articles|articles|/[Name]|article", "hostComponents|hostComponents|/[Name]|hostComponent", "hostCookies|hostCookies|/[Name]|hostCookie", "hostPairs|hostPairs|/[Name]|hostPair", "hostPorts|hostPorts|/[Name]|hostPort", "hosts|hosts|/[Name]|host", "hostSslCertificates|hostSslCertificates|/[Name]|hostSslCertificate", "hostTrackers|hostTrackers|/[Name]|hostTracker", "intelligenceProfileIndicators|intelligenceProfileIndicators|/[Name]|intelligenceProfileIndicator", "intelProfiles|intelligenceProfiles|/[Name]|intelligenceProfile", "passiveDnsRecords|passiveDnsRecords|/[Name]|passiveDnsRecord", "sslCertificates|sslCertificates|/[Name]|sslCertificate", "subdomains|subdomains|/[Name]|subdomain", "vulnerabilities|vulnerabilitys|/[Name]|vulnerability", "whoisHistoryRecords|whoisHistoryRecords|/[Name]|whoisHistoryRecord", "whoisRecords|whoisRecords|/[Name]|whoisRecord"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        articleIndicators: {
            requestType: utils_1.RequestType.Get,
            returnType: "articleIndicators"
        },
        articles: {
            requestType: utils_1.RequestType.Get,
            returnType: "articles"
        },
        hostComponents: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostComponents"
        },
        hostCookies: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostCookies"
        },
        hostPairs: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostPairs"
        },
        hostPorts: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostPorts"
        },
        hosts: {
            requestType: utils_1.RequestType.Get,
            returnType: "hosts"
        },
        hostSslCertificates: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostSslCertificates"
        },
        hostTrackers: {
            requestType: utils_1.RequestType.Get,
            returnType: "hostTrackers"
        },
        intelligenceProfileIndicators: {
            requestType: utils_1.RequestType.Get,
            returnType: "intelligenceProfileIndicators"
        },
        intelProfiles: {
            requestType: utils_1.RequestType.Get,
            returnType: "intelligenceProfiles"
        },
        passiveDnsRecords: {
            requestType: utils_1.RequestType.Get,
            returnType: "passiveDnsRecords"
        },
        sslCertificates: {
            requestType: utils_1.RequestType.Get,
            returnType: "sslCertificates"
        },
        subdomains: {
            requestType: utils_1.RequestType.Get,
            returnType: "subdomains"
        },
        vulnerabilities: {
            requestType: utils_1.RequestType.Get,
            returnType: "vulnerabilitys"
        },
        whoisHistoryRecords: {
            requestType: utils_1.RequestType.Get,
            returnType: "whoisHistoryRecords"
        },
        whoisRecords: {
            requestType: utils_1.RequestType.Get,
            returnType: "whoisRecords"
        },
    },
    thumbnailSet: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    thumbnailSets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    timeCard: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        clockOut: {
            argNames: ["isAtApprovedLocation", "notes"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.timeCard"
        },
        confirm: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.timeCard"
        },
        endBreak: {
            argNames: ["isAtApprovedLocation", "notes"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.timeCard"
        },
        startBreak: {
            argNames: ["isAtApprovedLocation", "notes"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.timeCard"
        },
    },
    timeCards: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    timeOff: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    timeOffs: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    timeOffReason: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    timeOffReasons: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    timeOffRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    timeOffRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    todo: {
        properties: [
            "lists|todoTaskLists|/[Name]|todoTaskList"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        lists: {
            requestType: utils_1.RequestType.Get,
            returnType: "todoTaskLists"
        },
    },
    todoTask: {
        properties: [
            "attachments|attachmentBases|/[Name]|attachmentBase", "attachmentSessions|attachmentSessions|/[Name]|attachmentSession", "checklistItems|checklistItems|/[Name]|checklistItem", "extensions|extensions|/[Name]|extension", "linkedResources|linkedResources|/[Name]|linkedResource"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        attachments: {
            requestType: utils_1.RequestType.Get,
            returnType: "attachmentBases"
        },
        attachmentSessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "attachmentSessions"
        },
        checklistItems: {
            requestType: utils_1.RequestType.Get,
            returnType: "checklistItems"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        linkedResources: {
            requestType: utils_1.RequestType.Get,
            returnType: "linkedResources"
        },
    },
    todoTasks: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    todoTaskList: {
        properties: [
            "extensions|extensions|/[Name]|extension", "tasks|todoTasks|/[Name]|todoTask"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "todoTasks"
        },
    },
    todoTaskLists: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    tokenIssuancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    tokenIssuancePolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    tokenLifetimePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    tokenLifetimePolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    training: {
        properties: [
            "languageDetails|trainingLanguageDetails|/[Name]|trainingLanguageDetail"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        languageDetails: {
            requestType: utils_1.RequestType.Get,
            returnType: "trainingLanguageDetails"
        },
    },
    trainings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    trainingLanguageDetail: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    trainingLanguageDetails: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    trending: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resource: {
            returnType: "entity"
        },
    },
    trendings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    triggerTypesRoot: {
        properties: [
            "retentionEventTypes|retentionEventTypes|/[Name]|retentionEventType"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        retentionEventTypes: {
            requestType: utils_1.RequestType.Get,
            returnType: "retentionEventTypes"
        },
    },
    triggersRoot: {
        properties: [
            "retentionEvents|retentionEvents|/[Name]|retentionEvent"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        retentionEvents: {
            requestType: utils_1.RequestType.Get,
            returnType: "retentionEvents"
        },
    },
    unbilledUsage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unclassifiedArtifact: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedGroupSource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        group: {
            returnType: "group"
        },
    },
    unifiedRbacResourceAction: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRbacResourceActions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRbacResourceNamespace: {
        properties: [
            "resourceActions|unifiedRbacResourceActions|/[Name]|unifiedRbacResourceAction"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resourceActions: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRbacResourceActions"
        },
    },
    unifiedRbacResourceNamespaces: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appScope: {
            returnType: "appScope"
        },
        directoryScope: {
            returnType: "directoryObject"
        },
        principal: {
            returnType: "directoryObject"
        },
        roleDefinition: {
            returnType: "unifiedRoleDefinition"
        },
    },
    unifiedRoleAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleAssignmentSchedule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activatedUsing: {
            returnType: "unifiedRoleEligibilitySchedule"
        },
    },
    unifiedRoleAssignmentSchedules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleAssignmentScheduleInstance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activatedUsing: {
            returnType: "unifiedRoleEligibilityScheduleInstance"
        },
    },
    unifiedRoleAssignmentScheduleInstances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleAssignmentScheduleRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        activatedUsing: {
            returnType: "unifiedRoleEligibilitySchedule"
        },
        appScope: {
            returnType: "appScope"
        },
        directoryScope: {
            returnType: "directoryObject"
        },
        principal: {
            returnType: "directoryObject"
        },
        roleDefinition: {
            returnType: "unifiedRoleDefinition"
        },
        targetSchedule: {
            returnType: "unifiedRoleAssignmentSchedule"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    unifiedRoleAssignmentScheduleRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleDefinition: {
        properties: [
            "inheritsPermissionsFrom|unifiedRoleDefinitions|/[Name]|unifiedRoleDefinition"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        inheritsPermissionsFrom: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleDefinitions"
        },
    },
    unifiedRoleDefinitions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleEligibilitySchedule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleEligibilitySchedules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleEligibilityScheduleInstance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleEligibilityScheduleInstances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleEligibilityScheduleRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appScope: {
            returnType: "appScope"
        },
        directoryScope: {
            returnType: "directoryObject"
        },
        principal: {
            returnType: "directoryObject"
        },
        roleDefinition: {
            returnType: "unifiedRoleDefinition"
        },
        targetSchedule: {
            returnType: "unifiedRoleEligibilitySchedule"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    unifiedRoleEligibilityScheduleRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicy: {
        properties: [
            "effectiveRules|unifiedRoleManagementPolicyRules|/[Name]|unifiedRoleManagementPolicyRule", "rules|unifiedRoleManagementPolicyRules|/[Name]|unifiedRoleManagementPolicyRule"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        effectiveRules: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleManagementPolicyRules"
        },
        rules: {
            requestType: utils_1.RequestType.Get,
            returnType: "unifiedRoleManagementPolicyRules"
        },
    },
    unifiedRoleManagementPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyApprovalRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        policy: {
            returnType: "unifiedRoleManagementPolicy"
        },
    },
    unifiedRoleManagementPolicyAssignments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyAuthenticationContextRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyEnablementRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyExpirationRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyNotificationRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyRule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleManagementPolicyRules: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    unifiedRoleScheduleBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appScope: {
            returnType: "appScope"
        },
        directoryScope: {
            returnType: "directoryObject"
        },
        principal: {
            returnType: "directoryObject"
        },
        roleDefinition: {
            returnType: "unifiedRoleDefinition"
        },
    },
    unifiedRoleScheduleInstanceBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appScope: {
            returnType: "appScope"
        },
        directoryScope: {
            returnType: "directoryObject"
        },
        principal: {
            returnType: "directoryObject"
        },
        roleDefinition: {
            returnType: "unifiedRoleDefinition"
        },
    },
    unifiedStorageQuota: {
        properties: [
            "services|serviceStorageQuotaBreakdowns|/[Name]|serviceStorageQuotaBreakdown"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        services: {
            requestType: utils_1.RequestType.Get,
            returnType: "serviceStorageQuotaBreakdowns"
        },
    },
    unmuteParticipantOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    updateRecordingStatusOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    urlAssessmentRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    usedInsight: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        resource: {
            returnType: "entity"
        },
    },
    usedInsights: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    user: {
        properties: [
            "appRoleAssignments|appRoleAssignments|/[Name]|appRoleAssignment", "createdObjects|directoryObjects|/[Name]|directoryObject", "directReports|directoryObjects|/[Name]|directoryObject", "licenseDetails|licenseDetailss|/[Name]|licenseDetails", "memberOf|directoryObjects|/[Name]|directoryObject", "oauth2PermissionGrants|oAuth2PermissionGrants|/[Name]|oAuth2PermissionGrant", "ownedDevices|directoryObjects|/[Name]|directoryObject", "ownedObjects|directoryObjects|/[Name]|directoryObject", "registeredDevices|directoryObjects|/[Name]|directoryObject", "scopedRoleMemberOf|scopedRoleMemberships|/[Name]|scopedRoleMembership", "sponsors|directoryObjects|/[Name]|directoryObject", "transitiveMemberOf|directoryObjects|/[Name]|directoryObject", "calendarGroups|calendarGroups|/[Name]|calendarGroup", "calendars|calendars|/[Name]|calendar", "calendarView|events|/[Name]|event", "contactFolders|contactFolders|/[Name]|contactFolder", "contacts|contacts|/[Name]|contact", "events|events|/[Name]|event", "mailFolders|mailFolders|/[Name]|mailFolder", "messages|messages|/[Name]|message", "people|persons|/[Name]|person", "drives|drives|/[Name]|drive", "followedSites|sites|/[Name]|site", "extensions|extensions|/[Name]|extension", "agreementAcceptances|agreementAcceptances|/[Name]|agreementAcceptance", "managedDevices|managedDevices|/[Name]|managedDevice", "managedAppRegistrations|managedAppRegistrations|/[Name]|managedAppRegistration", "deviceManagementTroubleshootingEvents|deviceManagementTroubleshootingEvents|/[Name]|deviceManagementTroubleshootingEvent", "photos|profilePhotos|/[Name]|profilePhoto", "activities|userActivitys|/[Name]|userActivity", "onlineMeetings|onlineMeetings|/[Name]|onlineMeeting", "chats|chats|/[Name]|chat", "joinedTeams|teams|/[Name]|team", "permissionGrants|resourceSpecificPermissionGrants|/[Name]|resourceSpecificPermissionGrant"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appRoleAssignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "appRoleAssignments"
        },
        createdObjects: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        directReports: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        licenseDetails: {
            requestType: utils_1.RequestType.Get,
            returnType: "licenseDetailss"
        },
        manager: {
            returnType: "directoryObject"
        },
        memberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        oauth2PermissionGrants: {
            requestType: utils_1.RequestType.Get,
            returnType: "oAuth2PermissionGrants"
        },
        ownedDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        ownedObjects: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        registeredDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        scopedRoleMemberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "scopedRoleMemberships"
        },
        sponsors: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        transitiveMemberOf: {
            requestType: utils_1.RequestType.Get,
            returnType: "directoryObjects"
        },
        calendar: {
            returnType: "calendar"
        },
        calendarGroups: {
            requestType: utils_1.RequestType.Get,
            returnType: "calendarGroups"
        },
        calendars: {
            requestType: utils_1.RequestType.Get,
            returnType: "calendars"
        },
        calendarView: {
            requestType: utils_1.RequestType.Get,
            returnType: "events"
        },
        contactFolders: {
            requestType: utils_1.RequestType.Get,
            returnType: "contactFolders"
        },
        contacts: {
            requestType: utils_1.RequestType.Get,
            returnType: "contacts"
        },
        events: {
            requestType: utils_1.RequestType.Get,
            returnType: "events"
        },
        inferenceClassification: {
            returnType: "inferenceClassification"
        },
        mailFolders: {
            requestType: utils_1.RequestType.Get,
            returnType: "mailFolders"
        },
        messages: {
            requestType: utils_1.RequestType.Get,
            returnType: "messages"
        },
        outlook: {
            returnType: "outlookUser"
        },
        people: {
            requestType: utils_1.RequestType.Get,
            returnType: "persons"
        },
        drive: {
            returnType: "drive"
        },
        drives: {
            requestType: utils_1.RequestType.Get,
            returnType: "drives"
        },
        followedSites: {
            requestType: utils_1.RequestType.Get,
            returnType: "sites"
        },
        extensions: {
            requestType: utils_1.RequestType.Get,
            returnType: "extensions"
        },
        agreementAcceptances: {
            requestType: utils_1.RequestType.Get,
            returnType: "agreementAcceptances"
        },
        managedDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedDevices"
        },
        managedAppRegistrations: {
            requestType: utils_1.RequestType.Get,
            returnType: "managedAppRegistrations"
        },
        deviceManagementTroubleshootingEvents: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceManagementTroubleshootingEvents"
        },
        planner: {
            returnType: "plannerUser"
        },
        insights: {
            returnType: "itemInsights"
        },
        settings: {
            returnType: "userSettings"
        },
        onenote: {
            returnType: "onenote"
        },
        cloudClipboard: {
            returnType: "cloudClipboardRoot"
        },
        photo: {
            returnType: "profilePhoto"
        },
        photos: {
            requestType: utils_1.RequestType.Get,
            returnType: "profilePhotos"
        },
        activities: {
            requestType: utils_1.RequestType.Get,
            returnType: "userActivitys"
        },
        onlineMeetings: {
            requestType: utils_1.RequestType.Get,
            returnType: "onlineMeetings"
        },
        presence: {
            returnType: "presence"
        },
        authentication: {
            returnType: "authentication"
        },
        chats: {
            requestType: utils_1.RequestType.Get,
            returnType: "chats"
        },
        joinedTeams: {
            requestType: utils_1.RequestType.Get,
            returnType: "teams"
        },
        permissionGrants: {
            requestType: utils_1.RequestType.Get,
            returnType: "resourceSpecificPermissionGrants"
        },
        teamwork: {
            returnType: "userTeamwork"
        },
        solutions: {
            returnType: "userSolutionRoot"
        },
        todo: {
            returnType: "todo"
        },
        employeeExperience: {
            returnType: "employeeExperienceUser"
        },
        assignLicense: {
            argNames: ["addLicenses", "removeLicenses"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.user"
        },
        changePassword: {
            argNames: ["currentPassword", "newPassword"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        reprocessLicenseAssignment: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.user"
        },
        retryServiceProvisioning: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        revokeSignInSessions: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "boolean"
        },
        findMeetingTimes: {
            argNames: ["attendees", "locationConstraint", "timeConstraint", "meetingDuration", "maxCandidates", "isOrganizerOptional", "returnSuggestionReasons", "minimumAttendeePercentage"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.meetingTimeSuggestionsResult"
        },
        getMailTips: {
            argNames: ["EmailAddresses", "MailTipsOptions"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.mailTips[]"
        },
        sendMail: {
            argNames: ["Message", "SaveToSentItems"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        translateExchangeIds: {
            argNames: ["InputIds", "TargetIdType", "SourceIdType"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.convertIdResult[]"
        },
        removeAllDevicesFromManagement: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        wipeManagedAppRegistrationsByDeviceTag: {
            argNames: ["deviceTag"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        exportPersonalData: {
            argNames: ["storageLocation"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        exportDeviceAndAppManagementData: {
            argNames: ["skip", "top"],
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.deviceAndAppManagementData"
        },
        getManagedAppDiagnosticStatuses: {
            requestType: utils_1.RequestType.Get,
            returnType: "ComplexTypes.managedAppDiagnosticStatus[]"
        },
        getManagedAppPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "EntityTypes.managedAppPolicy[]"
        },
        getManagedDevicesWithAppFailures: {
            requestType: utils_1.RequestType.Get,
            returnType: "Array<string>[]"
        },
    },
    users: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userActivity: {
        properties: [
            "historyItems|activityHistoryItems|/[Name]|activityHistoryItem"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        historyItems: {
            requestType: utils_1.RequestType.Get,
            returnType: "activityHistoryItems"
        },
    },
    userActivitys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userConsentRequest: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        approval: {
            returnType: "approval"
        },
    },
    userConsentRequests: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDetails: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDetailss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDeviceId: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthAppPerformanceByAppVersionDeviceIds: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthAppPerformanceByOSVersion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthAppPerformanceByOSVersions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthApplicationPerformance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthApplicationPerformances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthDeviceModelPerformance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthDeviceModelPerformances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthDevicePerformance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthDevicePerformances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthDevicePerformanceDetails: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthDevicePerformanceDetailss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthOSVersionPerformance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsAppHealthOSVersionPerformances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsBaseline: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        appHealthMetrics: {
            returnType: "userExperienceAnalyticsCategory"
        },
        batteryHealthMetrics: {
            returnType: "userExperienceAnalyticsCategory"
        },
        bestPracticesMetrics: {
            returnType: "userExperienceAnalyticsCategory"
        },
        deviceBootPerformanceMetrics: {
            returnType: "userExperienceAnalyticsCategory"
        },
        rebootAnalyticsMetrics: {
            returnType: "userExperienceAnalyticsCategory"
        },
        resourcePerformanceMetrics: {
            returnType: "userExperienceAnalyticsCategory"
        },
        workFromAnywhereMetrics: {
            returnType: "userExperienceAnalyticsCategory"
        },
    },
    userExperienceAnalyticsBaselines: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsCategory: {
        properties: [
            "metricValues|userExperienceAnalyticsMetrics|/[Name]|userExperienceAnalyticsMetric"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        metricValues: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsMetrics"
        },
    },
    userExperienceAnalyticsCategorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDevicePerformance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDevicePerformances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceScores: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceScoress: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceStartupHistory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceStartupHistorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceStartupProcess: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceStartupProcesss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceStartupProcessPerformance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsDeviceStartupProcessPerformances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsMetric: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsMetrics: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsMetricHistory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsMetricHistorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsModelScores: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsModelScoress: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsOverview: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsScoreHistory: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsScoreHistorys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsWorkFromAnywhereDevice: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsWorkFromAnywhereDevices: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsWorkFromAnywhereHardwareReadinessMetric: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsWorkFromAnywhereMetric: {
        properties: [
            "metricDevices|userExperienceAnalyticsWorkFromAnywhereDevices|/[Name]|userExperienceAnalyticsWorkFromAnywhereDevice"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        metricDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "userExperienceAnalyticsWorkFromAnywhereDevices"
        },
    },
    userExperienceAnalyticsWorkFromAnywhereMetrics: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsWorkFromAnywhereModelPerformance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userExperienceAnalyticsWorkFromAnywhereModelPerformances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userFlowLanguageConfiguration: {
        properties: [
            "defaultPages|userFlowLanguagePages|/[Name]|userFlowLanguagePage", "overridesPages|userFlowLanguagePages|/[Name]|userFlowLanguagePage"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        defaultPages: {
            requestType: utils_1.RequestType.Get,
            returnType: "userFlowLanguagePages"
        },
        overridesPages: {
            requestType: utils_1.RequestType.Get,
            returnType: "userFlowLanguagePages"
        },
    },
    userFlowLanguageConfigurations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userFlowLanguagePage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userFlowLanguagePages: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userInsightsSettings: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userInstallStateSummary: {
        properties: [
            "deviceStates|deviceInstallStates|/[Name]|deviceInstallState"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        deviceStates: {
            requestType: utils_1.RequestType.Get,
            returnType: "deviceInstallStates"
        },
    },
    userInstallStateSummarys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userProcessingResult: {
        properties: [
            "taskProcessingResults|taskProcessingResults|/[Name]|taskProcessingResult"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        subject: {
            returnType: "user"
        },
        taskProcessingResults: {
            requestType: utils_1.RequestType.Get,
            returnType: "taskProcessingResults"
        },
    },
    userRegistrationDetails: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userRegistrationDetailss: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userScopeTeamsAppInstallation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        chat: {
            returnType: "chat"
        },
    },
    userScopeTeamsAppInstallations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userSettings: {
        properties: [
            "windows|windowsSettings|/[Name]|windowsSetting"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        itemInsights: {
            returnType: "userInsightsSettings"
        },
        windows: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsSettings"
        },
        shiftPreferences: {
            returnType: "shiftPreferences"
        },
        storage: {
            returnType: "userStorage"
        },
    },
    userSignInInsight: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userSolutionRoot: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        workingTimeSchedule: {
            returnType: "workingTimeSchedule"
        },
    },
    userSource: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    userStorage: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        quota: {
            returnType: "unifiedStorageQuota"
        },
    },
    userTeamwork: {
        properties: [
            "associatedTeams|associatedTeamInfos|/[Name]|associatedTeamInfo", "installedApps|userScopeTeamsAppInstallations|/[Name]|userScopeTeamsAppInstallation"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        associatedTeams: {
            requestType: utils_1.RequestType.Get,
            returnType: "associatedTeamInfos"
        },
        installedApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "userScopeTeamsAppInstallations"
        },
        sendActivityNotification: {
            argNames: ["topic", "activityType", "chainId", "previewText", "teamsAppId", "templateParameters"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    verticalSection: {
        properties: [
            "webparts|webParts|/[Name]|webPart"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        webparts: {
            requestType: utils_1.RequestType.Get,
            returnType: "webParts"
        },
    },
    virtualEndpoint: {
        properties: [
            "auditEvents|cloudPcAuditEvents|/[Name]|cloudPcAuditEvent", "cloudPCs|cloudPCs|/[Name]|cloudPC", "deviceImages|cloudPcDeviceImages|/[Name]|cloudPcDeviceImage", "galleryImages|cloudPcGalleryImages|/[Name]|cloudPcGalleryImage", "onPremisesConnections|cloudPcOnPremisesConnections|/[Name]|cloudPcOnPremisesConnection", "provisioningPolicies|cloudPcProvisioningPolicys|/[Name]|cloudPcProvisioningPolicy", "userSettings|cloudPcUserSettings|/[Name]|cloudPcUserSetting"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        auditEvents: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcAuditEvents"
        },
        cloudPCs: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPCs"
        },
        deviceImages: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcDeviceImages"
        },
        galleryImages: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcGalleryImages"
        },
        onPremisesConnections: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcOnPremisesConnections"
        },
        provisioningPolicies: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcProvisioningPolicys"
        },
        userSettings: {
            requestType: utils_1.RequestType.Get,
            returnType: "cloudPcUserSettings"
        },
    },
    virtualEvent: {
        properties: [
            "presenters|virtualEventPresenters|/[Name]|virtualEventPresenter", "sessions|virtualEventSessions|/[Name]|virtualEventSession"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        presenters: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEventPresenters"
        },
        sessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEventSessions"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        publish: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        setExternalEventInformation: {
            argNames: ["externalEventId"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    virtualEvents: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventPresenter: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventPresenters: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventRegistration: {
        properties: [
            "sessions|virtualEventSessions|/[Name]|virtualEventSession"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        sessions: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEventSessions"
        },
        cancel: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    virtualEventRegistrations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventRegistrationConfiguration: {
        properties: [
            "questions|virtualEventRegistrationQuestionBases|/[Name]|virtualEventRegistrationQuestionBase"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        questions: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEventRegistrationQuestionBases"
        },
    },
    virtualEventRegistrationCustomQuestion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventRegistrationPredefinedQuestion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventRegistrationQuestionBase: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventRegistrationQuestionBases: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventSession: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventSessions: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventTownhall: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventTownhalls: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventWebinar: {
        properties: [
            "registrations|virtualEventRegistrations|/[Name]|virtualEventRegistration"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        registrationConfiguration: {
            returnType: "virtualEventWebinarRegistrationConfiguration"
        },
        registrations: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEventRegistrations"
        },
    },
    virtualEventWebinars: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventWebinarRegistrationConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    virtualEventsRoot: {
        properties: [
            "events|virtualEvents|/[Name]|virtualEvent", "townhalls|virtualEventTownhalls|/[Name]|virtualEventTownhall", "webinars|virtualEventWebinars|/[Name]|virtualEventWebinar"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        events: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEvents"
        },
        townhalls: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEventTownhalls"
        },
        webinars: {
            requestType: utils_1.RequestType.Get,
            returnType: "virtualEventWebinars"
        },
    },
    voiceAuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|authenticationMethodTargets|/[Name]|authenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodTargets"
        },
    },
    vppToken: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        syncLicenses: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "EntityTypes.vppToken"
        },
    },
    vppTokens: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    vulnerability: {
        properties: [
            "articles|articles|/[Name]|article", "components|vulnerabilityComponents|/[Name]|vulnerabilityComponent"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        articles: {
            requestType: utils_1.RequestType.Get,
            returnType: "articles"
        },
        components: {
            requestType: utils_1.RequestType.Get,
            returnType: "vulnerabilityComponents"
        },
    },
    vulnerabilityComponent: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    webApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    webPart: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        getPositionOfWebPart: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
            returnType: "ComplexTypes.webPartPosition"
        },
    },
    webParts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    whoisBaseRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        host: {
            returnType: "host"
        },
    },
    whoisHistoryRecord: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    whoisRecord: {
        properties: [
            "history|whoisHistoryRecords|/[Name]|whoisHistoryRecord"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        history: {
            requestType: utils_1.RequestType.Get,
            returnType: "whoisHistoryRecords"
        },
    },
    win32LobApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10CompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10CustomConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10EndpointProtectionConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10EnrollmentCompletionPageConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10EnterpriseModernAppManagementConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10GeneralConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10MobileCompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10SecureAssessmentConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows10TeamGeneralConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows81CompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windows81GeneralConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsAppX: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsAutopilotDeploymentProfile: {
        properties: [
            "assignedDevices|windowsAutopilotDeviceIdentitys|/[Name]|windowsAutopilotDeviceIdentity"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignedDevices: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsAutopilotDeviceIdentitys"
        },
    },
    windowsAutopilotDeploymentProfileAssignment: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsAutopilotDeviceIdentity: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignUserToDevice: {
            argNames: ["userPrincipalName", "addressableUserName"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        unassignUserFromDevice: {
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
        updateDeviceProperties: {
            argNames: ["userPrincipalName", "addressableUserName", "groupTag", "displayName"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    windowsAutopilotDeviceIdentitys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsDefenderAdvancedThreatProtectionConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsDeviceMalwareState: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsDeviceMalwareStates: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsHelloForBusinessAuthenticationMethod: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        device: {
            returnType: "device"
        },
    },
    windowsHelloForBusinessAuthenticationMethods: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtection: {
        properties: [
            "assignments|targetedManagedAppPolicyAssignments|/[Name]|targetedManagedAppPolicyAssignment", "exemptAppLockerFiles|windowsInformationProtectionAppLockerFiles|/[Name]|windowsInformationProtectionAppLockerFile", "protectedAppLockerFiles|windowsInformationProtectionAppLockerFiles|/[Name]|windowsInformationProtectionAppLockerFile"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        assignments: {
            requestType: utils_1.RequestType.Get,
            returnType: "targetedManagedAppPolicyAssignments"
        },
        exemptAppLockerFiles: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsInformationProtectionAppLockerFiles"
        },
        protectedAppLockerFiles: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsInformationProtectionAppLockerFiles"
        },
        assign: {
            argNames: ["assignments"],
            requestType: utils_1.RequestType.PostWithArgsInBody,
        },
    },
    windowsInformationProtectionAppLearningSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtectionAppLearningSummarys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtectionAppLockerFile: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtectionAppLockerFiles: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtectionNetworkLearningSummary: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtectionNetworkLearningSummarys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtectionPolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsInformationProtectionPolicys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsMalwareInformation: {
        properties: [
            "deviceMalwareStates|malwareStateForWindowsDevices|/[Name]|malwareStateForWindowsDevice"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        deviceMalwareStates: {
            requestType: utils_1.RequestType.Get,
            returnType: "malwareStateForWindowsDevices"
        },
    },
    windowsMalwareInformations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsMicrosoftEdgeApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsMobileMSI: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsPhone81CompliancePolicy: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsPhone81CustomConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsPhone81GeneralConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsProtectionState: {
        properties: [
            "detectedMalwareState|windowsDeviceMalwareStates|/[Name]|windowsDeviceMalwareState"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        detectedMalwareState: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsDeviceMalwareStates"
        },
    },
    windowsSetting: {
        properties: [
            "instances|windowsSettingInstances|/[Name]|windowsSettingInstance"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        instances: {
            requestType: utils_1.RequestType.Get,
            returnType: "windowsSettingInstances"
        },
    },
    windowsSettings: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsSettingInstance: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsSettingInstances: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsUniversalAppX: {
        properties: [
            "committedContainedApps|mobileContainedApps|/[Name]|mobileContainedApp"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        committedContainedApps: {
            requestType: utils_1.RequestType.Get,
            returnType: "mobileContainedApps"
        },
    },
    windowsUniversalAppXContainedApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsUpdateForBusinessConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    windowsWebApp: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbook: {
        properties: [
            "comments|workbookComments|/[Name]|workbookComment", "names|workbookNamedItems|/[Name]|workbookNamedItem", "operations|workbookOperations|/[Name]|workbookOperation", "tables|workbookTables|/[Name]|workbookTable", "worksheets|workbookWorksheets|/[Name]|workbookWorksheet"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        application: {
            returnType: "workbookApplication"
        },
        comments: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookComments"
        },
        functions: {
            returnType: "workbookFunctions"
        },
        names: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookNamedItems"
        },
        operations: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookOperations"
        },
        tables: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookTables"
        },
        worksheets: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookWorksheets"
        },
    },
    workbookApplication: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookChart: {
        properties: [
            "series|workbookChartSeriess|/[Name]|workbookChartSeries"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        axes: {
            returnType: "workbookChartAxes"
        },
        dataLabels: {
            returnType: "workbookChartDataLabels"
        },
        format: {
            returnType: "workbookChartAreaFormat"
        },
        legend: {
            returnType: "workbookChartLegend"
        },
        series: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookChartSeriess"
        },
        title: {
            returnType: "workbookChartTitle"
        },
        worksheet: {
            returnType: "workbookWorksheet"
        },
    },
    workbookCharts: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookChartAreaFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fill: {
            returnType: "workbookChartFill"
        },
        font: {
            returnType: "workbookChartFont"
        },
    },
    workbookChartAxes: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        categoryAxis: {
            returnType: "workbookChartAxis"
        },
        seriesAxis: {
            returnType: "workbookChartAxis"
        },
        valueAxis: {
            returnType: "workbookChartAxis"
        },
    },
    workbookChartAxis: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartAxisFormat"
        },
        majorGridlines: {
            returnType: "workbookChartGridlines"
        },
        minorGridlines: {
            returnType: "workbookChartGridlines"
        },
        title: {
            returnType: "workbookChartAxisTitle"
        },
    },
    workbookChartAxisFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        font: {
            returnType: "workbookChartFont"
        },
        line: {
            returnType: "workbookChartLineFormat"
        },
    },
    workbookChartAxisTitle: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartAxisTitleFormat"
        },
    },
    workbookChartAxisTitleFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        font: {
            returnType: "workbookChartFont"
        },
    },
    workbookChartDataLabelFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fill: {
            returnType: "workbookChartFill"
        },
        font: {
            returnType: "workbookChartFont"
        },
    },
    workbookChartDataLabels: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartDataLabelFormat"
        },
    },
    workbookChartFill: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookChartFont: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookChartGridlines: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartGridlinesFormat"
        },
    },
    workbookChartGridlinesFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        line: {
            returnType: "workbookChartLineFormat"
        },
    },
    workbookChartLegend: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartLegendFormat"
        },
    },
    workbookChartLegendFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fill: {
            returnType: "workbookChartFill"
        },
        font: {
            returnType: "workbookChartFont"
        },
    },
    workbookChartLineFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookChartPoint: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartPointFormat"
        },
    },
    workbookChartPoints: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookChartPointFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fill: {
            returnType: "workbookChartFill"
        },
    },
    workbookChartSeries: {
        properties: [
            "points|workbookChartPoints|/[Name]|workbookChartPoint"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartSeriesFormat"
        },
        points: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookChartPoints"
        },
    },
    workbookChartSeriess: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookChartSeriesFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fill: {
            returnType: "workbookChartFill"
        },
        line: {
            returnType: "workbookChartLineFormat"
        },
    },
    workbookChartTitle: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookChartTitleFormat"
        },
    },
    workbookChartTitleFormat: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        fill: {
            returnType: "workbookChartFill"
        },
        font: {
            returnType: "workbookChartFont"
        },
    },
    workbookComment: {
        properties: [
            "replies|workbookCommentReplys|/[Name]|workbookCommentReply"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        replies: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookCommentReplys"
        },
    },
    workbookComments: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookCommentReply: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookCommentReplys: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookFilter: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookFormatProtection: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookFunctionResult: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookFunctions: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookNamedItem: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        worksheet: {
            returnType: "workbookWorksheet"
        },
    },
    workbookNamedItems: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookOperation: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookOperations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookPivotTable: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        worksheet: {
            returnType: "workbookWorksheet"
        },
    },
    workbookPivotTables: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookRange: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        format: {
            returnType: "workbookRangeFormat"
        },
        sort: {
            returnType: "workbookRangeSort"
        },
        worksheet: {
            returnType: "workbookWorksheet"
        },
    },
    workbookRangeBorder: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookRangeBorders: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookRangeFill: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookRangeFont: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookRangeFormat: {
        properties: [
            "borders|workbookRangeBorders|/[Name]|workbookRangeBorder"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        borders: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookRangeBorders"
        },
        fill: {
            returnType: "workbookRangeFill"
        },
        font: {
            returnType: "workbookRangeFont"
        },
        protection: {
            returnType: "workbookFormatProtection"
        },
    },
    workbookRangeSort: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookRangeView: {
        properties: [
            "rows|workbookRangeViews|/[Name]|workbookRangeView"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        rows: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookRangeViews"
        },
    },
    workbookRangeViews: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookTable: {
        properties: [
            "columns|workbookTableColumns|/[Name]|workbookTableColumn", "rows|workbookTableRows|/[Name]|workbookTableRow"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        columns: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookTableColumns"
        },
        rows: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookTableRows"
        },
        sort: {
            returnType: "workbookTableSort"
        },
        worksheet: {
            returnType: "workbookWorksheet"
        },
    },
    workbookTables: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookTableColumn: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        filter: {
            returnType: "workbookFilter"
        },
    },
    workbookTableColumns: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookTableRow: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookTableRows: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookTableSort: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookWorksheet: {
        properties: [
            "charts|workbookCharts|/[Name]|workbookChart", "names|workbookNamedItems|/[Name]|workbookNamedItem", "pivotTables|workbookPivotTables|/[Name]|workbookPivotTable", "tables|workbookTables|/[Name]|workbookTable"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        charts: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookCharts"
        },
        names: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookNamedItems"
        },
        pivotTables: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookPivotTables"
        },
        protection: {
            returnType: "workbookWorksheetProtection"
        },
        tables: {
            requestType: utils_1.RequestType.Get,
            returnType: "workbookTables"
        },
    },
    workbookWorksheets: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workbookWorksheetProtection: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workflow: {
        properties: [
            "executionScope|userProcessingResults|/[Name]|userProcessingResult", "runs|runs|/[Name]|run", "taskReports|taskReports|/[Name]|taskReport", "userProcessingResults|userProcessingResults|/[Name]|userProcessingResult", "versions|workflowVersions|/[Name]|workflowVersion"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        executionScope: {
            requestType: utils_1.RequestType.Get,
            returnType: "userProcessingResults"
        },
        runs: {
            requestType: utils_1.RequestType.Get,
            returnType: "runs"
        },
        taskReports: {
            requestType: utils_1.RequestType.Get,
            returnType: "taskReports"
        },
        userProcessingResults: {
            requestType: utils_1.RequestType.Get,
            returnType: "userProcessingResults"
        },
        versions: {
            requestType: utils_1.RequestType.Get,
            returnType: "workflowVersions"
        },
    },
    workflowBase: {
        properties: [
            "tasks|tasks|/[Name]|task"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        createdBy: {
            returnType: "user"
        },
        lastModifiedBy: {
            returnType: "user"
        },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "tasks"
        },
    },
    workflowTemplate: {
        properties: [
            "tasks|tasks|/[Name]|task"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        tasks: {
            requestType: utils_1.RequestType.Get,
            returnType: "tasks"
        },
    },
    workflowVersion: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workforceIntegration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workforceIntegrations: {
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    workingTimeSchedule: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
    x509CertificateAuthenticationMethodConfiguration: {
        properties: [
            "includeTargets|authenticationMethodTargets|/[Name]|authenticationMethodTarget"
        ],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
        includeTargets: {
            requestType: utils_1.RequestType.Get,
            returnType: "authenticationMethodTargets"
        },
    },
    x509CertificateCombinationConfiguration: {
        properties: [],
        query: { argNames: ["oData"], requestType: utils_1.RequestType.OData },
    },
};
